@@ -22,21 +22,19 @@
  */
 
 #include "modules/adminapi/cluster/add_instance.h"
-#include <functional>
+
 #include "adminapi/common/group_replication_options.h"
 #include "modules/adminapi/common/connectivity_check.h"
 #include "modules/adminapi/common/dba_errors.h"
 #include "modules/adminapi/common/gtid_validations.h"
 #include "modules/adminapi/common/instance_validations.h"
-#include "modules/adminapi/common/member_recovery_monitoring.h"
 #include "modules/adminapi/common/provision.h"
 #include "modules/adminapi/common/server_features.h"
-#include "modules/adminapi/common/validations.h"
+#include "mysqlshdk/libs/config/config_server_handler.h"
 #include "mysqlshdk/libs/mysql/async_replication.h"
 #include "mysqlshdk/libs/mysql/clone.h"
 #include "mysqlshdk/libs/textui/textui.h"
 #include "mysqlshdk/libs/utils/debug.h"
-#include "mysqlshdk/libs/utils/utils_net.h"
 
 namespace mysqlsh::dba::cluster {
 
@@ -175,7 +173,7 @@ void Add_instance::store_local_replication_account() const {
   log_debug("Adding joining member recovery account to metadata");
   m_cluster_impl->execute_in_members(
       [this](const std::shared_ptr<Instance> &instance,
-             const Instance_md_and_gr_member &info) {
+             const Cluster_impl::Instance_md_and_gr_member &info) {
         if (info.second.state == mysqlshdk::gr::Member_state::ONLINE) {
           try {
             m_cluster_impl->get_metadata_storage()
@@ -183,7 +181,7 @@ void Add_instance::store_local_replication_account() const {
                     instance->get_uuid(), Cluster_type::GROUP_REPLICATION,
                     Replica_type::GROUP_MEMBER,
                     m_gr_opts.recovery_credentials->user, m_account_host);
-          } catch (const std::exception &e) {
+          } catch (const std::exception &) {
             log_info(
                 "Failed updating Metadata of '%s' to include the recovery "
                 "account of the joining member",
@@ -192,9 +190,8 @@ void Add_instance::store_local_replication_account() const {
         }
         return true;
       },
-      [](const shcore::Error &, const Instance_md_and_gr_member &) {
-        return true;
-      });
+      [](const shcore::Error &,
+         const Cluster_impl::Instance_md_and_gr_member &) { return true; });
 
   m_cluster_impl->get_metadata_storage()->update_instance_repl_account(
       m_target_instance->get_uuid(), Cluster_type::GROUP_REPLICATION,
@@ -514,9 +511,6 @@ void Add_instance::do_run() {
   auto cfg = mysqlsh::dba::create_server_config(
       m_target_instance.get(), mysqlshdk::config::k_dft_cfg_server_handler);
 
-  // Common informative logging
-  cluster_topology_executor_ops::log_used_gr_options(m_gr_opts);
-
   console->print_info("Adding instance to the cluster...");
   console->print_info();
 
@@ -575,10 +569,10 @@ void Add_instance::do_run() {
     m_cluster_impl->configure_cluster_set_member(m_target_instance);
   }
 
-  const auto post_failure_actions = [this](bool owns_rpl_user,
-                                           bool drop_rpl_user,
-                                           int64_t restore_clone_thrsh,
-                                           bool restore_rec_accounts) {
+  const auto post_failure_actions = [this, &cfg](bool owns_rpl_user,
+                                                 bool drop_rpl_user,
+                                                 int64_t restore_clone_thrsh,
+                                                 bool restore_rec_accounts) {
     assert(restore_clone_thrsh >= -1);
 
     bool credentials_exist = m_gr_opts.recovery_credentials &&
@@ -619,19 +613,29 @@ void Add_instance::do_run() {
         }
       } catch (const shcore::Error &e) {
         log_info(
-            "Could not restore value of group_replication_clone_threshold: "
-            "%s. "
+            "Could not restore value of group_replication_clone_threshold: %s. "
             "Not a fatal error.",
             e.what());
       }
     }
+
+    // Restore remaining variables
+    {
+      auto srv_cfg = dynamic_cast<mysqlshdk::config::Config_server_handler *>(
+          cfg->get_handler(mysqlshdk::config::k_dft_cfg_server_handler));
+
+      if (srv_cfg) {
+        srv_cfg->remove_from_undo("group_replication_clone_threshold");
+        srv_cfg->undo_changes();
+      }
+    }
   };
 
   try {
     // we need a point in time as close as possible, but still earlier than
     // when recovery starts to monitor the recovery phase. The timestamp
     // resolution is timestamp(3) irrespective of platform
-    std::string join_begin_time =
+    auto join_begin_time =
         m_target_instance->queryf_one_string(0, "", "SELECT NOW(3)");
 
     bool recovery_certificates{false};
@@ -644,6 +648,7 @@ void Add_instance::do_run() {
       case mysqlsh::dba::Replication_auth_type::CERT_ISSUER_PASSWORD:
       case mysqlsh::dba::Replication_auth_type::CERT_SUBJECT_PASSWORD:
         recovery_certificates = true;
+        break;
       default:
         break;
     }
@@ -713,6 +718,10 @@ void Add_instance::do_run() {
           restore_recovery_accounts = true;
         }
 
+        DBUG_EXECUTE_IF("dba_revert_trigger_exception", {
+          throw shcore::Exception("Exception while adding instance.", 0);
+        });
+
         // Join the instance to the Group Replication group.
         mysqlsh::dba::join_cluster(*m_target_instance, *m_primary_instance,
                                    m_gr_opts, recovery_certificates,
@@ -743,6 +752,17 @@ void Add_instance::do_run() {
               is_instance_on_md ? "is already in the Metadata."
                                 : "is being added to the Metadata...");
 
+    // at this point, GR is already running, so if something wrong happens we
+    // don't want to clear any variables
+    {
+      auto srv_cfg = dynamic_cast<mysqlshdk::config::Config_server_handler *>(
+          cfg->get_handler(mysqlshdk::config::k_dft_cfg_server_handler));
+
+      if (srv_cfg) {
+        srv_cfg->remove_all_from_undo();
+      }
+    }
+
     MetadataStorage::Transaction trx(m_cluster_impl->get_metadata_storage());
 
     // If the instance is not on the Metadata, we must add it.
