@@ -22,25 +22,26 @@
  */
 #include "modules/adminapi/cluster/api_options.h"
 
-#include <cinttypes>
-#include <utility>
 #include <vector>
 
 #include "adminapi/common/api_options.h"
 #include "adminapi/common/async_topology.h"
 #include "modules/adminapi/common/common.h"
-#include "mysqlshdk/include/scripting/type_info/custom.h"
-#include "mysqlshdk/include/scripting/type_info/generic.h"
 #include "mysqlshdk/include/shellcore/console.h"
-#include "mysqlshdk/libs/db/utils_connection.h"
-#include "mysqlshdk/libs/utils/utils_file.h"
-#include "shellcore/shell_options.h"
-#include "utils/utils_net.h"
 
 namespace mysqlsh {
 namespace dba {
 namespace cluster {
 
+namespace {
+void throw_rescan_mixing_exception() {
+  throw shcore::Exception::argument_error(shcore::str_format(
+      "Options '%s' and '%s' are mutually exclusive with deprecated options "
+      "'%s' and '%s'. Mixing either one from both groups isn't allowed.",
+      kAddUnmanaged, kRemoveObsolete, kAddInstances, kRemoveInstances));
+}
+}  // namespace
+
 const shcore::Option_pack_def<Add_instance_options>
     &Add_instance_options::options() {
   static const auto opts =
@@ -143,6 +144,8 @@ const shcore::Option_pack_def<Rescan_options> &Rescan_options::options() {
                     &Rescan_options::set_update_topology_mode)
           .optional(kAddInstances, &Rescan_options::set_list_option)
           .optional(kRemoveInstances, &Rescan_options::set_list_option)
+          .optional(kAddUnmanaged, &Rescan_options::set_bool_option)
+          .optional(kRemoveObsolete, &Rescan_options::set_bool_option)
           .optional(kUpgradeCommProtocol,
                     &Rescan_options::upgrade_comm_protocol)
           .optional(kUpdateViewChangeUuid,
@@ -160,8 +163,32 @@ void Rescan_options::set_update_topology_mode(bool /*value*/) {
   console->print_info();
 }
 
+void Rescan_options::set_bool_option(const std::string &option, bool value) {
+  if (m_used_deprecated.has_value() && !m_used_deprecated.value())
+    throw_rescan_mixing_exception();
+
+  m_used_deprecated = true;
+
+  if (option == kAddUnmanaged)
+    auto_add = value;
+  else
+    auto_remove = value;
+}
+
 void Rescan_options::set_list_option(const std::string &option,
                                      const shcore::Value &value) {
+  if (m_used_deprecated.has_value() && m_used_deprecated.value())
+    throw_rescan_mixing_exception();
+
+  m_used_deprecated = false;
+
+  auto console = mysqlsh::current_console();
+  console->print_info(shcore::str_format(
+      "The '%s' and '%s' options are deprecated. Please use '%s' and/or '%s' "
+      "instead.",
+      kAddInstances, kRemoveInstances, kAddUnmanaged, kRemoveObsolete));
+  console->print_info();
+
   std::vector<mysqlshdk::db::Connection_options> *instances_list;
 
   // Selects the target list
@@ -170,7 +197,7 @@ void Rescan_options::set_list_option(const std::string &option,
 
   bool *auto_option = option == kRemoveInstances ? &auto_remove : &auto_add;
 
-  if (value.type == shcore::Value_type::String) {
+  if (value.get_type() == shcore::Value_type::String) {
     auto str_val = value.as_string();
     if (shcore::str_caseeq(str_val, "auto")) {
       *auto_option = true;
@@ -180,7 +207,7 @@ void Rescan_options::set_list_option(const std::string &option,
           "value, otherwise a list of instances is expected.",
           option.c_str()));
     }
-  } else if (value.type == shcore::Value_type::Array) {
+  } else if (value.get_type() == shcore::Value_type::Array) {
     auto instances_array = value.as_array();
     if (instances_array->empty()) {
       throw shcore::Exception::argument_error(shcore::str_format(
@@ -232,7 +259,7 @@ void Add_replica_instance_options::set_replication_sources(
   validate_replication_sources_option(value);
 
   // Iterate the list to build the vector of Managed_async_channel_source(s)
-  if (value.type == shcore::Value_type::Array) {
+  if (value.get_type() == shcore::Value_type::Array) {
     auto sources = value.to_string_container<std::vector<std::string>>();
 
     replication_sources_option.replication_sources =
@@ -258,7 +285,7 @@ void Add_replica_instance_options::set_replication_sources(
 
     // Set the source type to CUSTOM
     replication_sources_option.source_type = Source_type::CUSTOM;
-  } else if (value.type == shcore::Value_type::String) {
+  } else if (value.get_type() == shcore::Value_type::String) {
     auto string = value.as_string();
 
     if (shcore::str_caseeq(string, kReplicationSourcesAutoPrimary)) {
