@@ -29,8 +29,8 @@
 #include "modules/adminapi/common/parallel_applier_options.h"
 #include "modules/adminapi/common/server_features.h"
 #include "mysqlshdk/libs/mysql/group_replication.h"
-#include "mysqlshdk/libs/mysql/repl_config.h"
 #include "mysqlshdk/libs/mysql/replication.h"
+#include "utils/version.h"
 
 namespace mysqlsh {
 namespace dba {
@@ -253,11 +253,18 @@ shcore::Array_t Options::get_instance_options(
     const mysqlsh::dba::Instance &instance) {
   shcore::Array_t array = shcore::make_array();
   Parallel_applier_options parallel_applier_options(instance);
+  auto target_instance_version = instance.get_version();
 
   // Get all the options supported by the AdminAPI
   // If the target instance does not support a particular option, it will be
   // listed with the null value, as expected.
   for (const auto &cfg : k_instance_options) {
+    // Skip ipWhitelist since that's removed in 8.3.0
+    if (target_instance_version >= mysqlshdk::utils::Version(8, 3, 0) &&
+        cfg.first == kIpWhitelist) {
+      continue;
+    }
+
     shcore::Dictionary_t option = shcore::make_dict();
     auto value = instance.get_sysvar_string(
         cfg.second, mysqlshdk::mysql::Var_qualifier::GLOBAL);
@@ -303,6 +310,12 @@ shcore::Array_t Options::get_instance_options(
       // skip it as it was already retrieved before
       if (option_supported_by_adminapi(name)) continue;
 
+      // Skip ipWhitelist since that's removed in 8.3.0
+      if (target_instance_version >= mysqlshdk::utils::Version(8, 3, 0) &&
+          name == kIpWhitelist) {
+        continue;
+      }
+
       shcore::Dictionary_t option = shcore::make_dict();
 
       (*option)["variable"] = shcore::Value(name);
