@@ -22,6 +22,7 @@
  */
 
 #include "modules/adminapi/cluster/remove_replica_instance.h"
+
 #include "modules/adminapi/common/async_topology.h"
 #include "modules/adminapi/common/dba_errors.h"
 #include "mysqlshdk/libs/mysql/async_replication.h"
@@ -172,7 +173,7 @@ void Remove_replica_instance::do_run() {
                  m_options.dry_run);
 
   m_undo_tracker.add_back(
-      "Adding back Read-Replica replication channel", [=]() {
+      "Adding back Read-Replica replication channel", [this]() {
         std::string repl_user;
         std::string repl_user_host;
 
@@ -234,4 +235,7 @@ void Remove_replica_instance::do_run() {
     console->print_info();
   }
 }
+
+void Remove_replica_instance::do_undo() { m_undo_tracker.execute(); }
+
 }  // namespace mysqlsh::dba::cluster
