@@ -30,15 +30,14 @@
 
 #include "modules/adminapi/common/metadata_storage.h"
 #include "modules/adminapi/common/preconditions.h"
+#include "modules/adminapi/common/server_features.h"
 #include "modules/adminapi/common/validations.h"
 #include "mysqlshdk/include/scripting/types.h"
 #include "mysqlshdk/include/shellcore/console.h"
 #include "mysqlshdk/libs/config/config.h"
-#include "mysqlshdk/libs/config/config_server_handler.h"
-#include "mysqlshdk/libs/db/mysql/session.h"
-#include "mysqlshdk/libs/mysql/async_replication.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
 #include "mysqlshdk/libs/utils/utils_net.h"
+#include "utils/version.h"
 
 namespace mysqlsh {
 namespace dba {
@@ -224,7 +223,7 @@ void Rescan::prepare() {
                                     Precondition_checker::k_min_cs_version;
 
   // Validate the usage of the option 'updateViewChangeUuid'
-  if (m_options.update_view_change_uuid.get_safe() &&
+  if (m_options.update_view_change_uuid.value_or(false) &&
       !m_is_view_change_uuid_supported) {
     throw shcore::Exception::argument_error(
         "The Cluster cannot be configured to use "
@@ -236,7 +235,7 @@ void Rescan::check_mismatched_hostnames_addresses(
     shcore::Array_t instances) const {
   m_cluster->execute_in_members(
       [&instances](const std::shared_ptr<Instance> &instance,
-                   const Instance_md_and_gr_member &info) {
+                   const Cluster_impl::Instance_md_and_gr_member &info) {
         // skip members that are already in the update list
         for (const auto &i : *instances) {
           if (i.as_map()->get_string("member_id") == instance->get_uuid())
@@ -324,9 +323,8 @@ void Rescan::check_mismatched_hostnames_addresses(
 
         return true;
       },
-      [](const shcore::Error &, const Instance_md_and_gr_member &) {
-        return true;
-      });
+      [](const shcore::Error &,
+         const Cluster_impl::Instance_md_and_gr_member &) { return true; });
 }
 
 shcore::Value::Map_type_ref Rescan::get_rescan_report() const {
@@ -429,16 +427,17 @@ shcore::Value::Map_type_ref Rescan::get_rescan_report() const {
 
   // Get the primary UUID value to determine GR mode:
   // UUID (not empty) -> single-primary or "" (empty) -> multi-primary
-  std::string gr_primary_uuid = mysqlshdk::gr::get_group_primary_uuid(
-      *m_cluster->get_cluster_server(), nullptr);
+  bool single_primary;
+  mysqlshdk::gr::get_group_primary_uuid(*m_cluster->get_cluster_server(),
+                                        &single_primary);
 
   // Check if the topology mode match and report needed change in the metadata.
-  if (gr_primary_uuid.empty() &&
+  if (!single_primary &&
       metadata_topology_mode == mysqlshdk::gr::Topology_mode::SINGLE_PRIMARY) {
     // Topology mode need to be changed to multi-primary on the metadata.
     (*cluster_map)["newTopologyMode"] = shcore::Value(
         mysqlshdk::gr::to_string(mysqlshdk::gr::Topology_mode::MULTI_PRIMARY));
-  } else if (!gr_primary_uuid.empty() &&
+  } else if (single_primary &&
              metadata_topology_mode ==
                  mysqlshdk::gr::Topology_mode::MULTI_PRIMARY) {
     // Topology mode need to be changed to single-primary on the metadata.
@@ -882,7 +881,7 @@ void Rescan::ensure_transaction_size_limit_consistency() {
   m_cluster->execute_in_members(
       [cluster_transaction_size_limit](
           const std::shared_ptr<Instance> &instance,
-          const Instance_md_and_gr_member &info) {
+          const Cluster_impl::Instance_md_and_gr_member &info) {
         if (info.second.state != mysqlshdk::gr::Member_state::RECOVERING &&
             info.second.state != mysqlshdk::gr::Member_state::UNREACHABLE) {
           // Get the instance's value for transaction_size_limit
@@ -916,75 +915,90 @@ void Rescan::ensure_transaction_size_limit_consistency() {
         }
         return true;
       },
-      [](const shcore::Error &, const Instance_md_and_gr_member &) {
-        return true;
-      });
+      [](const shcore::Error &,
+         const Cluster_impl::Instance_md_and_gr_member &) { return true; });
 }
 
 void Rescan::ensure_recovery_accounts_match() {
   m_cluster->execute_in_members(
       [this](const std::shared_ptr<Instance> &instance,
-             const Instance_md_and_gr_member &info) {
-        if (info.second.state != mysqlshdk::gr::Member_state::RECOVERING &&
-            info.second.state != mysqlshdk::gr::Member_state::UNREACHABLE) {
-          // Get the instance's recovery account
-          std::string recovery_user;
-          std::vector<std::string> recovery_user_hosts;
-          std::tie(recovery_user, recovery_user_hosts, std::ignore) =
-              m_cluster->get_replication_user(*instance);
-
-          // Check if the account is using the old prefix
-          bool old_prefix = false;
-          if (shcore::str_beginswith(
-                  recovery_user,
-                  mysqlshdk::gr::k_group_recovery_old_user_prefix)) {
-            old_prefix = true;
-          }
-
-          // Generate the recovery account string for this instance
-          std::string recovery_user_generated =
-              Cluster_impl::make_replication_user_name(
-                  instance->get_server_id(),
-                  old_prefix ? mysqlshdk::gr::k_group_recovery_old_user_prefix
-                             : mysqlshdk::gr::k_group_recovery_user_prefix);
-
-          // If the recovery user being used is different than the generated
-          // one it means the instance was added using clone as the recovery
-          // method and waitRecovery set to zero so the AdminAPI couldn't
-          // handle the fact that clone copies everything including
-          // mysql.slave_master_info where the replication credentials for the
-          // recovery channel are stored
-          if (recovery_user != recovery_user_generated) {
-            // Ensure the user exists first
-            if (!m_cluster->get_primary_master()->user_exists(
-                    recovery_user_generated, recovery_user_hosts.front())) {
-              log_debug("Recovery account '%s' does not exist in the cluster",
-                        recovery_user_generated.c_str());
-              return true;
-            }
-
-            mysqlsh::current_console()->print_info(shcore::str_format(
-                "Fixing incorrect recovery account '%s' in instance '%s'",
-                recovery_user.c_str(), instance->descr().c_str()));
-
-            // Generate and set a new password and update the replication
-            // credentials
-            m_cluster->reset_recovery_password(
-                instance, recovery_user_generated, recovery_user_hosts);
-
-            // Update the recovery account to the right one
-            log_info("Updating recovery account in metadata");
-            m_cluster->get_metadata_storage()->update_instance_repl_account(
-                instance->get_uuid(), Cluster_type::GROUP_REPLICATION,
-                Replica_type::GROUP_MEMBER, recovery_user_generated,
-                recovery_user_hosts.front());
-          }
+             const Cluster_impl::Instance_md_and_gr_member &info) {
+        switch (info.second.state) {
+          case mysqlshdk::gr::Member_state::RECOVERING:
+          case mysqlshdk::gr::Member_state::UNREACHABLE:
+            return true;
+          default:
+            break;
         }
+
+        // Get the instance's recovery account
+        std::string recovery_user;
+        std::vector<std::string> recovery_user_hosts;
+        std::tie(recovery_user, recovery_user_hosts, std::ignore) =
+            m_cluster->get_replication_user(*instance);
+
+        // Check if the account is using the old prefix
+        auto old_prefix = shcore::str_beginswith(
+            recovery_user, mysqlshdk::gr::k_group_recovery_old_user_prefix);
+
+        // Generate the recovery account string for this instance
+        auto recovery_user_generated = Cluster_impl::make_replication_user_name(
+            instance->get_server_id(),
+            old_prefix ? mysqlshdk::gr::k_group_recovery_old_user_prefix
+                       : mysqlshdk::gr::k_group_recovery_user_prefix);
+
+        // If the recovery user being used is different than the generated one
+        // it means the instance was added using clone as the recovery method
+        // and waitRecovery set to zero so the AdminAPI couldn't handle the fact
+        // that clone copies everything including mysql.slave_master_info where
+        // the replication credentials for the recovery channel are stored. Or
+        // if the recovery user has changed / created explicitly by the user.
+        if (recovery_user == recovery_user_generated) return true;
+
+        auto console = mysqlsh::current_console();
+        console->print_info(shcore::str_format(
+            "Fixing incorrect recovery account '%s' in instance '%s'",
+            recovery_user.c_str(), instance->descr().c_str()));
+
+        if (!m_cluster->get_primary_master()->user_exists(
+                recovery_user_generated, recovery_user_hosts.front())) {
+          log_info("Recovery account '%s' does not exist in the cluster.",
+                   recovery_user_generated.c_str());
+
+          recovery_user_generated = Cluster_impl::make_replication_user_name(
+              instance->get_server_id(),
+              mysqlshdk::gr::k_group_recovery_user_prefix);
+
+          auto [new_user, new_host] = m_cluster->recreate_replication_user(
+              instance,
+              m_cluster->query_cluster_instance_auth_cert_subject(*instance));
+
+          m_cluster->get_metadata_storage()->update_instance_repl_account(
+              instance->get_uuid(), Cluster_type::GROUP_REPLICATION,
+              Replica_type::GROUP_MEMBER, new_user, new_host);
+
+          console->print_warning(shcore::str_format(
+              "A new recovery user for instance '%s' was created, which leaves "
+              "the previous user, '%s', unused, so it should be removed.",
+              instance->descr().c_str(), recovery_user.c_str()));
+
+        } else {
+          log_info("Updating recovery account '%s' in metadata.",
+                   recovery_user_generated.c_str());
+
+          m_cluster->reset_recovery_password(instance, recovery_user_generated,
+                                             recovery_user_hosts);
+
+          m_cluster->get_metadata_storage()->update_instance_repl_account(
+              instance->get_uuid(), Cluster_type::GROUP_REPLICATION,
+              Replica_type::GROUP_MEMBER, recovery_user_generated,
+              recovery_user_hosts.front());
+        }
+
         return true;
       },
-      [](const shcore::Error &, const Instance_md_and_gr_member &) {
-        return true;
-      });
+      [](const shcore::Error &,
+         const Cluster_impl::Instance_md_and_gr_member &) { return true; });
 }
 
 shcore::Value Rescan::execute() {
@@ -1005,7 +1019,7 @@ shcore::Value Rescan::execute() {
   }
 
   // Print warning about not used instances in addInstances.
-  {
+  if (!m_options.add_instances_list.empty()) {
     std::vector<std::string> not_used_add_instances;
     not_used_add_instances.reserve(m_options.add_instances_list.size());
 
@@ -1025,12 +1039,8 @@ shcore::Value Rescan::execute() {
   }
 
   // Check if there are missing instances
-  std::shared_ptr<shcore::Value::Array_type> missing_instances;
-
   if (result->has_key("unavailableInstances")) {
-    missing_instances = result->get_array("unavailableInstances");
-
-    remove_metadata_for_instances(missing_instances);
+    remove_metadata_for_instances(result->get_array("unavailableInstances"));
   }
 
   if (result->has_key("updatedInstances")) {
@@ -1038,7 +1048,7 @@ shcore::Value Rescan::execute() {
   }
 
   // Fix all missing recovery accounts from metadata.
-  m_cluster->ensure_metadata_has_recovery_accounts();
+  m_cluster->ensure_metadata_has_recovery_accounts(true);
 
   // This calls ensures all of the instances have server_id as instance
   // attribute, including the case were rescan is executed and no new/updated
@@ -1048,13 +1058,16 @@ shcore::Value Rescan::execute() {
   // Check if group_replication_view_change_uuid is set on the Cluster and all
   // of its members when running MySQL >= 8.0.27. Also verify the Metadata
   // consistency regarding group_replication_view_change_uuid when already in
-  // use
+  // use.
+  // Skip if running MySQL >= 8.3.0, since the option is no longer needed.
   if (m_is_view_change_uuid_supported) {
     auto view_change_uuid = m_cluster->get_primary_master()->get_sysvar_string(
         "group_replication_view_change_uuid", "");
 
     if (view_change_uuid == "AUTOMATIC") {
-      if (m_options.update_view_change_uuid.is_null()) {
+      if (!m_options.update_view_change_uuid.has_value() &&
+          m_cluster->get_lowest_instance_version() <
+              k_view_change_uuid_deprecated) {
         console->print_note(
             "The Cluster is not configured to use "
             "'group_replication_view_change_uuid', which is required "
@@ -1073,7 +1086,7 @@ shcore::Value Rescan::execute() {
               "Use the 'updateViewChangeUuid' option to generate and "
               "configure a value for the Cluster.");
         }
-      } else if (m_options.update_view_change_uuid.get_safe()) {
+      } else if (m_options.update_view_change_uuid.value_or(false)) {
         ensure_view_change_uuid_set();
       }
     } else {
@@ -1091,7 +1104,7 @@ shcore::Value Rescan::execute() {
   ensure_transaction_size_limit_consistency();
 
   // Print warning about not used instances in removeInstances.
-  {
+  if (!m_options.remove_instances_list.empty()) {
     std::vector<std::string> not_used_remove_instances;
     not_used_remove_instances.reserve(m_options.remove_instances_list.size());
 
@@ -1116,7 +1129,7 @@ shcore::Value Rescan::execute() {
   //       the auto-increment settings on all of them.
   if (result->has_key("newTopologyMode") &&
       !result->is_null("newTopologyMode")) {
-    std::string new_topology_mode = result->get_string("newTopologyMode");
+    auto new_topology_mode = result->get_string("newTopologyMode");
 
     if (!new_topology_mode.empty()) {
       console->print_note("The topology mode of the cluster changed to '" +
