@@ -1558,10 +1558,9 @@ shcore::Dictionary_t Status::get_topology(
         if (*m_extended >= 1) {
           fence_sysvars = instance->get_fence_sysvars();
 
-          auto workers = parallel_applier_options.replica_parallel_workers;
-
-          if (parallel_applier_options.replica_parallel_workers.value_or(0) >
-              0) {
+          const auto &workers =
+              parallel_applier_options.replica_parallel_workers;
+          if (workers.value_or(0) > 0) {
             (*member)["applierWorkerThreads"] = shcore::Value(*workers);
           }
         }
@@ -1582,9 +1581,10 @@ shcore::Dictionary_t Status::get_topology(
           m_cluster->get_metadata_storage()->query_instance_attribute(
               instance->get_uuid(), k_instance_attribute_join_time, &join_time);
 
-          std::tie(status, recovery_info) = recovery_status(
-              *instance,
-              join_time.type == shcore::String ? join_time.as_string() : "");
+          std::tie(status, recovery_info) =
+              recovery_status(*instance, join_time.get_type() == shcore::String
+                                             ? join_time.as_string()
+                                             : "");
           if (!status.empty()) {
             (*member)["recoveryStatusText"] = shcore::Value(status);
           }
@@ -2152,7 +2152,7 @@ shcore::Dictionary_t Status::feed_read_replica_info(const Read_replica_info &rr,
       if (m_cluster->get_metadata_storage()->query_instance_attribute(
               rr.md.uuid, k_instance_attribute_read_replica_replication_sources,
               &source_attribute)) {
-        if (source_attribute.type == shcore::String) {
+        if (source_attribute.get_type() == shcore::String) {
           source_list->push_back(shcore::Value(source_attribute.as_string()));
         }
       }
@@ -2185,7 +2185,7 @@ shcore::Dictionary_t Status::feed_read_replica_info(const Read_replica_info &rr,
           *(m_cluster->get_metadata_storage()->get_md_server()),
           "Binlog Dump GTID", instance_repl_account_user, "Ssl%",
           [&ssl_cipher, &ssl_version](const std::string &var_name,
-                                      const std::string &var_value) {
+                                      std::string var_value) {
             if (var_name == "Ssl_cipher") {
               ssl_cipher = std::move(var_value);
             } else if (var_name == "Ssl_version") {
