@@ -23,10 +23,7 @@
 
 #include "modules/adminapi/common/base_cluster_impl.h"
 
-#include <iomanip>
-#include <iostream>
 #include <memory>
-#include <sstream>
 #include <string>
 #include <vector>
 
@@ -45,18 +42,12 @@
 #include "modules/adminapi/common/router.h"
 #include "modules/adminapi/common/server_features.h"
 #include "modules/adminapi/common/setup_account.h"
-#include "modules/adminapi/common/sql.h"
-#include "modules/mod_shell.h"
-#include "modules/mysqlxtest_utils.h"
 #include "mysqlshdk/include/shellcore/console.h"
-#include "mysqlshdk/include/shellcore/utils_help.h"
-#include "mysqlshdk/libs/mysql/async_replication.h"
 #include "mysqlshdk/libs/mysql/group_replication.h"
 #include "mysqlshdk/libs/mysql/replication.h"
 #include "mysqlshdk/libs/mysql/utils.h"
 #include "mysqlshdk/libs/utils/debug.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
-#include "mysqlshdk/libs/utils/utils_mysql_parsing.h"
 #include "mysqlshdk/libs/utils/utils_net.h"
 #include "mysqlshdk/libs/utils/version.h"
 
@@ -878,21 +869,19 @@ void Base_cluster_impl::setup_router_account(
   setup_account_common(username, host, options, Setup_account_type::ROUTER);
 }
 
-void Base_cluster_impl::remove_router_metadata(const std::string &router,
-                                               bool lock_metadata) {
+void Base_cluster_impl::remove_router_metadata(const std::string &router) {
   check_preconditions("removeRouterMetadata");
 
   auto c_lock = get_lock_shared();
 
-  /*
-   * The metadata lock is currently only used in ReplicaSet, and only until it's
-   * removed (deprecated because we use DB transactions). At that time, all
-   * metadata locks will be removed, along with this parameter.
-   */
-  if (!get_metadata_storage()->remove_router(router, lock_metadata)) {
+  MetadataStorage::Transaction trx(get_metadata_storage());
+
+  if (!get_metadata_storage()->remove_router(router)) {
     throw shcore::Exception::argument_error("Invalid router instance '" +
                                             router + "'");
   }
+
+  trx.commit();
 }
 
 void Base_cluster_impl::set_instance_tag(const std::string &instance_def,
@@ -1007,7 +996,7 @@ std::string Base_cluster_impl::query_cluster_auth_cert_issuer() const {
   if (shcore::Value value;
       get_metadata_storage()->query_cluster_attribute(
           get_id(), k_cluster_attribute_cert_issuer, &value) &&
-      (value.type == shcore::String))
+      (value.get_type() == shcore::String))
     return value.as_string();
 
   return {};
@@ -1018,7 +1007,7 @@ std::string Base_cluster_impl::query_cluster_instance_auth_cert_subject(
   if (shcore::Value value;
       get_metadata_storage()->query_instance_attribute(
           instance_uuid, k_instance_attribute_cert_subject, &value) &&
-      (value.type == shcore::String))
+      (value.get_type() == shcore::String))
     return value.as_string();
 
   return {};
@@ -1067,7 +1056,7 @@ Base_cluster_impl::validate_set_option_namespace(
     }
     // If the type of the value is not Null, check that it can be
     // converted to the expected type
-    if (value.type != shcore::Value_type::Null) {
+    if (value.get_type() != shcore::Value_type::Null) {
       try {
         switch (c_it->second) {
           case shcore::Value_type::Bool:
@@ -1085,7 +1074,7 @@ Base_cluster_impl::validate_set_option_namespace(
         throw shcore::Exception::type_error(shcore::str_format(
             "Built-in tag '%s' is expected to be of type %s, but is %s",
             c_it->first.c_str(), type_name(c_it->second).c_str(),
-            type_name(value.type).c_str()));
+            type_name(value.get_type()).c_str()));
       }
     }
   }
