@@ -261,6 +261,8 @@ inline constexpr const char kForce[] = "force";
 inline constexpr const char kAdoptFromGR[] = "adoptFromGR";
 inline constexpr const char kAddInstances[] = "addInstances";
 inline constexpr const char kRemoveInstances[] = "removeInstances";
+inline constexpr const char kAddUnmanaged[] = "addUnmanaged";
+inline constexpr const char kRemoveObsolete[] = "removeObsolete";
 inline constexpr const char kRejoinInstances[] = "rejoinInstances";
 inline constexpr const char kWaitRecovery[] = "waitRecovery";
 inline constexpr const char kRecoveryProgress[] = "recoveryProgress";
@@ -802,8 +804,6 @@ void ensure_instance_check_installed_schema_version(
     const std::shared_ptr<mysqlsh::dba::Instance> &target_instance,
     mysqlshdk::utils::Version lowest_cluster_version);
 
-void log_used_gr_options(const Group_replication_options &gr_options);
-
 /**
  * Validate the use of IPv6 addresses on the localAddress of the
  * target instance and check if the target instance supports usage of
