@@ -31,13 +31,11 @@
 #include "modules/adminapi/common/dba_errors.h"
 #include "modules/adminapi/common/metadata_storage.h"
 #include "modules/adminapi/common/provision.h"
-#include "modules/adminapi/common/sql.h"
-#include "modules/adminapi/mod_dba.h"
 #include "mysqlshdk/include/shellcore/console.h"
-#include "mysqlshdk/libs/config/config_server_handler.h"
 #include "mysqlshdk/libs/mysql/replication.h"
 #include "mysqlshdk/libs/textui/textui.h"
 #include "mysqlshdk/libs/utils/utils_net.h"
+#include "mysqlshdk/libs/utils/utils_string.h"
 #include "mysqlshdk/libs/utils/version.h"
 
 // Naming convention for validations:
@@ -464,7 +462,7 @@ std::vector<mysqlshdk::mysql::Invalid_config> validate_configuration(
       (*error)["option"] = shcore::Value(cfg.var_name);
       process_row_values(cfg, error);
       process_row_action(cfg, error, action);
-      if (!cfg.persisted_val.is_null()) {
+      if (cfg.persisted_val.has_value()) {
         (*error)["persisted"] = shcore::Value(*cfg.persisted_val);
       }
       config_errors->push_back(shcore::Value(std::move(error)));
@@ -530,7 +528,7 @@ void validate_performance_schema_enabled(
 void ensure_instance_not_belong_to_cluster(
     const std::shared_ptr<Instance> &instance,
     const std::shared_ptr<Instance> &cluster_instance,
-    const std::string &cluster_id) {
+    std::string_view cluster_id, bool omit_missing_instance_warn) {
   auto metadata = std::make_shared<MetadataStorage>(instance);
   auto type = mysqlsh::dba::get_instance_type(*metadata, *instance);
 
@@ -538,14 +536,38 @@ void ensure_instance_not_belong_to_cluster(
     // these types don't need any more checks
     case TargetType::Standalone:
     case TargetType::StandaloneWithMetadata:
-    case TargetType::StandaloneInMetadata:
     case TargetType::AsyncReplication:
       return;
     default:
       break;
   }
 
-  if (type != TargetType::InnoDBClusterSetOffline) {
+  if (type == TargetType::StandaloneInMetadata) {
+    // Check if the instance is (MISSING)
+    try {
+      // Double-check that the instance is part of this Cluster
+      auto metadata_cluster =
+          std::make_shared<MetadataStorage>(cluster_instance);
+
+      metadata_cluster->get_instance_by_uuid(instance->get_uuid());
+
+      if (!omit_missing_instance_warn)
+        current_console()->print_error(
+            shcore::str_format("Instance '%s' is already part of this InnoDB "
+                               "Cluster but is (MISSING). Please use "
+                               "<Cluster>.<<<rejoinInstance()>>> to rejoin it.",
+                               instance->descr().c_str()));
+
+      throw shcore::Exception("The instance '" + instance->descr() +
+                                  "' is already part of this InnoDB Cluster",
+                              SHERR_DBA_BADARG_INSTANCE_MANAGED_IN_CLUSTER);
+    } catch (const shcore::Exception &exp) {
+      if (exp.code() != SHERR_DBA_MEMBER_METADATA_MISSING) throw;
+      // If not part of the Metadata it can be considered a standalone
+      // instance (might have been forcefully removed)
+      return;
+    }
+  } else if (type != TargetType::InnoDBClusterSetOffline) {
     // Retrieves the new instance UUID
     std::string uuid = instance->get_uuid();
 
