@@ -24,7 +24,11 @@
 #ifndef MODULES_ADMINAPI_COMMON_SERVER_FEATURES_H_
 #define MODULES_ADMINAPI_COMMON_SERVER_FEATURES_H_
 
-#include "mysqlshdk/libs/mysql/instance.h"
+#include "mysqlshdk/libs/utils/version.h"
+
+namespace mysqlshdk::mysql {
+class IInstance;
+}
 
 namespace mysqlsh::dba {
 
@@ -39,6 +43,13 @@ inline const mysqlshdk::utils::Version
 inline const mysqlshdk::utils::Version k_paxos_single_leader_initial_version(
     8, 0, 31);
 
+inline const mysqlshdk::utils::Version k_view_change_uuid_deprecated(8, 3, 0);
+
+inline const mysqlshdk::utils::Version
+    k_transaction_writeset_extraction_removed(8, 3, 0);
+
+inline const mysqlshdk::utils::Version k_replica_parallel_type_removed(8, 3, 0);
+
 // Feature getters
 
 std::string get_communication_stack(
@@ -65,6 +76,8 @@ bool supports_repl_channel_compression(
 bool supports_repl_channel_network_namespace(
     const mysqlshdk::utils::Version &version);
 
+bool supports_gtid_tags(const mysqlshdk::utils::Version &version);
+
 }  // namespace mysqlsh::dba
 
 #endif  // MODULES_ADMINAPI_COMMON_SERVER_FEATURES_H_
