@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2021, 2024, Oracle and/or its affiliates.
+ * Copyright (c) 2021, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -128,7 +126,7 @@ const shcore::Option_pack_def<Configure_instance_options>
 
 void Configure_instance_options::set_password_expiration(
     const shcore::Value &value) {
-  switch (value.type) {
+  switch (value.get_type()) {
     case shcore::Null:
       cluster_admin_password_expiration.reset();
       break;
@@ -162,7 +160,7 @@ void Configure_instance_options::set_password_expiration(
       throw shcore::Exception::type_error(
           std::string("Option '") + kPasswordExpiration +
           "' UInteger, 'NEVER' or 'DEFAULT' expected, but value is " +
-          type_name(value.type));
+          type_name(value.get_type()));
   }
 }
 
@@ -215,6 +213,11 @@ Configure_cluster_instance_options::Configure_cluster_instance_options()
 
 void Configure_cluster_instance_options::set_replica_parallel_workers(
     int64_t value) {
+  if (value < 0)
+    throw shcore::Exception::argument_error(shcore::str_format(
+        "Invalid value for '%s' option: it only accepts positive integers.",
+        kApplierWorkerThreads));
+
   replica_parallel_workers = value;
 }
 
@@ -237,6 +240,11 @@ Configure_replicaset_instance_options::Configure_replicaset_instance_options()
 
 void Configure_replicaset_instance_options::set_replica_parallel_workers(
     int64_t value) {
+  if (value < 0)
+    throw shcore::Exception::argument_error(shcore::str_format(
+        "Invalid value for '%s' option: it only accepts positive integers.",
+        kApplierWorkerThreads));
+
   replica_parallel_workers = value;
 }
 
