@@ -45,14 +45,15 @@
 #include "modules/adminapi/dba_utils.h"
 #include "modules/adminapi/mod_dba_cluster.h"
 #include "mysqlshdk/include/scripting/types.h"
+#include "mysqlshdk/libs/config/config_server_handler.h"
 #include "mysqlshdk/libs/mysql/async_replication.h"
 #include "mysqlshdk/libs/mysql/clone.h"
 #include "mysqlshdk/libs/mysql/group_replication.h"
 #include "mysqlshdk/libs/mysql/replication.h"
 #include "mysqlshdk/libs/mysql/utils.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
-#include "mysqlshdk/libs/utils/utils_net.h"
-#include "mysqlshdk/shellcore/shell_console.h"
+#include "utils/debug.h"
+#include "utils/version.h"
 
 namespace mysqlsh {
 namespace dba {
@@ -175,7 +176,7 @@ void Create_cluster::validate_create_cluster_options() {
   // Set multi-primary to false by default.
   if (!m_options.multi_primary) m_options.multi_primary = false;
 
-  if (*m_options.multi_primary && !m_options.force.get_safe()) {
+  if (*m_options.multi_primary && !m_options.force.value_or(false)) {
     if (m_options.interactive()) {
       console->print_para(
           "The MySQL InnoDB Cluster is going to be setup in advanced "
@@ -285,7 +286,7 @@ void Create_cluster::prepare() {
 
   // Verify if the instance is running asynchronous
   // replication. Skip if 'force' is enabled.
-  if (!m_options.force.get_safe()) {
+  if (!m_options.force.value_or(false)) {
     validate_async_channels(*m_target_instance, {}, checks::Check_type::CREATE);
   } else {
     log_debug(
@@ -414,9 +415,12 @@ void Create_cluster::prepare() {
         m_options.gr_options.group_name = m_target_instance->generate_uuid();
       }
 
-      // Generate the GR view-change UUID
-      if (m_target_instance->get_version() >=
-          Precondition_checker::k_min_cs_version) {
+      // Generate the GR view-change UUID if the target instance version is
+      // >= 8.0.27 and < 8.3.0
+      auto target_instance_version = m_target_instance->get_version();
+
+      if (target_instance_version >= Precondition_checker::k_min_cs_version &&
+          target_instance_version < k_view_change_uuid_deprecated) {
         m_options.gr_options.view_change_uuid =
             m_target_instance->generate_uuid();
       }
@@ -426,10 +430,11 @@ void Create_cluster::prepare() {
     if (m_options.get_adopt_from_gr()) {
       // Get the primary UUID value to determine GR mode:
       // UUID (not empty) -> single-primary or "" (empty) -> multi-primary
-      std::string gr_primary_uuid =
-          mysqlshdk::gr::get_group_primary_uuid(*m_target_instance, nullptr);
+      bool single_primary;
+      mysqlshdk::gr::get_group_primary_uuid(*m_target_instance,
+                                            &single_primary);
 
-      m_options.multi_primary = gr_primary_uuid.empty();
+      m_options.multi_primary = !single_primary;
     } else {
       // Set the internal configuration object: read/write configs from the
       // server.
@@ -464,74 +469,6 @@ void Create_cluster::prepare() {
   }
 }
 
-void Create_cluster::log_used_gr_options() {
-  auto console = mysqlsh::current_console();
-
-  log_info("Using Group Replication single primary mode: %s",
-           *m_options.multi_primary ? "FALSE" : "TRUE");
-
-  if (m_options.gr_options.ssl_mode != Cluster_ssl_mode::NONE) {
-    log_info("Using Group Replication SSL mode: %s",
-             to_string(m_options.gr_options.ssl_mode).c_str());
-  }
-
-  if (m_options.gr_options.group_name.has_value()) {
-    log_info("Using Group Replication group name: %s",
-             m_options.gr_options.group_name->c_str());
-  }
-
-  if (m_options.gr_options.local_address.has_value()) {
-    log_info("Using Group Replication local address: %s",
-             m_options.gr_options.local_address->c_str());
-  }
-
-  if (m_options.gr_options.group_seeds.has_value()) {
-    log_info("Using Group Replication group seeds: %s",
-             m_options.gr_options.group_seeds->c_str());
-  }
-
-  if (m_options.gr_options.exit_state_action.has_value()) {
-    log_info("Using Group Replication exit state action: %s",
-             m_options.gr_options.exit_state_action->c_str());
-  }
-
-  if (m_options.gr_options.member_weight.has_value()) {
-    log_info("Using Group Replication member weight: %s",
-             std::to_string(*m_options.gr_options.member_weight).c_str());
-  }
-
-  if (m_options.gr_options.consistency.has_value()) {
-    log_info("Using Group Replication failover consistency: %s",
-             m_options.gr_options.consistency->c_str());
-  }
-
-  if (m_options.gr_options.expel_timeout.has_value()) {
-    log_info("Using Group Replication expel timeout: %s",
-             std::to_string(*m_options.gr_options.expel_timeout).c_str());
-  }
-
-  if (m_options.gr_options.auto_rejoin_tries.has_value()) {
-    log_info("Using Group Replication auto-rejoin tries: %s",
-             std::to_string(*m_options.gr_options.auto_rejoin_tries).c_str());
-  }
-
-  if (m_options.gr_options.communication_stack.has_value()) {
-    log_info("Using Group Replication Communication Stack: %s",
-             m_options.gr_options.communication_stack->c_str());
-  }
-
-  if (m_options.gr_options.transaction_size_limit.has_value()) {
-    log_info(
-        "Using Group Replication transaction size limit: %s",
-        std::to_string(*m_options.gr_options.transaction_size_limit).c_str());
-  }
-
-  if (m_options.gr_options.paxos_single_leader.has_value()) {
-    log_info("Using Group Replication Paxos Single Leader: %s",
-             m_options.gr_options.paxos_single_leader.value() ? "ON" : "OFF");
-  }
-}
-
 void Create_cluster::prepare_metadata_schema() {
   // Ensure that the metadata schema is ready for creating a new cluster in it
   // If the metadata schema does not exist, we create it
@@ -655,7 +592,7 @@ void Create_cluster::store_recovery_account_metadata(
   if (cluster.get_metadata_storage()->query_cluster_attribute(
           cluster.get_id(), k_cluster_attribute_replication_allowed_host,
           &allowed_host) &&
-      allowed_host.type == shcore::String &&
+      allowed_host.get_type() == shcore::String &&
       !allowed_host.as_string().empty()) {
     repl_account_host = allowed_host.as_string();
   }
@@ -763,8 +700,6 @@ shcore::Value Create_cluster::execute() {
     log_info(
         "Adopting cluster from existing Group Replication and using its "
         "settings.");
-  } else {
-    log_used_gr_options();
   }
 
   // Make sure the GR plugin is installed (only installed if needed).
@@ -876,7 +811,7 @@ shcore::Value Create_cluster::execute() {
         }
 
         // Drop the recovery account if GR fails to start
-        undo_list.push_front([=]() {
+        undo_list.push_front([=, this]() {
           std::string repl_account_host =
               m_options.replication_allowed_host.empty()
                   ? "%"
@@ -912,6 +847,7 @@ shcore::Value Create_cluster::execute() {
         case mysqlsh::dba::Replication_auth_type::CERT_ISSUER_PASSWORD:
         case mysqlsh::dba::Replication_auth_type::CERT_SUBJECT_PASSWORD:
           requires_certificates = true;
+          break;
         default:
           break;
       }
@@ -1093,7 +1029,7 @@ shcore::Value Create_cluster::execute() {
                                 &repl_account);
 
         // Drop the recovery account if GR fails to start
-        undo_list.push_front([=]() {
+        undo_list.push_front([=, this]() {
           std::string repl_account_host =
               m_options.replication_allowed_host.empty()
                   ? "%"
@@ -1140,6 +1076,10 @@ shcore::Value Create_cluster::execute() {
       }
     }
 
+    DBUG_EXECUTE_IF("dba_revert_trigger_exception", {
+      throw shcore::Exception("Exception while creating the cluster.", 0);
+    });
+
     // Everything after this should not affect the result of the createCluster()
     // even if an exception is thrown.
     trx.commit();
@@ -1156,6 +1096,13 @@ shcore::Value Create_cluster::execute() {
 
       undo_list.call();
 
+      {
+        auto srv_cfg = dynamic_cast<mysqlshdk::config::Config_server_handler *>(
+            m_cfg->get_handler(mysqlshdk::config::k_dft_cfg_server_handler));
+
+        if (srv_cfg) srv_cfg->undo_changes();
+      }
+
       mysqlshdk::mysql::drop_indicator_tag(*m_target_instance,
                                            metadata::kClusterSetupIndicatorTag);
     } catch (const std::exception &e) {
