@@ -28,19 +28,17 @@
 
 #include "modules/adminapi/cluster/rejoin_instance.h"
 #include "modules/adminapi/common/async_topology.h"
-#include "modules/adminapi/common/cluster_topology_executor.h"
 #include "modules/adminapi/common/dba_errors.h"
 #include "modules/adminapi/common/preconditions.h"
 #include "modules/adminapi/common/provision.h"
 #include "modules/adminapi/common/server_features.h"
 #include "modules/adminapi/common/sql.h"
+#include "modules/adminapi/common/topology_executor.h"
 #include "modules/adminapi/common/validations.h"
-#include "modules/adminapi/mod_dba.h"
-#include "mysqlshdk/include/shellcore/utils_help.h"
+#include "modules/errors.h"
 #include "mysqlshdk/libs/mysql/async_replication.h"
 #include "mysqlshdk/libs/utils/utils_net.h"
 #include "mysqlshdk/libs/utils/utils_string.h"
-#include "mysqlshdk/shellcore/shell_console.h"
 
 namespace mysqlsh::dba {
 
@@ -231,14 +229,15 @@ void rejoin_instances(Cluster_impl *cluster_impl,
       bool ignore_cluster_set =
           removed_from_set || !cluster_impl->is_cluster_set_member();
 
-      Cluster_topology_executor<cluster::Rejoin_instance>{
+      Topology_executor<cluster::Rejoin_instance>{
           cluster_impl,       instance,
           rejoin_options,     options.switch_communication_stack.has_value(),
           ignore_cluster_set, true}
           .run();
 
     } catch (const shcore::Error &e) {
-      console->print_warning(instance->descr() + ": " + e.format());
+      console->print_warning(shcore::str_format(
+          "%s: %s", instance->descr().c_str(), e.format().c_str()));
       // TODO(miguel) Once WL#13535 is implemented and rejoin supports
       // clone, simplify the following note by telling the user to use
       // rejoinInstance. E.g: “%s’ could not be automatically rejoined.
@@ -732,7 +731,7 @@ void Reboot_cluster_from_complete_outage::reboot_seed(
     try {
       mysqlsh::dba::checks::ensure_instance_not_belong_to_cluster(
           m_target_instance, m_cluster->impl()->get_cluster_server(),
-          m_cluster->impl()->get_id());
+          m_cluster->impl()->get_id(), true);
     } catch (const shcore::Exception &exp) {
       m_already_member =
           (exp.code() == SHERR_DBA_ASYNC_MEMBER_INCONSISTENT) ||
@@ -769,9 +768,6 @@ void Reboot_cluster_from_complete_outage::reboot_seed(
   auto cfg = mysqlsh::dba::create_server_config(
       m_target_instance.get(), mysqlshdk::config::k_dft_cfg_server_handler);
 
-  // Common informative logging
-  cluster_topology_executor_ops::log_used_gr_options(m_options.gr_options);
-
   // If the Cluster is using the 'MySQL' communication stack, we cannot
   // guarantee that:
   //   - The recovery account exists and is configured at every Cluster
@@ -848,7 +844,7 @@ void Reboot_cluster_from_complete_outage::reboot_seed(
         m_cluster->impl()->get_metadata_storage()->query_cluster_set_attribute(
             m_cluster->impl()->get_id(),
             k_cluster_attribute_replication_allowed_host, &allowed_host) &&
-        allowed_host.type == shcore::String &&
+        allowed_host.get_type() == shcore::String &&
         !allowed_host.as_string().empty()) {
       repl_account_host = allowed_host.as_string();
     }
@@ -1174,7 +1170,7 @@ std::shared_ptr<Cluster> Reboot_cluster_from_complete_outage::do_run() {
 
   // pick the seed instance
   std::shared_ptr<Instance> best_instance_gtid;
-  {
+  try {
     best_instance_gtid =
         pick_best_instance_gtid(instances, m_cs_info.is_member,
                                 m_options.get_force(), m_options.get_primary());
@@ -1217,6 +1213,14 @@ std::shared_ptr<Cluster> Reboot_cluster_from_complete_outage::do_run() {
 
       instances.pop_back();
     }
+  } catch (const shcore::Error &e) {
+    if (e.code() != SHERR_UNSUPPORTED_GTID_TAG) throw;
+
+    console->print_error(
+        "A GTID set with tags was detected while verifying GTID compatibility "
+        "between Cluster instances. To use GTID tags, all members of the "
+        "Cluster must support them.");
+    throw;
   }
 
   // The 'force' option is a no-op in this scenario (instances aren't rejoined
