@@ -24,7 +24,6 @@
 #ifndef MODULES_ADMINAPI_DBA_REBOOT_CLUSTER_FROM_COMPLETE_OUTAGE_H_
 #define MODULES_ADMINAPI_DBA_REBOOT_CLUSTER_FROM_COMPLETE_OUTAGE_H_
 
-#include "modules/adminapi/common/undo.h"
 #include "modules/adminapi/mod_dba.h"
 
 namespace mysqlsh::dba {
@@ -59,6 +58,8 @@ class Reboot_cluster_from_complete_outage {
  protected:
   std::shared_ptr<Cluster> do_run();
 
+  static constexpr bool supports_undo() noexcept { return false; }
+
  private:
   /*
    * Retrieves info regarding the clusters ClusterSet (if any)
@@ -98,10 +99,6 @@ class Reboot_cluster_from_complete_outage {
    */
   void reboot_seed(const MetadataStorage &metadata);
 
- protected:
-  shcore::Scoped_callback_list m_undo_list;
-  Undo_tracker m_undo_tracker;
-
  private:
   Dba *m_dba;
   std::shared_ptr<Cluster> m_cluster;
