@@ -28,14 +28,13 @@
 #include <string>
 
 #include "db/utils_connection.h"
+
 #include "modules/adminapi/common/common.h"
 #include "modules/adminapi/mod_dba_cluster_set.h"
 #include "mysqlshdk/include/shellcore/utils_help.h"
 #include "mysqlshdk/libs/utils/debug.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
 
-using std::placeholders::_1;
-
 DEBUG_OBJ_ENABLE(Cluster);
 
 namespace mysqlsh {
@@ -222,7 +221,7 @@ incremental. Default is auto.
 recovery process to finish and its verbosity level. Deprecated.
 @li recoveryProgress: Integer value to indicate the recovery process verbosity
 level.
-@li password: the instance connection password
+@li password: the instance connection password. Deprecated.
 @li memberSslMode: SSL mode used on the instance
 ${CLUSTER_OPT_IP_WHITELIST}
 ${CLUSTER_OPT_IP_ALLOWLIST}
@@ -236,6 +235,10 @@ ${CLUSTER_OPT_MEMBER_WEIGHT}
 ${CLUSTER_OPT_AUTO_REJOIN_TRIES}
 ${OPT_CERT_SUBJECT}
 
+The label must be non-empty and no greater than 256 characters long. It must be
+unique within the Cluster and can only contain alphanumeric, _ (underscore),
+. (period), - (hyphen), or : (colon) characters.
+
 The password may be contained on the instance definition, however, it can be
 overwritten if it is specified on the options.
 
@@ -301,6 +304,8 @@ Please use the ipAllowlist option instead.
 Please use the recoveryProgress option instead.
 
 @attention The interactive option will be removed in a future release.
+
+@attention The password option will be removed in a future release.
 )*");
 
 /**
@@ -321,7 +326,7 @@ void Cluster::add_instance(
 
   auto instance_def = instance_def_;
 
-  if (!options->password.is_null()) {
+  if (options->password.has_value()) {
     instance_def.set_password(*(options->password));
   }
 
@@ -352,7 +357,7 @@ ${TOPIC_CONNECTION_MORE_INFO}
 
 The options dictionary may contain the following attributes:
 
-@li password: the instance connection password
+@li password: the instance connection password. Deprecated.
 @li recoveryMethod: Preferred method of state recovery. May be auto, clone or
 incremental. Default is auto.
 @li recoveryProgress: Integer value to indicate the recovery process verbosity
@@ -414,6 +419,8 @@ ${CLUSTER_OPT_LOCAL_ADDRESS_EXTRA}
 Please use the ipAllowlist option instead.
 
 @attention The interactive option will be removed in a future release.
+
+@attention The password option will be removed in a future release.
 )*");
 
 /**
@@ -435,7 +442,7 @@ void Cluster::rejoin_instance(
 
   auto instance_def = instance_def_;
 
-  if (!options->password.is_null()) {
+  if (options->password.has_value()) {
     instance_def.set_password(*(options->password));
   }
 
@@ -464,7 +471,7 @@ ${TOPIC_CONNECTION_MORE_INFO}
 
 The options dictionary may contain the following attributes:
 
-@li password: the instance connection password
+@li password: the instance connection password. Deprecated.
 @li force: boolean, indicating if the instance must be removed (even if only
 from metadata) in case it cannot be reached. By default, set to false.
 ${OPT_INTERACTIVE}
@@ -486,6 +493,8 @@ removed without the force option to avoid errors trying to add it back to a
 cluster.
 
 @attention The interactive option will be removed in a future release.
+
+@attention The password option will be removed in a future release.
 )*");
 
 /**
@@ -507,13 +516,10 @@ void Cluster::remove_instance(
 
   auto instance_def = instance_def_;
 
-  if (!options->password.is_null()) {
+  if (options->password.has_value()) {
     instance_def.set_password(*(options->password));
   }
 
-  // Throw an error if the cluster has already been dissolved
-  assert_valid("removeInstance");
-
   return execute_with_pool(
       [&]() {
         // Remove the Instance from the Cluster
@@ -524,23 +530,23 @@ void Cluster::remove_instance(
 
 REGISTER_HELP_FUNCTION(describe, Cluster);
 REGISTER_HELP_FUNCTION_TEXT(CLUSTER_DESCRIBE, R"*(
-Describe the structure of the cluster.
+Describe the structure of the Cluster.
 
-@returns A JSON object describing the structure of the cluster.
+@returns A JSON object describing the structure of the Cluster.
 
-This function describes the structure of the cluster including all its
-information, ReplicaSets and Instances.
+This function describes the structure of the Cluster including all its
+information and members.
 
 The returned JSON object contains the following attributes:
 
-@li clusterName: the cluster name
+@li clusterName: the name of the Cluster
 @li defaultReplicaSet: the default ReplicaSet object
 
 The defaultReplicaSet JSON object contains the following attributes:
 
-@li name: the ReplicaSet name
+@li name: the ReplicaSet name (default)
 @li topology: a list of dictionaries describing each instance belonging to the
-ReplicaSet.
+Cluster.
 @li topologyMode: the InnoDB Cluster topology mode.
 
 Each instance dictionary contains the following attributes:
@@ -548,7 +554,6 @@ Each instance dictionary contains the following attributes:
 @li address: the instance address in the form of host:port
 @li label: the instance name identifier
 @li role: the instance role
-@li version: the instance version (only available for instances >= 8.0.11)
 )*");
 
 /**
@@ -557,9 +562,9 @@ Each instance dictionary contains the following attributes:
  * $(CLUSTER_DESCRIBE)
  */
 #if DOXYGEN_JS
-String Cluster::describe() {}
+Dictionary Cluster::describe() {}
 #elif DOXYGEN_PY
-str Cluster::describe() {}
+dict Cluster::describe() {}
 #endif
 
 shcore::Value Cluster::describe(void) {
@@ -571,18 +576,18 @@ shcore::Value Cluster::describe(void) {
 
 REGISTER_HELP_FUNCTION(status, Cluster);
 REGISTER_HELP_FUNCTION_TEXT(CLUSTER_STATUS, R"*(
-Describe the status of the cluster.
+Describe the status of the Cluster.
 
 @param options Optional dictionary with options.
 
-@returns A JSON object describing the status of the cluster.
+@returns A JSON object describing the status of the Cluster.
 
-This function describes the status of the cluster including its ReplicaSets and
-Instances. The following options may be given to control the amount of
-information gathered and returned.
+This function describes the status of the Cluster and its members. The
+following options may be given to control the amount of information gathered
+and returned.
 
 @li extended: verbosity level of the command output.
-@li queryMembers: if true, connect to each Instance of the ReplicaSets to query
+@li queryMembers: if true, connect to each Instance of the Cluster to query
 for more detailed stats about the replication machinery.
 
 @attention The queryMembers option will be removed in a future release. Please
@@ -593,7 +598,7 @@ The extended option supports Integer or Boolean values:
 @li 0: disables the command verbosity (default);
 @li 1: includes information about the Metadata Version, Group Protocol
        Version, Group name, cluster member UUIDs, cluster member roles and
-       states as reported byGroup Replication and the list of fenced system
+       states as reported by Group Replication and the list of fenced system
        variables;
 @li 2: includes information about transactions processed by connection and
        applier;
@@ -717,15 +722,16 @@ void Cluster::dissolve(
 
 REGISTER_HELP_FUNCTION(resetRecoveryAccountsPassword, Cluster);
 REGISTER_HELP_FUNCTION_TEXT(CLUSTER_RESETRECOVERYACCOUNTSPASSWORD, R"*(
-Reset the password of the recovery accounts of the cluster.
+Resets the password of the recovery and replication accounts of the Cluster.
 
 @param options Dictionary with options for the operation.
 
 @returns Nothing.
 
 This function resets the passwords for all internal recovery user accounts
-used by the Cluster.
-It can be used to reset the passwords of the recovery user
+used by the Cluster as well as for all replication accounts used by any
+Read Replica instance.
+It can be used to reset the passwords of the recovery or replication user
 accounts when needed for any security reasons. For example:
 periodically to follow some custom password lifetime policy, or after
 some security breach event.
@@ -786,11 +792,11 @@ The options dictionary may contain the following attributes:
 
 @li addInstances: List with the connection data of the new active instances to
 add to the metadata, or "auto" to automatically add missing instances to the
-metadata.
+metadata. Deprecated.
 ${OPT_INTERACTIVE}
 @li removeInstances: List with the connection data of the obsolete instances to
 remove from the metadata, or "auto" to automatically remove obsolete instances
-from the metadata.
+from the metadata. Deprecated.
 @li updateTopologyMode: boolean value used to indicate if the topology mode
 (single-primary or multi-primary) in the metadata should be updated (true) or
 not (false) to match the one being used by the cluster. By default, the
@@ -799,7 +805,14 @@ metadata is not updated (false). Deprecated.
 communication protocol to the highest version possible.
 @li updateViewChangeUuid: boolean value used to indicate if the command should
 generate and set a value for Group Replication View Change UUID in the whole
-Cluster. Required for InnoDB ClusterSet usage.
+Cluster. Required for InnoDB ClusterSet usage (if running MySQL version lower
+than 8.3.0).
+@li addUnmanaged: set to true to automatically add newly discovered instances,
+i.e. already part of the replication topology but not managed in the Cluster,
+to the metadata. Defaults to false.
+@li removeObsolete: set to true to automatically remove all obsolete instances,
+i.e. no longer part of the replication topology, from the metadata. Defaults
+to false.
 
 The value for addInstances and removeInstances is used to specify which
 instances to add or remove from the metadata, respectively. Both options accept
@@ -810,6 +823,9 @@ without having to explicitly specify them.
 @attention The updateTopologyMode option will be removed in a future release.
 
 @attention The interactive option will be removed in a future release.
+
+@attention The addInstances and removeInstances options will be removed in a
+future release. Use addUnmanaged and removeObsolete instead.
 )*");
 
 /**
@@ -857,7 +873,7 @@ REGISTER_HELP_FUNCTION_TEXT(CLUSTER_FORCEQUORUMUSINGPARTITIONOF, R"*(
 Restores the cluster from quorum loss.
 
 @param instance An instance definition to derive the forced group from.
-@param password Optional string with the password for the connection.
+@param password Optional string with the password for the connection. Deprecated.
 
 @returns Nothing.
 
@@ -876,6 +892,8 @@ in the network, but not accessible from your location.
 
 When this function is used, all the members that are ONLINE from the point of
 view of the given instance definition will be added to the group.
+
+@attention The password option will be removed in a future release.
 )*");
 
 /**
@@ -910,8 +928,6 @@ void Cluster::force_quorum_using_partition_of(
     instance_def.set_port(mysqlshdk::db::k_default_mysql_port);
   }
 
-  instance_def.set_default_data();
-
   bool interactive = current_shell_options()->get().wizards;
 
   return execute_with_pool(
@@ -1149,6 +1165,11 @@ ${CLUSTER_OPT_REPLICATION_OPTION_ZSTD_COMPRESSION_LEVEL}
 ${CLUSTER_OPT_REPLICATION_OPTION_BIND}
 ${CLUSTER_OPT_REPLICATION_OPTION_NETWORK_NAMESPACE}
 
+The clusterName must be non-empty and no greater than 63 characters long. It
+can only start with an alphanumeric character or with _ (underscore), and can
+only contain alphanumeric, _ ( underscore), . (period), or - (hyphen)
+characters.
+
 @attention The failoverConsistency option will be removed in a future release.
 Please use the consistency option instead.
 
@@ -1242,6 +1263,10 @@ ${NAMESPACE_TAG_DETAIL_CLUSTER}
 
 ${NAMESPACE_TAG_INSTANCE_DETAILS_EXTRA}
 
+The label must be non-empty and no greater than 256 characters long. It must be
+unique within the Cluster and can only contain alphanumeric, _ (underscore),
+. (period), - (hyphen), or : (colon) characters.
+
 The replicationSources is a comma separated list of instances (host:port) to
 act as sources of the replication channel, i.e. to provide source failover of
 the channel. The first member of the list is configured with the highest
@@ -1438,7 +1463,7 @@ void Cluster::remove_router_metadata(const std::string &router_def) {
   assert_valid("removeRouterMetadata");
 
   return execute_with_pool(
-      [&]() { impl()->remove_router_metadata(router_def, true); }, false);
+      [&]() { impl()->remove_router_metadata(router_def); }, false);
 }
 
 REGISTER_HELP_FUNCTION(setupAdminAccount, Cluster);
@@ -1621,6 +1646,10 @@ The following is a non-exhaustive list of requirements to create a ClusterSet:
 @li The target cluster's Metadata schema version is 2.1.0 or newer.
 @li Unmanaged replication channels are not allowed.
 
+The domainName must be non-empty and no greater than 63 characters long. It can
+only start with an alphanumeric character or with _ (underscore), and can only
+contain alphanumeric, _ ( underscore), . (period), or - (hyphen) characters.
+
 <b>Options</b>
 
 The options dictionary can contain the following values:
@@ -1751,6 +1780,10 @@ established. If reached, the operation is rolled-back. Default is 0 (no
 timeout).
 ${CLUSTER_OPT_CLONE_DONOR}
 
+The label must be non-empty and no greater than 256 characters long. It must be
+unique within the Cluster and can only contain alphanumeric, _ (underscore),
+. (period), - (hyphen), or : (colon) characters.
+
 The replicationSources is a comma separated list of instances (host:port) to
 act as sources of the replication channel, i.e. to provide source failover of
 the channel. The first member of the list is configured with the highest
