@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2015, 2024, Oracle and/or its affiliates.
+ * Copyright (c) 2015, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -792,12 +790,12 @@ TableSelect TableSelect::offset(int numberOfRows) {}
 void TableSelect::set_lock_contention(const shcore::Argument_list &args) {
   std::string lock_contention;
   if (args.size() == 1) {
-    if (args[0].type == shcore::Object) {
+    if (args[0].get_type() == shcore::Object) {
       std::shared_ptr<Constant> constant =
           std::dynamic_pointer_cast<Constant>(args.object_at(0));
       if (constant && constant->group() == "LockContention")
         lock_contention = constant->data().get_string();
-    } else if (args[0].type == shcore::String) {
+    } else if (args[0].get_type() == shcore::String) {
       lock_contention = args.string_at(0);
     }
 
