@@ -26,10 +26,12 @@
 #include <mysqld_error.h>
 
 #include <algorithm>
+#include <iterator>
 #include <regex>
 #include <utility>
 
 #include "modules/mod_utils.h"
+#include "modules/util/common/dump/constants.h"
 #include "modules/util/common/dump/utils.h"
 #include "modules/util/dump/dump_manifest_config.h"
 #include "modules/util/load/load_errors.h"
@@ -50,11 +52,6 @@ namespace {
 
 using Version = mysqlshdk::utils::Version;
 
-const char *k_excluded_users[] = {"mysql.infoschema", "mysql.session",
-                                  "mysql.sys"};
-const char *k_oci_excluded_users[] = {"administrator", "ociadmin", "ocimonitor",
-                                      "ocirpl"};
-
 constexpr auto k_minimum_max_bytes_per_transaction = 4096;
 
 }  // namespace
@@ -119,6 +116,7 @@ const shcore::Option_pack_def<Load_dump_options> &Load_dump_options::options() {
           .optional("sessionInitSql", &Load_dump_options::m_session_init_sql)
           .optional("handleGrantErrors",
                     &Load_dump_options::set_handle_grant_errors)
+          .optional("checksum", &Load_dump_options::m_checksum)
           .include(&Load_dump_options::m_oci_bucket_options)
           .include(&Load_dump_options::m_s3_bucket_options)
           .include(&Load_dump_options::m_blob_storage_options)
@@ -245,10 +243,10 @@ void Load_dump_options::set_session(
 
   if (m_load_users) {
     // some users are always excluded
-    filters().users().exclude(k_excluded_users);
+    filters().users().exclude(dump::common::k_excluded_users);
 
     if (is_mds()) {
-      filters().users().exclude(k_oci_excluded_users);
+      filters().users().exclude(dump::common::k_mhs_excluded_users);
     }
 
     shcore::Account account;
@@ -258,6 +256,10 @@ void Load_dump_options::set_session(
     filters().users().exclude(std::move(account));
   }
 
+  if (is_mds()) {
+    filters().schemas().exclude(dump::common::k_mhs_excluded_schemas);
+  }
+
   if (m_target_server_version >= Version(8, 0, 27)) {
     // adding indexes in parallel was added in 8.0.27,
     // innodb_parallel_read_threads threads are used during the first stage,
@@ -314,7 +316,7 @@ void Load_dump_options::validate() {
       mysqlsh::current_console()->print_error(
           "The 'local_infile' global system variable must be set to ON in "
           "the target server, after the server is verified to be trusted.");
-      THROW_ERROR0(SHERR_LOAD_LOCAL_INFILE_DISABLED);
+      THROW_ERROR(SHERR_LOAD_LOCAL_INFILE_DISABLED);
     }
   }
 
@@ -343,30 +345,41 @@ std::string Load_dump_options::target_import_info(
 
   // this is validated earlier on
   assert(!what_to_load.empty() || m_analyze_tables != Analyze_table_mode::OFF ||
-         m_update_gtid_set != Update_gtid_set::OFF);
+         m_update_gtid_set != Update_gtid_set::OFF || m_checksum);
 
-  if (what_to_load.size() == 3) {
-    action = shcore::str_format(
-        "%s %s, %s and %s from %s", operation, what_to_load[0].c_str(),
-        what_to_load[1].c_str(), what_to_load[2].c_str(), where.c_str());
-  } else if (what_to_load.size() == 2) {
-    action = shcore::str_format("%s %s and %s from %s", operation,
-                                what_to_load[0].c_str(),
-                                what_to_load[1].c_str(), where.c_str());
-  } else if (!what_to_load.empty()) {
-    action = shcore::str_format("%s %s only from %s", operation,
-                                what_to_load[0].c_str(), where.c_str());
-  } else {
-    if (m_analyze_tables == Analyze_table_mode::HISTOGRAM)
-      action = "Updating table histograms";
-    else if (m_analyze_tables == Analyze_table_mode::ON)
-      action = "Updating table histograms and key distribution statistics";
-    if (m_update_gtid_set != Update_gtid_set::OFF) {
-      if (!action.empty())
-        action += ", and updating GTID_PURGED";
-      else
-        action = "Updating GTID_PURGED";
+  const auto concat = [&what_to_load]() {
+    if (1 == what_to_load.size()) {
+      return what_to_load[0] + " only";
     }
+
+    auto msg = shcore::str_join(what_to_load.begin(),
+                                std::prev(what_to_load.end()), ", ");
+    msg += " and ";
+    msg += what_to_load.back();
+
+    return msg;
+  };
+
+  if (!what_to_load.empty()) {
+    action = shcore::str_format("%s %s from %s", operation, concat().c_str(),
+                                where.c_str());
+  } else {
+    if (m_analyze_tables == Analyze_table_mode::HISTOGRAM) {
+      what_to_load.emplace_back("Updating table histograms");
+    } else if (m_analyze_tables == Analyze_table_mode::ON) {
+      what_to_load.emplace_back(
+          "Updating table histograms and key distribution statistics");
+    }
+
+    if (m_update_gtid_set != Update_gtid_set::OFF) {
+      what_to_load.emplace_back("Updating GTID_PURGED");
+    }
+
+    if (m_checksum) {
+      what_to_load.emplace_back("Verifying checksum information");
+    }
+
+    action = concat();
   }
 
   std::string detail = extra;
@@ -401,7 +414,7 @@ void Load_dump_options::on_unpacked_options() {
 
   if (!m_load_data && !m_load_ddl && !m_load_users &&
       m_analyze_tables == Analyze_table_mode::OFF &&
-      m_update_gtid_set == Update_gtid_set::OFF) {
+      m_update_gtid_set == Update_gtid_set::OFF && !m_checksum) {
     throw shcore::Exception::argument_error(
         "At least one of loadData, loadDdl or loadUsers options must be "
         "enabled");
