@@ -53,7 +53,16 @@ namespace {
 
 const Version ALL_VERSIONS("777.777.777");
 
-}
+// This map should be updated with the latest version of each series to enable
+// gatting the latest version available in case a partial version is provided
+// as the taget value, so for example, not needed when patch version is 0 in
+// the last version of a series
+static std::unordered_map<std::string, Version> latest_versions = {
+    {"8", Version(MYSH_VERSION)},  // If 8 is given, latest version
+                                   // is the current shell version
+    {"8.0", Version(LATEST_MYSH_80_VERSION)}};
+
+}  // namespace
 
 std::string upgrade_issue_to_string(const Upgrade_issue &problem) {
   std::stringstream ss;
@@ -96,9 +105,17 @@ const shcore::Option_pack_def<Upgrade_check_options>
   return opts;
 }
 
+mysqlshdk::utils::Version Upgrade_check_options::get_target_version() const {
+  return target_version.value_or(mysqlshdk::utils::Version(MYSH_VERSION));
+}
+
 void Upgrade_check_options::set_target_version(const std::string &value) {
-  if (!value.empty() && value != "8.0") {
-    target_version = Version(value);
+  if (!value.empty()) {
+    if (latest_versions.contains(value)) {
+      target_version = latest_versions.at(value);
+    } else {
+      target_version = Version(value);
+    }
   }
 }
 
@@ -263,8 +280,7 @@ std::vector<Upgrade_issue> Sql_upgrade_check::run(
     auto result = session->query(query);
     const mysqlshdk::db::IRow *row = nullptr;
     while ((row = result->fetch_one()) != nullptr) {
-      Upgrade_issue issue = parse_row(row);
-      if (!issue.empty()) issues.emplace_back(std::move(issue));
+      add_issue(row, &issues);
     }
   }
 
@@ -273,6 +289,12 @@ std::vector<Upgrade_issue> Sql_upgrade_check::run(
   return issues;
 }
 
+void Sql_upgrade_check::add_issue(const mysqlshdk::db::IRow *row,
+                                  std::vector<Upgrade_issue> *issues) {
+  Upgrade_issue issue = parse_row(row);
+  if (!issue.empty()) issues->emplace_back(std::move(issue));
+}
+
 const char *Sql_upgrade_check::get_description_internal() const {
   if (m_advice.empty()) return nullptr;
   return m_advice.c_str();
@@ -301,10 +323,10 @@ std::unique_ptr<Sql_upgrade_check> Sql_upgrade_check::get_old_temporal_check() {
       std::vector<std::string>{
           "SELECT table_schema, table_name,column_name,column_type "
           "FROM information_schema.columns WHERE column_type LIKE "
-          "'timestamp /* 5.5 binary format */';"},
+          "'%5.5 binary format%';"},
       Upgrade_issue::ERROR,
       "Following table columns use a deprecated and no longer supported "
-      "timestamp disk storage format. They must be converted to the new format "
+      "temporal disk storage format. They must be converted to the new format "
       "before upgrading. It can by done by rebuilding the table using 'ALTER "
       "TABLE <table_name> FORCE' command",
       nullptr, std::forward_list<std::string>{"SET show_old_temporals = ON;"},
@@ -441,12 +463,12 @@ class Routine_syntax_check : public Upgrade_check {
 
  protected:
   const char *get_title_internal() const override {
-    return "MySQL 8.0 syntax check for routine-like objects";
+    return "MySQL syntax check for routine-like objects";
   }
 
   const char *get_description_internal() const override {
     return "The following objects did not pass a syntax check with the latest "
-           "MySQL 8.0 grammar. A common reason is that they reference names "
+           "MySQL grammar. A common reason is that they reference names "
            "that conflict with new reserved keywords. You must update these "
            "routine definitions and `quote` any such references before "
            "upgrading.";
@@ -542,10 +564,11 @@ bool UNUSED_VARIABLE(register_utf8mb3) = Upgrade_check::register_check(
 std::unique_ptr<Sql_upgrade_check> Sql_upgrade_check::get_mysql_schema_check() {
   return std::make_unique<Sql_upgrade_check>(
       "mysqlSchemaCheck",
-      "Table names in the mysql schema conflicting with new tables in 8.0",
+      "Table names in the mysql schema conflicting with new tables in the "
+      "latest MySQL.",
       std::vector<std::string>{
-          "SELECT TABLE_SCHEMA, TABLE_NAME, 'Table name used in mysql schema "
-          "in 8.0' as WARNING FROM INFORMATION_SCHEMA.TABLES WHERE "
+          "SELECT TABLE_SCHEMA, TABLE_NAME, 'Table name used in mysql schema.' "
+          "as WARNING FROM INFORMATION_SCHEMA.TABLES WHERE "
           "LOWER(TABLE_SCHEMA) = 'mysql' and LOWER(TABLE_NAME) IN "
           "('catalogs', 'character_sets', 'collations', 'column_type_elements',"
           " 'columns', 'dd_properties', 'events', 'foreign_key_column_usage', "
@@ -559,9 +582,9 @@ std::unique_ptr<Sql_upgrade_check> Sql_upgrade_check::get_mysql_schema_check() {
           "'innodb_dynamic_metadata', 'password_history', 'role_edges');"},
       Upgrade_issue::ERROR,
       "The following tables in mysql schema have names that will conflict with "
-      "the ones introduced in 8.0 version. They must be renamed or removed "
-      "before upgrading (use RENAME TABLE command). This may also entail "
-      "changes to applications that use the affected tables.");
+      "the ones introduced in the latest version. They must be renamed or "
+      "removed before upgrading (use RENAME TABLE command). This may also "
+      "entail changes to applications that use the affected tables.");
 }
 
 namespace {
@@ -602,7 +625,7 @@ std::unique_ptr<Sql_upgrade_check> Sql_upgrade_check::get_zerofill_check() {
       Upgrade_issue::NOTICE,
       "The following table columns specify a ZEROFILL/display length "
       "attributes. "
-      "Please be aware that they will be ignored in MySQL 8.0");
+      "Please be aware that they will be ignored in the latest MySQL version.");
 }
 
 // Zerofill is still available in 8.0.11
@@ -622,13 +645,14 @@ Sql_upgrade_check::get_nonnative_partitioning_check() {
           "create_options like '%partitioned%' and upper(engine) not in "
           "('INNODB', 'NDB', 'NDBCLUSTER');"},
       Upgrade_issue::ERROR,
-      "In MySQL 8.0 storage engine is responsible for providing its own "
+      "In the latest MySQL storage engine is responsible for providing its own "
       "partitioning handler, and the MySQL server no longer provides generic "
       "partitioning support. InnoDB and NDB are the only storage engines that "
-      "provide a native partitioning handler that is supported in MySQL 8.0. A "
-      "partitioned table using any other storage engine must be altered—either "
-      "to convert it to InnoDB or NDB, or to remove its partitioning—before "
-      "upgrading the server, else it cannot be used afterwards.");
+      "provide a native partitioning handler that is supported in the latest "
+      "MySQL. A partitioned table using any other storage engine must be "
+      "altered—either to convert it to InnoDB or NDB, or to remove its "
+      "partitioning—before upgrading the server, else it cannot be used "
+      "afterwards.");
 }
 
 namespace {
@@ -682,12 +706,12 @@ Sql_upgrade_check::get_maxdb_sql_mode_flags_check() {
           "'sql_mode' and find_in_set('MAXDB', variable_value);"},
       Upgrade_issue::WARNING,
       "The following DB objects have the obsolete MAXDB option persisted for "
-      "sql_mode, which will be cleared during upgrade to 8.0. It "
+      "sql_mode, which will be cleared during the upgrade. It "
       "can potentially change the datatype DATETIME into TIMESTAMP if it is "
       "used inside object's definition, and this in turn can change the "
       "behavior in case of dates earlier than 1970 or later than 2037. If this "
       "is a concern, please redefine these objects so that they do not rely on "
-      "the MAXDB flag before running the upgrade to 8.0.");
+      "the MAXDB flag before running the upgrade.");
 }
 
 namespace {
@@ -730,7 +754,7 @@ Sql_upgrade_check::get_obsolete_sql_mode_flags_check() {
       "sqlModeFlagCheck", "Usage of obsolete sql_mode flags",
       std::move(queries), Upgrade_issue::NOTICE,
       "The following DB objects have obsolete options persisted for sql_mode, "
-      "which will be cleared during upgrade to 8.0.");
+      "which will be cleared during the upgrade.");
 }
 
 namespace {
@@ -822,8 +846,8 @@ Sql_upgrade_check::get_partitioned_tables_in_shared_tablespaces_check(
                 "itb.space and it.name like '%#P#%' and it.space_type != "
                 "'Single';"},
       Upgrade_issue::ERROR,
-      "The following tables have partitions in shared tablespaces. Before "
-      "upgrading to 8.0 they need to be moved to file-per-table tablespace. "
+      "The following tables have partitions in shared tablespaces. They need "
+      "to be moved to file-per-table tablespace before upgrading. "
       "You can do this by running query like 'ALTER TABLE table_name "
       "REORGANIZE PARTITION X INTO (PARTITION X VALUES LESS THAN (30) "
       "TABLESPACE=innodb_file_per_table);'");
@@ -966,8 +990,8 @@ class Removed_functions_check : public Sql_upgrade_check {
              "('performance_schema','information_schema','sys','mysql')"},
             Upgrade_issue::ERROR,
             "Following DB objects make use of functions that have "
-            "been removed in version 8.0. Please make sure to update them to "
-            "use supported alternatives before upgrade.") {}
+            "been removed int the latest MySQL version. Please make sure to "
+            "update them to use supported alternatives before upgrade.") {}
 
  protected:
   Upgrade_issue parse_row(const mysqlshdk::db::IRow *row) override {
@@ -1457,10 +1481,11 @@ Sql_upgrade_check::get_fts_in_tablename_check(const Upgrade_info &info) {
           "from information_schema.tables where table_name like binary "
           "'%FTS%';"},
       Upgrade_issue::ERROR,
-      "Upgrading from 5.7 to 8.0 does not support tables with name containing "
-      "'FTS' character string. The workaround is to rename the table for the "
-      "upgrade - e.g. it is enough to change any letter of the 'FTS' part to a "
-      "lower case. It can be renamed back again after the upgrade.");
+      "Upgrading from 5.7 to the latest MySQL version does not support tables "
+      "with name containing 'FTS' character string. The workaround is to "
+      "rename the table for the upgrade - e.g. it is enough to change any "
+      "letter of the 'FTS' part to a lower case. It can be renamed back again "
+      "after the upgrade.");
 }
 
 namespace {
@@ -1954,9 +1979,243 @@ bool UNUSED_VARIABLE(register_get_invalid_engine_foreign_key_check) =
         Upgrade_check::Target::OBJECT_DEFINITIONS, "8.0.0");
 }
 
+namespace {
+namespace deprecated_auth_funcs {
+constexpr std::array<std::string_view, 3> k_auth_list = {
+    "sha256_password", "mysql_native_password", "authentication_fido"};
+
+std::string get_auth_list() {
+  return shcore::str_join(k_auth_list, ", ", [](const auto &item) {
+    return shcore::sqlformat("?", item);
+  });
+}
+
+std::string get_auth_or_like_list(const std::string &value_name) {
+  return shcore::str_join(k_auth_list, " OR ", [&](const auto &item) {
+    return value_name + " LIKE '%" + std::string(item) + "%'";
+  });
+}
+
+bool is_auth_method(const std::string &auth) {
+  return std::find(k_auth_list.begin(), k_auth_list.end(), auth) !=
+         k_auth_list.end();
+}
+
+void setup_fido(const Version &target_version, Upgrade_issue *problem) {
+  if (target_version < Version(8, 0, 27)) {
+    problem->description =
+        "authentication_fido was introduced in 8.0.27 release and is not "
+        "supported in lower versions - this must be corrected.";
+    problem->level = Upgrade_issue::ERROR;
+  } else if (target_version < Version(8, 2, 0)) {
+    problem->description =
+        "authentication_fido is deprecated as of MySQL 8.2 and will be removed "
+        "in a future release. Consider using authentication_webauthn instead.";
+    problem->level = Upgrade_issue::NOTICE;
+  } else if (target_version < Version(8, 4, 0)) {
+    problem->description =
+        "authentication_fido is deprecated as of MySQL 8.2 and will be removed "
+        "in a future release. Use authentication_webauthn instead.";
+    problem->level = Upgrade_issue::WARNING;
+  } else {
+    problem->description =
+        "authentication_fido was replaced by authentication_webauthn as of "
+        "8.4.0 release - this must be corrected.";
+    problem->level = Upgrade_issue::ERROR;
+  }
+}
+
+void setup_other(const std::string &plugin, const Version &target_version,
+                 Upgrade_issue *problem) {
+  if (target_version < Version(8, 4, 0)) {
+    problem->description =
+        plugin +
+        " authentication method is deprecated and it should be considered to "
+        "correct this before upgrading to 8.4.0 release.";
+    problem->level = Upgrade_issue::WARNING;
+  } else {
+    problem->description =
+        plugin +
+        " authentication method was removed and it must be corrected before "
+        "upgrading to 8.4.0 release.";
+    problem->level = Upgrade_issue::ERROR;
+  }
+}
+
+Upgrade_issue parse_fido(const std::string &item,
+                         const Version &target_version) {
+  Upgrade_issue problem;
+  problem.schema = item;
+
+  setup_fido(target_version, &problem);
+
+  return problem;
+}
+
+Upgrade_issue parse_other(const std::string &item, const std::string &plugin,
+                          const Version &target_version) {
+  Upgrade_issue problem;
+  problem.schema = item;
+
+  setup_other(plugin, target_version, &problem);
+
+  return problem;
+}
+
+Upgrade_issue parse_item(const std::string &item, const std::string &auth,
+                         const Version &target_version) {
+  if (auth == "authentication_fido") {
+    return parse_fido(item, target_version);
+  } else {
+    return parse_other(item, auth, target_version);
+  }
+}
+}  // namespace deprecated_auth_funcs
+
+class Deprecated_auth_method_check : public Sql_upgrade_check {
+ public:
+  Deprecated_auth_method_check(mysqlshdk::utils::Version target_ver)
+      : Sql_upgrade_check(
+            "deprecatedAuthMethod",
+            "Check for deprecated or invalid user authentication methods.",
+            std::vector<std::string>{
+                "SELECT CONCAT(user, '@', host), plugin FROM "
+                "mysql.user WHERE plugin IN (" +
+                deprecated_auth_funcs::get_auth_list() +
+                ") AND user NOT LIKE 'mysql_router%';"},
+            Upgrade_issue::WARNING),
+        m_target_version(target_ver) {
+    m_advice =
+        "The following users are using a deprecated authentication method:\n";
+  }
+
+  ~Deprecated_auth_method_check() = default;
+
+  bool is_multi_lvl_check() const override { return true; }
+
+ protected:
+  Upgrade_issue parse_row(const mysqlshdk::db::IRow *row) override {
+    auto item = row->get_as_string(0);
+    auto auth = row->get_as_string(1);
+
+    return deprecated_auth_funcs::parse_item(item, auth, m_target_version);
+  }
+
+ private:
+  const mysqlshdk::utils::Version m_target_version;
+};
+}  // namespace
+
+Deprecated_default_auth_check::Deprecated_default_auth_check(
+    mysqlshdk::utils::Version target_ver)
+    : Sql_upgrade_check(
+          "deprecatedDefaultAuth",
+          "Check for deprecated or invalid default authentication methods in "
+          "system variables.",
+          std::vector<std::string>{
+              "show variables where variable_name = "
+              "'default_authentication_plugin' AND value IN (" +
+                  deprecated_auth_funcs::get_auth_list() + ");",
+              "show variables where variable_name = 'authentication_policy' "
+              "AND (" +
+                  deprecated_auth_funcs::get_auth_or_like_list("value") + ");"},
+          Upgrade_issue::WARNING),
+      m_target_version(target_ver) {
+  m_advice =
+      "The following variables have problems with their set "
+      "authentication method:\n";
+}
+
+Deprecated_default_auth_check::~Deprecated_default_auth_check() = default;
+
+void Deprecated_default_auth_check::add_issue(
+    const mysqlshdk::db::IRow *row, std::vector<Upgrade_issue> *issues) {
+  auto item = row->get_as_string(0);
+  auto auth = row->get_as_string(1);
+
+  parse_var(item, auth, issues);
+}
+
+void Deprecated_default_auth_check::parse_var(
+    const std::string &item, const std::string &auth,
+    std::vector<Upgrade_issue> *issues) {
+  auto list = shcore::split_string(auth, ",", true);
+  if (list.empty()) return;
+
+  for (auto &list_item : list) {
+    auto value = shcore::str_strip(list_item);
+    if (!deprecated_auth_funcs::is_auth_method(value)) continue;
+
+    auto issue =
+        deprecated_auth_funcs::parse_item(item, value, m_target_version);
+    if (!issue.empty()) issues->emplace_back(std::move(issue));
+  }
+}
+
+std::unique_ptr<Sql_upgrade_check>
+Sql_upgrade_check::get_deprecated_auth_method_check(
+    const Upgrade_check::Upgrade_info &info) {
+  return std::make_unique<Deprecated_auth_method_check>(info.target_version);
+}
+
+namespace {
+bool UNUSED_VARIABLE(register_get_deprecated_auth_method_check) =
+    Upgrade_check::register_check(
+        &Sql_upgrade_check::get_deprecated_auth_method_check,
+        Upgrade_check::Target::AUTHENTICATION_PLUGINS, "8.0.0", "8.1.0",
+        "8.2.0");
+}
+
+std::unique_ptr<Sql_upgrade_check>
+Sql_upgrade_check::get_deprecated_default_auth_check(
+    const Upgrade_check::Upgrade_info &info) {
+  return std::make_unique<Deprecated_default_auth_check>(info.target_version);
+}
+
+namespace {
+bool UNUSED_VARIABLE(register_get_deprecated_default_auth_check) =
+    Upgrade_check::register_check(
+        &Sql_upgrade_check::get_deprecated_default_auth_check,
+        Upgrade_check::Target::SYSTEM_VARIABLES, "8.0.0", "8.1.0", "8.2.0");
+}
+
+std::unique_ptr<Sql_upgrade_check>
+Sql_upgrade_check::get_deprecated_router_auth_method_check(
+    const Upgrade_check::Upgrade_info &info) {
+  return std::make_unique<Sql_upgrade_check>(
+      "deprecatedRouterAuthMethod",
+      "Check for deprecated or invalid authentication methods in use by MySQL "
+      "Router internal accounts.",
+      std::vector<std::string>{
+          "SELECT CONCAT(user, '@', host), ' - router user "
+          "with deprecated authentication method.' FROM "
+          "mysql.user WHERE plugin IN (" +
+          deprecated_auth_funcs::get_auth_list() +
+          ") AND user LIKE 'mysql_router%';"},
+      info.target_version >= Version(8, 4, 0) ? Upgrade_issue::ERROR
+                                              : Upgrade_issue::WARNING,
+      "The following accounts are MySQL Router accounts that use a deprecated "
+      "authentication method.\n"
+      "Those accounts are automatically created at bootstrap time when the "
+      "Router is not instructed to use an existing account. Please upgrade "
+      "MySQL Router to the latest version to ensure deprecated authentication "
+      "methods are no longer used.\n"
+      "Since version 8.0.19 it's also possible to instruct MySQL Router to use "
+      "a dedicated account. That account can be created using the AdminAPI.");
+}
+
+namespace {
+bool UNUSED_VARIABLE(register_get_deprecated_router_auth_method_check) =
+    Upgrade_check::register_check(
+        &Sql_upgrade_check::get_deprecated_router_auth_method_check,
+        Upgrade_check::Target::AUTHENTICATION_PLUGINS, "8.0.0", "8.1.0",
+        "8.2.0");
+}
+
 Upgrade_check_config::Upgrade_check_config(const Upgrade_check_options &options)
     : m_output_format(options.output_format) {
-  m_upgrade_info.target_version = options.target_version;
+  m_upgrade_info.target_version = options.get_target_version();
+  m_upgrade_info.explicit_target_version = options.target_version.has_value();
   m_upgrade_info.config_path = options.config_path;
 
   if (m_output_format.empty()) {
@@ -2027,7 +2286,8 @@ bool check_for_upgrade(const Upgrade_check_config &config) {
 
   print->check_info(config.session()->get_connection_options().uri_endpoint(),
                     config.upgrade_info().server_version_long,
-                    config.upgrade_info().target_version.get_base());
+                    config.upgrade_info().target_version.get_base(),
+                    config.upgrade_info().explicit_target_version);
 
   const auto checklist =
       Upgrade_check::create_checklist(config.upgrade_info(), config.targets());
@@ -2048,8 +2308,8 @@ bool check_for_upgrade(const Upgrade_check_config &config) {
     }
   };
 
-  // Workaround for 5.7 "No database selected/Corrupted" UPGRADE bug present up
-  // to 5.7.39
+  // Workaround for 5.7 "No database selected/Corrupted" UPGRADE bug present
+  // up to 5.7.39
   config.session()->execute("USE mysql;");
 
   for (const auto &check : checklist)
