@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2016, 2024, Oracle and/or its affiliates.
+ * Copyright (c) 2016, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -97,6 +95,7 @@ struct Help_topic {
   Help_topic *m_parent;
   Help_topic_refs m_childs;
   bool m_enabled;
+  std::map<std::string, std::string> m_keywords;
 
   const Help_topic *get_category() const;
 
@@ -127,6 +126,8 @@ struct Help_topic {
   std::string get_id(IShell_core::Mode mode,
                      Topic_id_mode id_mode = Topic_id_mode::FULL) const;
 
+  std::string get_keyword(const std::string &keyword) const;
+
   /**
    * Fills the tokens array with the name of every single topic name
    * starting from the topmost relevant topic.
@@ -188,7 +189,7 @@ class Help_registry {
   static Help_registry *get();
 
   // Retrieves the help text associated to a specific token
-  std::string get_token(const std::string &help);
+  std::string get_token(const std::string &help) const;
 
   /**
    * Helper function to register multiple help entries for a topic at once.
@@ -198,9 +199,12 @@ class Help_registry {
    * @param auto_brief If true, treats the 1st paragraph as the brief text.
    * @param nosuffix If true, don't append the section specific suffix to the
    * prefix when generating tag names.
+   * @param is_shell_command If true, parsing will also support defining the
+   * syntax tag wth @syntax and examples with @example
    */
   void add_split_help(const std::string &prefix, const std::string &data,
-                      bool auto_brief, bool nosuffix);
+                      bool auto_brief, bool nosuffix,
+                      bool is_shell_command = false);
 
   /**
    * Helper function to register a single help entry.
@@ -282,7 +286,8 @@ class Help_registry {
   void add_help_class(
       const std::string &name, const std::string &parent,
       const std::string &upper_class = "",
-      IShell_core::Mode_mask mode = IShell_core::all_scripting_modes());
+      IShell_core::Mode_mask mode = IShell_core::all_scripting_modes(),
+      std::map<std::string, std::string> keywords = {});
   void inherit_members(Help_topic *parent, Help_topic *child);
   void inherit_member(Help_topic *parent, Help_topic *member);
 
@@ -415,9 +420,10 @@ struct Help_register {
  */
 struct Help_register_split {
   Help_register_split(const std::string &prefix, const std::string &data,
-                      bool auto_brief, bool nosuffix) {
+                      bool auto_brief, bool nosuffix,
+                      bool is_shell_command = false) {
     shcore::Help_registry::get()->add_split_help(prefix, data, auto_brief,
-                                                 nosuffix);
+                                                 nosuffix, is_shell_command);
   }
 };
 
@@ -470,7 +476,8 @@ struct Help_topic_register {
 struct Help_class_register {
   Help_class_register(const std::string &child, const std::string &parent,
                       const std::string &upper_class,
-                      Help_mode mode = Help_mode::SCRIPTING);
+                      Help_mode mode = Help_mode::SCRIPTING,
+                      const std::map<std::string, std::string> &keywords = {});
 };
 enum class Help_option {
   Name,
@@ -530,16 +537,17 @@ class Help_manager {
                        const Help_options &options = Help_options::any(),
                        cli::Shell_cli_mapper *cli = nullptr);
 
-  void add_childs_section(const std::vector<const Help_topic *> &childs,
+  void add_childs_section(const Help_topic &parent,
+                          const std::vector<const Help_topic *> &childs,
                           std::vector<std::string> *sections, size_t padding,
                           bool members, const std::string &tag,
                           const std::string &default_title, bool alias = false);
 
-  void add_section(const std::string &title, const std::string &tag,
-                   std::vector<std::string> *sections, size_t padding,
-                   bool insert_blank_lines = true);
+  void add_section(const Help_topic &topic, const std::string &title,
+                   const std::string &tag, std::vector<std::string> *sections,
+                   size_t padding, bool insert_blank_lines = true);
 
-  void add_examples_section(const std::string &tag,
+  void add_examples_section(const Help_topic &topic, const std::string &tag,
                             std::vector<std::string> *sections, size_t padding,
                             const std::string &single_title = "EXAMPLE",
                             const std::string &multi_title = "EXAMPLES");
@@ -586,8 +594,9 @@ class Help_manager {
    *
    */
   std::map<std::string, std::string> preprocess_help(
-      std::vector<std::string> *text_lines) const;
-  std::string format_help_text(std::vector<std::string> *lines, size_t width,
+      const Help_topic &topic, std::vector<std::string> *text_lines) const;
+  std::string format_help_text(const Help_topic &topic,
+                               std::vector<std::string> *lines, size_t width,
                                size_t left_padding,
                                bool paragraph_per_line) const;
 
@@ -621,7 +630,7 @@ class Help_manager {
    * The following functions format the help data using a specific format for
    * each topic type
    */
-  void add_section_data(const std::string &title,
+  void add_section_data(const Help_topic &topic, const std::string &title,
                         std::vector<std::string> *details,
                         std::vector<std::string> *sections, size_t padding,
                         bool insert_blank_lines = true);
@@ -679,7 +688,8 @@ class Help_manager {
    */
   std::string format_topic_list(const std::vector<const Help_topic *> &topics,
                                 size_t lpadding = 0, bool alias = false);
-  std::string format_list_description(const std::string &name,
+  std::string format_list_description(const Help_topic &topic,
+                                      const std::string &name,
                                       std::vector<std::string> *help_text,
                                       size_t name_max_len, size_t lpadding = 0,
                                       const std::string &alias = "",
@@ -691,14 +701,24 @@ class Help_manager {
 
 }  // namespace shcore
 
+#define REGISTER_HELP_ALIAS(x, y) shcore::Help_register_alias x(#x, #y)
+
 #define REGISTER_HELP(x, y) shcore::Help_register x(#x, y)
 
 #define REGISTER_HELP_CLASS_MODE(name, parent, mode) \
   shcore::Help_class_register class_##parent##name(#name, #parent, "", mode)
 
+#define REGISTER_HELP_CLASS_MODE_KW(name, parent, mode, keywords)         \
+  shcore::Help_class_register class_kw_##parent##name(#name, #parent, "", \
+                                                      mode, keywords)
+
 #define REGISTER_HELP_CLASS(name, parent) \
   REGISTER_HELP_CLASS_MODE(name, parent, shcore::Help_mode::SCRIPTING)
 
+#define REGISTER_HELP_CLASS_KW(name, parent, keywords)                    \
+  REGISTER_HELP_CLASS_MODE_KW(name, parent, shcore::Help_mode::SCRIPTING, \
+                              keywords)
+
 #define REGISTER_HELP_SUB_CLASS(name, parent, upper) \
   shcore::Help_class_register class_##parent##name(#name, #parent, #upper)
 
@@ -754,7 +774,13 @@ class Help_manager {
 #define REGISTER_HELP_PROPERTY_TEXT(x, y) \
   shcore::Help_register_split x##property(#x, y, true, false)
 
+#define REGISTER_HELP_COMMAND_TEXT(x, y) \
+  shcore::Help_register_split x##command(#x, y, true, false, true)
+
 #define REGISTER_HELP_DETAIL_TEXT(x, y) \
   shcore::Help_register_split x##detail(#x, y, false, true)
 
+#define REGISTER_HELP_SHARED_TEXT(name, text) \
+  inline constexpr const char *name = text
+
 #endif  // MYSQLSHDK_INCLUDE_SHELLCORE_UTILS_HELP_H_
