@@ -24,12 +24,17 @@
 #include "mysqlshdk/libs/mysql/replication.h"
 
 #include <algorithm>
+#include <array>
 #include <random>
 #include <string>
 #include <vector>
 
 #include "modules/adminapi/common/common.h"
+#include "modules/adminapi/common/dba_errors.h"
+#include "modules/adminapi/common/server_features.h"
+#include "modules/errors.h"
 #include "mysqlshdk/libs/mysql/instance.h"
+#include "mysqlshdk/libs/utils/logger.h"
 #include "mysqlshdk/libs/utils/structured_text.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
 #include "mysqlshdk/libs/utils/utils_string.h"
@@ -574,7 +579,7 @@ void unserialize_channel_relay_log_info(
 }  // namespace
 
 bool get_channel_info(const mysqlshdk::mysql::IInstance &instance,
-                      const std::string &channel_name,
+                      std::string_view channel_name,
                       Replication_channel_master_info *out_master_info,
                       Replication_channel_relay_log_info *out_relay_log_info) {
   if (!out_master_info && !out_relay_log_info) return false;
@@ -607,17 +612,26 @@ bool get_channel_info(const mysqlshdk::mysql::IInstance &instance,
 std::vector<Slave_host> get_slaves(
     const mysqlshdk::mysql::IInstance &instance) {
   std::vector<Slave_host> slaves;
+  std::shared_ptr<mysqlshdk::db::IResult> result;
 
-  auto result = instance.query("SHOW SLAVE HOSTS");
+  if (instance.get_version() < utils::Version(8, 2, 0)) {
+    result = instance.query("SHOW SLAVE HOSTS");
+  } else {
+    result = instance.query("SHOW REPLICAS");
+  }
   while (auto row = result->fetch_one_named()) {
     Slave_host host;
     host.host = row.get_string("Host");
     host.port = row.get_uint("Port");
-    host.uuid = row.get_string("Slave_UUID");
+    if (instance.get_version() < utils::Version(8, 2, 0)) {
+      host.uuid = row.get_string("Slave_UUID");
+    } else {
+      host.uuid = row.get_string("Replica_UUID");
+    }
     slaves.push_back(std::move(host));
   }
 
-  // Sort by host/name to ensure deterministic output
+  // Sort by host/port to ensure deterministic output
   std::sort(slaves.begin(), slaves.end(),
             [](const Slave_host &a, const Slave_host &b) {
               return a.host < b.host || (a.host == b.host && a.port < b.port);
@@ -718,7 +732,7 @@ std::string get_replication_user(const mysqlshdk::mysql::IInstance &instance,
 }
 
 Replication_channel wait_replication_done_connecting(
-    const mysqlshdk::mysql::IInstance &slave, const std::string &channel_name) {
+    const mysqlshdk::mysql::IInstance &slave, std::string_view channel_name) {
   // Check that the IO thread for the channel switches to ON/OFF.
   // NOTE: It is assumed that the IO thread will not stay forever with the
   //       state CONNECTING and will eventually switch to ON or OFF (stopped).
@@ -777,18 +791,19 @@ size_t estimate_gtid_set_size(const std::string &gtid_set) {
       gtid_set,
       [&count](std::string_view s) {
         size_t p = s.find(':');
-        if (p != std::string::npos) {
-          std::string range{s};
-          size_t begin, end;
-          switch (sscanf(&range[p + 1], "%zu-%zu", &begin, &end)) {
-            case 2:
-              count += end - begin + 1;
-              break;
-            case 1:
-              count++;
-              break;
-          }
+        if (p == std::string::npos) return true;
+
+        std::string range{s};
+        size_t begin, end;
+        switch (sscanf(&range[p + 1], "%zu-%zu", &begin, &end)) {
+          case 2:
+            count += end - begin + 1;
+            break;
+          case 1:
+            count++;
+            break;
         }
+
         return true;
       },
       ",");
@@ -865,34 +880,32 @@ Gtid_set_relation compare_gtid_sets(const mysqlshdk::mysql::IInstance &server,
     return Gtid_set_relation::CONTAINS;
   }
 
-  // Set some session tempvars for caching
-  server.executef("SET @gtidset_a=?", gtidset_a);
-  server.executef("SET @gtidset_b=?", gtidset_b);
+  auto set_a = mysqlshdk::mysql::Gtid_set::from_normalized_string(
+      std::string{gtidset_a});
+  auto set_b = mysqlshdk::mysql::Gtid_set::from_normalized_string(
+      std::string{gtidset_b});
 
-  std::string a_sub_b = server.queryf_one_string(
-      0, "", "SELECT GTID_SUBTRACT(@gtidset_a, @gtidset_b)");
-  std::string b_sub_a = server.queryf_one_string(
-      0, "", "SELECT GTID_SUBTRACT(@gtidset_b, @gtidset_a)");
-
-  if (out_missing_from_a) *out_missing_from_a = b_sub_a;
-  if (out_missing_from_b) *out_missing_from_b = a_sub_b;
-
-  if (a_sub_b.empty() && b_sub_a.empty()) {
-    return Gtid_set_relation::EQUAL;
-  } else if (a_sub_b.empty() && !b_sub_a.empty()) {
-    return Gtid_set_relation::CONTAINED;
-  } else if (!a_sub_b.empty() && b_sub_a.empty()) {
-    return Gtid_set_relation::CONTAINS;
-  } else {
-    std::string ab_intersection =
-        server.queryf_one_string(0, "",
-                                 "SELECT GTID_SUBTRACT(@gtidset_a, "
-                                 "GTID_SUBTRACT(@gtidset_a, @gtidset_b))");
-    if (ab_intersection.empty())
-      return Gtid_set_relation::DISJOINT;
-    else
-      return Gtid_set_relation::INTERSECTS;
+  if (!mysqlsh::dba::supports_gtid_tags(server.get_version()) &&
+      (set_a.has_tags() || set_b.has_tags())) {
+    throw shcore::Exception(
+        shcore::str_format("Instance '%s' doesn't support GTID tags.",
+                           server.descr().c_str()),
+        SHERR_UNSUPPORTED_GTID_TAG);
   }
+
+  auto a_sub_b = mysqlshdk::mysql::Gtid_set{set_a}.subtract(set_b, server);
+  auto b_sub_a = mysqlshdk::mysql::Gtid_set{set_b}.subtract(set_a, server);
+
+  if (out_missing_from_a) *out_missing_from_a = b_sub_a.str();
+  if (out_missing_from_b) *out_missing_from_b = a_sub_b.str();
+
+  if (a_sub_b.empty() && b_sub_a.empty()) return Gtid_set_relation::EQUAL;
+  if (a_sub_b.empty() && !b_sub_a.empty()) return Gtid_set_relation::CONTAINED;
+  if (!a_sub_b.empty() && b_sub_a.empty()) return Gtid_set_relation::CONTAINS;
+
+  set_b.intersect(set_a, server);
+  return set_b.empty() ? Gtid_set_relation::DISJOINT
+                       : Gtid_set_relation::INTERSECTS;
 }
 
 std::string to_string(Replica_gtid_state state) {
@@ -924,6 +937,14 @@ void compute_joining_replica_gtid_state(
   assert(out_missing_gtids && out_unrecoverable_gtids && out_errant_gtids &&
          out_allowed_errant_gtids);
 
+  if (!mysqlsh::dba::supports_gtid_tags(instance.get_version()) &&
+      joiner_gtids.has_tags()) {
+    throw shcore::Exception(
+        shcore::str_format("Instance '%s' doesn't support GTID tags.",
+                           instance.descr().c_str()),
+        SHERR_UNSUPPORTED_GTID_TAG);
+  }
+
   using mysqlshdk::mysql::Gtid_set;
 
   Gtid_set completely_purged_gtids;
@@ -1046,6 +1067,15 @@ std::string get_replication_source_keyword(
   }
 }
 
+std::string get_binary_logs_keyword(const mysqlshdk::utils::Version &version,
+                                    bool status) {
+  if (version < mysqlshdk::utils::Version(8, 2, 0)) {
+    return "MASTER";
+  } else {
+    return (status == true ? "BINARY LOG" : "BINARY LOGS AND GTIDS");
+  }
+}
+
 std::tuple<std::string, std::string> get_replication_source_keywords(
     const mysqlshdk::utils::Version &version) {
   if (version < mysqlshdk::utils::Version(8, 0, 23))
@@ -1054,15 +1084,66 @@ std::tuple<std::string, std::string> get_replication_source_keywords(
 }
 
 std::string get_replication_option_keyword(
-    const mysqlshdk::utils::Version &version, const std::string &option) {
-  std::string ret = option;
+    const mysqlshdk::utils::Version &version, std::string_view option) {
+  using namespace std::literals;
 
-  if (version >= mysqlshdk::utils::Version(8, 0, 26)) {
-    ret = shcore::str_replace(ret, "slave", "replica");
-    ret = shcore::str_replace(ret, "master", "source");
-  } else {
-    ret = shcore::str_replace(ret, "replica", "slave");
-    ret = shcore::str_replace(ret, "source", "master");
+  // assume current keywords (>= 8.0.26)
+  std::array<std::tuple<std::string_view, std::string_view>, 2> replacements{
+      std::make_tuple("slave"sv, "replica"sv),
+      std::make_tuple("master"sv, "source"sv)};
+
+  // switch old<>new keywords if target is an older version
+  if (version < mysqlshdk::utils::Version(8, 0, 26)) {
+    for (auto &rep : replacements)
+      std::swap(std::get<0>(rep), std::get<1>(rep));
+  }
+
+  // Cannot blindly replace keywords, otherwise "aaa_replication_bbb" is
+  // incorrectly replaced with "aaa_slavetion_bbb". Replacements are only made
+  // if:
+  //  - keyword is at the beginning and is followed with '_', '-' or ' '
+  //  - keyword is at the end and is preceded with '_', '-' or ' '
+  //  - keyword is followed and preceded with '_', '-' or ' '
+  //
+  // It's also assumed that the replacement only needs to be made once per
+  // keyword.
+
+  std::array<const char, 3> separators{'_', '-', ' '};
+
+  std::string ret{option};
+
+  for (const auto &[old_name, new_name] : replacements) {
+    if (ret == old_name) return std::string{new_name};
+
+    auto it = ret.find(old_name);
+    if (it == std::string::npos) continue;
+
+    if (it == 0) {  // replace at beginning
+      assert(ret.size() > old_name.size());
+      if (std::find(separators.begin(), separators.end(),
+                    ret[old_name.size()]) != separators.end())
+        ret.replace(it, old_name.size(), new_name);
+      continue;
+    }
+
+    if (it == (ret.size() - old_name.size())) {  // replace at end
+      assert(ret.size() > old_name.size());
+      if (std::find(separators.begin(), separators.end(), ret[it - 1]) !=
+          separators.end())
+        ret.replace(it, old_name.size(), new_name);
+      continue;
+    }
+
+    // replace in the middle
+    assert((it + old_name.size()) < ret.size());
+    if (std::find(separators.begin(), separators.end(), ret[it - 1]) ==
+        separators.end())
+      continue;
+    if (std::find(separators.begin(), separators.end(),
+                  ret[it + old_name.size()]) == separators.end())
+      continue;
+
+    ret.replace(it, old_name.size(), new_name);
   }
 
   return ret;
