@@ -228,7 +228,7 @@ bool get_channel_state(const mysqlshdk::mysql::IInstance &instance,
  * @return false if the channel does not exist.
  */
 bool get_channel_info(const mysqlshdk::mysql::IInstance &instance,
-                      const std::string &channel_name,
+                      std::string_view channel_name,
                       Replication_channel_master_info *out_master_info,
                       Replication_channel_relay_log_info *out_relay_log_info);
 
@@ -255,7 +255,7 @@ std::vector<Slave_host> get_slaves(const mysqlshdk::mysql::IInstance &instance);
  * @param channel_name - the name of the replication channel to monitor
  */
 Replication_channel wait_replication_done_connecting(
-    const mysqlshdk::mysql::IInstance &slave, const std::string &channel_name);
+    const mysqlshdk::mysql::IInstance &slave, std::string_view channel_name);
 
 /**
  * Get the replication user used for the given channel.
@@ -476,6 +476,23 @@ std::string get_replica_keyword(const mysqlshdk::utils::Version &version);
 std::string get_replication_source_keyword(
     const mysqlshdk::utils::Version &version, bool command = false);
 
+/**
+ * Get the correct keyword in use for the replication configuration commands:
+ * 'SHOW MASTER LOGS' / 'SHOW MASTER STATUS' / 'PURGE MASTER LOGS'
+ *  regarding the target instance version.
+ *
+ * Useful for the construction of queries or output/error messages.
+ *
+ * @param version Version of the target server.
+ * @param command Boolean value to indicate if the keyword is for status
+ * command: 'SHOW MASTER STATUS'
+ *
+ * @return a string with the right keyword to be used for the replication
+ * configuration command
+ */
+std::string get_binary_logs_keyword(const mysqlshdk::utils::Version &version,
+                                    bool status = false);
+
 /**
  * Get the correct keywords in use for the replication configuration command:
  * 'change replication source/master' regarding the target instance version.
@@ -508,7 +525,7 @@ std::tuple<std::string, std::string> get_replication_source_keywords(
  * Replication option
  */
 std::string get_replication_option_keyword(
-    const mysqlshdk::utils::Version &version, const std::string &option);
+    const mysqlshdk::utils::Version &version, std::string_view option);
 
 }  // namespace mysql
 }  // namespace mysqlshdk
