@@ -39,7 +39,7 @@
 namespace mysqlshdk {
 namespace rest {
 
-class Retry_strategy;
+class IRetry_strategy;
 
 enum class Type { GET, HEAD, POST, PUT, PATCH, DELETE };
 
@@ -98,7 +98,7 @@ struct Request {
   /**
    * Retry strategy to use.
    */
-  Retry_strategy *retry_strategy = nullptr;
+  IRetry_strategy *retry_strategy = nullptr;
 
   /**
    * Causes a PUT request to load the data from this file
@@ -130,7 +130,7 @@ struct Json_request final : public Request {
   explicit Json_request(Masked_string path, const shcore::Value &data = {},
                         Headers headers = {})
       : Request(std::move(path), std::move(headers)) {
-    if (data.type != shcore::Value_type::Undefined) {
+    if (data.get_type() != shcore::Value_type::Undefined) {
       m_json = data.repr();
     }
 
