@@ -42,7 +42,7 @@ struct Http_request : public rest::Request {
   Http_request(Masked_string path, bool use_retry, rest::Headers headers = {});
 
  private:
-  std::unique_ptr<rest::Retry_strategy> m_retry_strategy;
+  std::unique_ptr<rest::IRetry_strategy> m_retry_strategy;
 };
 
 class Http_object : public IFile {
@@ -117,6 +117,8 @@ class Http_object : public IFile {
 
   std::optional<rest::Response_error> fetch_file_size() const;
 
+  void set_full_path(const Masked_string &full_path);
+
   off64_t m_offset = 0;
   Masked_string m_base;
   std::string m_path;
