@@ -28,6 +28,7 @@
 #include <chrono>
 #include <functional>
 #include <list>
+#include <optional>
 #include <set>
 #include <sstream>
 #include <string>
@@ -196,6 +197,18 @@ bool SHCORE_PUBLIC match_glob(const std::string_view pattern,
                               const std::string_view s,
                               bool case_sensitive = false);
 
+/**
+ * Replaces all escaped wildcard characters with their unescaped counterparts.
+ * If pattern already contains an unescaped wildcard characters, does not return
+ * a value.
+ *
+ * @param pattern A pattern to process.
+ *
+ * @returns Processed pattern or no value.
+ */
+std::optional<std::string> SHCORE_PUBLIC
+unescape_glob(const std::string_view pattern);
+
 std::string SHCORE_PUBLIC to_camel_case(std::string_view name);
 std::string SHCORE_PUBLIC from_camel_case(std::string_view name);
 std::string SHCORE_PUBLIC from_camel_case_to_dashes(std::string_view name);
