@@ -37,7 +37,7 @@
 namespace {
 
 // updated as of 8.0, 2022-02-11, this array MUST be sorted
-constexpr std::array<std::string_view, 269> reserved_keywords = {
+constexpr std::array<std::string_view, 271> reserved_keywords = {
     "ACCESSIBLE",
     "ADD",
     "ADMIN",  // became nonreserved in 8.0.12
@@ -120,6 +120,7 @@ constexpr std::array<std::string_view, 269> reserved_keywords = {
     "FORCE",
     "FOREIGN",
     "FROM",
+    "FULL",
     "FULLTEXT",
     "FUNCTION",  // became reserved in 8.0.1
     "GENERATED",
@@ -151,6 +152,7 @@ constexpr std::array<std::string_view, 269> reserved_keywords = {
     "INT8",
     "INTEGER",
     "INTERVAL",
+    "INTERSECT",
     "INTO",
     "IO_AFTER_GTIDS",
     "IO_BEFORE_GTIDS",
@@ -453,6 +455,8 @@ std::string quote_identifier(std::string_view identifier, char q) {
  * allowed in unquoted identifiers. Leading numbers are not strictly forbidden
  * but discouraged as they may lead to ambiguous behavior.
  */
+// TODO(alfredo) - this should be removed (along with is_reserved_word)...
+// identifiers should just be always quoted
 std::string quote_identifier_if_needed(std::string_view ident, char q) {
   bool needs_quotation =
       is_reserved_word(ident);  // check whether it's a reserved keyword
