@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -199,15 +197,15 @@ size_t bits_to_string_hex_size(int nbits) {
   return num_chars;
 }
 
-std::string SHCORE_PUBLIC string_to_hex(std::string_view s) {
+std::string SHCORE_PUBLIC string_to_hex(std::string_view s, bool prefix) {
   constexpr std::array<char, 16> hexmap = {'0', '1', '2', '3', '4', '5',
                                            '6', '7', '8', '9', 'A', 'B',
                                            'C', 'D', 'E', 'F'};
 
   std::string encoded;
 
-  encoded.reserve(2 + s.size() * 2);
-  encoded.append("0x");
+  encoded.reserve((prefix ? 2 : 0) + s.size() * 2);
+  if (prefix) encoded.append("0x");
 
   for (const auto cur_char : s) {
     encoded.push_back(hexmap[(cur_char & 0xF0) >> 4]);
