@@ -1,18 +1,16 @@
 /*
-  Copyright (c) 2015, 2024, Oracle and/or its affiliates.
+  Copyright (c) 2015, 2023, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.
 
-  This program is designed to work with certain software (including
-  but not limited to OpenSSL) that is licensed under separate terms,
-  as designated in a particular file or component or in included license
+  This program is also distributed with certain software (including
+  but not limited to OpenSSL) that is licensed under separate terms, as
+  designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
-  separately licensed software that they have either included with
-  the program or referenced in the documentation.
-
+  separately licensed software that they have included with MySQL.
   This program is distributed in the hope that it will be useful,  but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -23,11 +21,13 @@
   51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */
 
-#ifndef UUID_GEN_INCLUDED
-#define UUID_GEN_INCLUDED
+#ifndef MYSQLSHDK_LIBS_UTILS_UUID_GEN_H_
+#define MYSQLSHDK_LIBS_UTILS_UUID_GEN_H_
 
 #include <string>
 
+namespace shcore {
+
 #define UUID_LENGTH_BIN 16
 typedef unsigned char uuid_type[UUID_LENGTH_BIN];
 
@@ -36,4 +36,5 @@ void end_uuid();
 void generate_uuid(uuid_type &uuid);
 std::string get_string_uuid();
 
-#endif
\ No newline at end of file
+}  // namespace shcore
+#endif  // MYSQLSHDK_LIBS_UTILS_UUID_GEN_H_
\ No newline at end of file
