@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2015, 2025, Oracle and/or its affiliates.
+ * Copyright (c) 2015, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -34,6 +32,221 @@ namespace shcore {
 
 namespace {
 
+////////////////////////////////////////////////////////////////////////////////
+// shcore::Value comparisons
+////////////////////////////////////////////////////////////////////////////////
+bool value_op_less(const Value &a, const Value &b);
+bool value_op_less_equal(const Value &a, const Value &b);
+
+bool value_op_less(const Value &a, const Value &b) {
+  auto a_type = a.get_type();
+  auto b_type = b.get_type();
+
+  if (a_type == b_type) {
+    switch (a_type) {
+      case Value_type::Undefined:
+      case Value_type::Null:
+        return false;
+      case Value_type::Bool:
+        return (a.as_bool() < b.as_bool());
+      case Value_type::String:
+      case Value_type::Binary:
+        return (a.get_string() < b.get_string());
+      case Value_type::Integer:
+        return (a.as_int() < b.as_int());
+      case Value_type::UInteger:
+        return (a.as_uint() < b.as_uint());
+      case Value_type::Float:
+        return (a.as_double() < b.as_double());
+      case Value_type::Object:
+        return (*a.as_object() < *b.as_object());
+      case Value_type::Array:
+        // NOTE: not implemented: it's not possible to order array (because of
+        // its values)
+        return false;  //(*a.as_array() < *b.as_array());
+      case Value_type::Map:
+        // NOTE: not implemented: it's not possible to order maps (because of
+        // its values)
+        return false;  //(*a.as_map() < *b.as_map());
+      case Value_type::Function:
+        // NOTE: not implemented: it's not possible to order functions
+        return false;
+      default:
+        return false;
+    }
+  }
+
+  // with type conversion
+  switch (a_type) {
+    case Value_type::Bool: {
+      switch (b_type) {
+        case Value_type::Integer:
+          if (b.as_int() == 1) return a.as_bool() < true;
+          return false;
+        case Value_type::UInteger:
+          if (b.as_uint() == 1) return a.as_bool() < true;
+          return false;
+        case Value_type::Float:
+          if (b.as_double() == 1.0) return a.as_bool() < true;
+          return false;
+        default:
+          return false;
+      }
+    }
+
+    case Value_type::Integer: {
+      if (b_type == Value_type::Bool) return !value_op_less_equal(b, a);
+
+      if (b_type == Value_type::Float) {
+        auto a_val = a.as_int();
+        auto b_val = b.as_double();
+        auto b_val_as_int = static_cast<int64_t>(b_val);
+        return ((a_val < b_val_as_int) ||
+                ((a_val == b_val_as_int) && ((b_val - b_val_as_int) > 0.0)));
+      }
+
+      return false;
+    }
+
+    case Value_type::UInteger: {
+      if (b_type == Value_type::Bool) return !value_op_less_equal(b, a);
+
+      if (b_type == Value_type::Float) {
+        auto a_val = a.as_uint();
+        auto b_val = b.as_double();
+        auto b_val_as_int = static_cast<uint64_t>(b_val);
+        return ((a_val < b_val_as_int) ||
+                ((a_val == b_val_as_int) && ((b_val - b_val_as_int) > 0.0)));
+      }
+
+      return false;
+    }
+
+    case Value_type::Float: {
+      switch (b_type) {
+        case Value_type::Bool:
+        case Value_type::Integer:
+        case Value_type::UInteger:
+          return value_op_less(b, a);
+        default:
+          return false;
+      }
+    }
+
+    default:
+      return false;
+  }
+}
+
+bool value_op_less_equal(const Value &a, const Value &b) {
+  auto a_type = a.get_type();
+  auto b_type = b.get_type();
+
+  if (a_type == b_type) {
+    switch (a_type) {
+      case Value_type::Undefined:
+      case Value_type::Null:
+        return true;
+      case Value_type::Bool:
+        return (a.as_bool() <= b.as_bool());
+      case Value_type::String:
+      case Value_type::Binary:
+        return (a.get_string() <= b.get_string());
+      case Value_type::Integer:
+        return (a.as_int() <= b.as_int());
+      case Value_type::UInteger:
+        return (a.as_uint() <= b.as_uint());
+      case Value_type::Float:
+        return (a.as_double() <= b.as_double());
+      case Value_type::Object:
+        return (*a.as_object() <= *b.as_object());
+      case Value_type::Array:
+        // NOTE: not implemented, it's not possible to order arrays (because of
+        // its values)
+        return (*a.as_array() == *b.as_array());
+      case Value_type::Map:
+        // NOTE: not implemented, it's not possible to order maps (because of
+        // its values)
+        return (*a.as_map() == *b.as_map());
+      case Value_type::Function:
+        // NOTE: not implemented, it's not possible to order functions
+        return (a.as_function() == b.as_function());
+      default:
+        return false;
+    }
+  }
+
+  // with type conversion
+  switch (a_type) {
+    case Value_type::Bool: {
+      switch (b_type) {
+        case Value_type::Integer:
+          if (auto val = b.as_int(); val == 1)
+            return true;
+          else if (val == 0)
+            return a.as_bool() <= false;
+          return false;
+        case Value_type::UInteger:
+          if (auto val = b.as_uint(); val == 1)
+            return true;
+          else if (val == 0)
+            return a.as_bool() <= false;
+          return false;
+        case Value_type::Float:
+          if (auto val = b.as_double(); val == 1.0)
+            return true;
+          else if (val == 0.0)
+            return a.as_bool() <= false;
+          return false;
+        default:
+          return false;
+      }
+    }
+
+    case Value_type::Integer: {
+      if (b_type == Value_type::Bool) return !value_op_less(b, a);
+
+      if (b_type == Value_type::Float) {
+        auto a_val = a.as_int();
+        auto b_val = b.as_double();
+        auto b_val_as_int = static_cast<int64_t>(b_val);
+        return ((a_val < b_val_as_int) ||
+                ((a_val == b_val_as_int) && ((b_val - b_val_as_int) >= 0.0)));
+      }
+
+      return false;
+    }
+
+    case Value_type::UInteger: {
+      if (b_type == Value_type::Bool) return !value_op_less(b, a);
+
+      if (b_type == Value_type::Float) {
+        auto a_val = a.as_uint();
+        auto b_val = b.as_double();
+        auto b_val_as_int = static_cast<uint64_t>(b_val);
+        return ((a_val < b_val_as_int) ||
+                ((a_val == b_val_as_int) && ((b_val - b_val_as_int) >= 0.0)));
+      }
+
+      return false;
+    }
+
+    case Value_type::Float: {
+      switch (b_type) {
+        case Value_type::Bool:
+        case Value_type::Integer:
+        case Value_type::UInteger:
+          return value_op_less_equal(b, a);
+        default:
+          return false;
+      }
+    }
+
+    default:
+      return false;
+  }
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // Array_object
 ////////////////////////////////////////////////////////////////////////////////
@@ -132,12 +345,13 @@ PyObject *ao_remove_all(Array_object *self);
 PyObject *ao_reverse(Array_object *self);
 PyObject *ao_sort(Array_object *self, PyObject *args, PyObject *kwds);
 
-#ifdef __GNUC__
-// -Wcast-function-type needs to be suppressed here, because we're casting
-// functions with different number of parameters to PyCFunction
+#if __GNUC__ > 7 && !defined(__clang__)
+// -Wcast-function-type was added in GCC 8.0, needs to be suppressed here,
+// because we're casting functions with different number of parameters to
+// PyCFunction
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wcast-function-type"
-#endif  // __GNUC__
+#endif  // __GNUC__ > 7 && !defined(__clang__)
 
 static PyMethodDef array_object_methods[] = {
     {"__getitem__", (PyCFunction)ao_subscript, METH_O | METH_COEXIST,
@@ -159,9 +373,9 @@ static PyMethodDef array_object_methods[] = {
     {nullptr, nullptr, 0, nullptr},
 };
 
-#ifdef __GNUC__
+#if __GNUC__ > 7 && !defined(__clang__)
 #pragma GCC diagnostic pop
-#endif  // __GNUC__
+#endif  // __GNUC__ > 7 && !defined(__clang__)
 
 ////////////////////////////////////////////////////////////////////////////////
 // Array_object_type
@@ -292,10 +506,6 @@ static PyTypeObject Array_object_type = {
     ,
     0  // tp_watched
 #endif
-#if PY_VERSION_HEX >= 0x030D0000
-    ,
-    0  // tp_versions_used
-#endif
 };
 
 #if PY_VERSION_HEX >= 0x03080000 && PY_VERSION_HEX < 0x03090000
@@ -329,12 +539,13 @@ PyObject *ao_iter_length(Array_object_iterator *self);
 PyObject *ao_iter_reduce(Array_object_iterator *self);
 PyObject *ao_iter_setstate(Array_object_iterator *self, PyObject *state);
 
-#ifdef __GNUC__
-// -Wcast-function-type needs to be suppressed here, because we're casting
-// functions with different number of parameters to PyCFunction
+#if __GNUC__ > 7 && !defined(__clang__)
+// -Wcast-function-type was added in GCC 8.0, needs to be suppressed here,
+// because we're casting functions with different number of parameters to
+// PyCFunction
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wcast-function-type"
-#endif  // __GNUC__
+#endif  // __GNUC__ > 7 && !defined(__clang__)
 
 static PyMethodDef ao_iter_methods[] = {
     {"__length_hint__", (PyCFunction)ao_iter_length, METH_NOARGS,
@@ -344,9 +555,9 @@ static PyMethodDef ao_iter_methods[] = {
     {nullptr, nullptr, 0, nullptr},
 };
 
-#ifdef __GNUC__
+#if __GNUC__ > 7 && !defined(__clang__)
 #pragma GCC diagnostic pop
-#endif  // __GNUC__
+#endif  // __GNUC__ > 7 && !defined(__clang__)
 
 ////////////////////////////////////////////////////////////////////////////////
 // Array_object_iterator_type
@@ -464,10 +675,6 @@ static PyTypeObject Array_object_iterator_type = {
     ,
     0  // tp_watched
 #endif
-#if PY_VERSION_HEX >= 0x030D0000
-    ,
-    0  // tp_versions_used
-#endif
 };
 
 #if PY_VERSION_HEX >= 0x03080000 && PY_VERSION_HEX < 0x03090000
@@ -484,12 +691,13 @@ PyObject *ao_rev_iter_length(Array_object_iterator *self);
 PyObject *ao_rev_iter_reduce(Array_object_iterator *self);
 PyObject *ao_rev_iter_setstate(Array_object_iterator *self, PyObject *state);
 
-#ifdef __GNUC__
-// -Wcast-function-type needs to be suppressed here, because we're casting
-// functions with different number of parameters to PyCFunction
+#if __GNUC__ > 7 && !defined(__clang__)
+// -Wcast-function-type was added in GCC 8.0, needs to be suppressed here,
+// because we're casting functions with different number of parameters to
+// PyCFunction
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wcast-function-type"
-#endif  // __GNUC__
+#endif  // __GNUC__ > 7 && !defined(__clang__)
 
 static PyMethodDef ao_riter_methods[] = {
     {"__length_hint__", (PyCFunction)ao_rev_iter_length, METH_NOARGS,
@@ -499,9 +707,9 @@ static PyMethodDef ao_riter_methods[] = {
     {nullptr, nullptr, 0, nullptr},
 };
 
-#ifdef __GNUC__
+#if __GNUC__ > 7 && !defined(__clang__)
 #pragma GCC diagnostic pop
-#endif  // __GNUC__
+#endif  // __GNUC__ > 7 && !defined(__clang__)
 
 ////////////////////////////////////////////////////////////////////////////////
 // Array_object_reverse_iterator_type
@@ -619,10 +827,6 @@ static PyTypeObject Array_object_reverse_iterator_type = {
     ,
     0  // tp_watched
 #endif
-#if PY_VERSION_HEX >= 0x030D0000
-    ,
-    0  // tp_versions_used
-#endif
 };
 
 #if PY_VERSION_HEX >= 0x03080000 && PY_VERSION_HEX < 0x03090000
@@ -1501,8 +1705,9 @@ PyObject *ao_sort(Array_object *self, PyObject *args, PyObject *kwds) {
     std::reverse(items.begin(), items.end());
   }
 
-  std::stable_sort(items.begin(), items.end(),
-                   [](const auto &l, const auto &r) { return l.key < r.key; });
+  std::stable_sort(
+      items.begin(), items.end(),
+      [](const auto &l, const auto &r) { return value_op_less(l.key, r.key); });
 
   // reverse the results
   if (reverse) {
@@ -1549,25 +1754,7 @@ int ao_init(Array_object *self, PyObject *args, PyObject *kw) {
     return -1;
   }
 
-  static constexpr auto expect_no_keywords = [](PyObject *kwargs) {
-    if (!kwargs) {
-      return true;
-    }
-
-    if (!PyDict_CheckExact(kwargs)) {
-      PyErr_BadInternalCall();
-      return false;
-    }
-
-    if (0 == PyDict_GET_SIZE(kwargs)) {
-      return true;
-    }
-
-    PyErr_SetString(PyExc_TypeError, "List() takes no keyword arguments");
-    return false;
-  };
-
-  if (!expect_no_keywords(kw)) {
+  if (!_PyArg_NoKeywords("List", kw)) {
     return -1;
   }
 
@@ -1677,11 +1864,11 @@ PyObject *ao_richcompare(Array_object *self, PyObject *right, int op) {
 
     switch (op) {
       case Py_LT:
-        result = vl < vr;
+        result = value_op_less(vl, vr);
         break;
 
       case Py_LE:
-        result = vl <= vr;
+        result = value_op_less_equal(vl, vr);
         break;
 
       case Py_EQ:
@@ -1691,11 +1878,11 @@ PyObject *ao_richcompare(Array_object *self, PyObject *right, int op) {
         Py_RETURN_TRUE;
 
       case Py_GT:
-        result = vl > vr;
+        result = !value_op_less_equal(vl, vr);
         break;
 
       case Py_GE:
-        result = vl >= vr;
+        result = !value_op_less(vl, vr);
         break;
 
       default:
@@ -1869,7 +2056,6 @@ PyObject *ao_rev_iter_setstate(Array_object_iterator *self, PyObject *state) {
 
   Py_RETURN_NONE;
 }
-
 }  // namespace
 
 void Python_context::init_shell_list_type() {
