@@ -374,6 +374,10 @@ PyTypeObject Type = {
     0  // tp_print
 #endif
 #endif
+#if PY_VERSION_HEX >= 0x030C0000
+    ,
+    0  // tp_watched
+#endif
 };
 
 #if PY_VERSION_HEX >= 0x03080000 && PY_VERSION_HEX < 0x03090000
@@ -856,6 +860,10 @@ PyTypeObject Type = {
     0  // tp_print
 #endif
 #endif
+#if PY_VERSION_HEX >= 0x030C0000
+    ,
+    0  // tp_watched
+#endif
 };
 
 #if PY_VERSION_HEX >= 0x03080000 && PY_VERSION_HEX < 0x03090000
@@ -1045,6 +1053,10 @@ PyTypeObject Type = {
     0  // tp_print
 #endif
 #endif
+#if PY_VERSION_HEX >= 0x030C0000
+    ,
+    0  // tp_watched
+#endif
 };
 
 #if PY_VERSION_HEX >= 0x03080000 && PY_VERSION_HEX < 0x03090000
@@ -1237,6 +1249,10 @@ PyTypeObject Type = {
     0  // tp_print
 #endif
 #endif
+#if PY_VERSION_HEX >= 0x030C0000
+    ,
+    0  // tp_watched
+#endif
 };
 
 #if PY_VERSION_HEX >= 0x03080000 && PY_VERSION_HEX < 0x03090000
