@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2015, 2024, Oracle and/or its affiliates.
+ * Copyright (c) 2015, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -288,10 +286,6 @@ PyTypeObject PyShMethodObjectType = {
     ,
     0  // tp_watched
 #endif
-#if PY_VERSION_HEX >= 0x030D0000
-    ,
-    0  // tp_versions_used
-#endif
 };
 
 #if PY_VERSION_HEX >= 0x03080000 && PY_VERSION_HEX < 0x03090000
@@ -404,7 +398,7 @@ PyObject *object_getattro(PyShObjObject *self, PyObject *attr_name) {
     error_handled = true;
   }
 
-  if (member.type != shcore::Undefined) {
+  if (member.get_type() != shcore::Undefined) {
     auto object = py::convert(member);
     self->cache->members[attrname] = py::Store{object.get()};
     return object.release();
@@ -736,10 +730,6 @@ PyTypeObject PyShObjObjectType = {
     ,
     0  // tp_watched
 #endif
-#if PY_VERSION_HEX >= 0x030D0000
-    ,
-    0  // tp_versions_used
-#endif
 };
 
 PyTypeObject PyShObjIndexedObjectType = {
@@ -839,10 +829,6 @@ PyTypeObject PyShObjIndexedObjectType = {
     ,
     0  // tp_watched
 #endif
-#if PY_VERSION_HEX >= 0x030D0000
-    ,
-    0  // tp_versions_used
-#endif
 };
 
 #if PY_VERSION_HEX >= 0x03080000 && PY_VERSION_HEX < 0x03090000
@@ -939,18 +925,13 @@ bool shcore::unwrap(PyObject *value,
 
 bool shcore::unwrap_method(PyObject *value,
                            std::shared_ptr<Function_base> *method) {
-  if (PyObject_TypeCheck(value, &PyShMethodObjectType)) {
-    const auto o = reinterpret_cast<PyShMethodObject *>(value);
-    const auto m = o->object->get()->get_member_advanced(*o->method);
+  if (!PyObject_TypeCheck(value, &PyShMethodObjectType)) return false;
 
-    if (shcore::Value_type::Function != m.type) {
-      return false;
-    }
+  const auto o = reinterpret_cast<PyShMethodObject *>(value);
+  const auto m = o->object->get()->get_member_advanced(*o->method);
 
-    *method = m.as_function();
+  if (shcore::Value_type::Function != m.get_type()) return false;
 
-    return true;
-  }
-
-  return false;
+  *method = m.as_function();
+  return true;
 }
