@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2014, 2025, Oracle and/or its affiliates.
+ * Copyright (c) 2014, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -40,14 +38,14 @@
 #include "utils/utils_general.h"
 #include "utils/utils_path.h"
 #include "utils/utils_string.h"
+#ifdef HAVE_V8
+#include "mysqlshdk/shellcore/provider_javascript.h"
+#include "shellcore/shell_jscript.h"
+#endif
 #ifdef HAVE_PYTHON
 #include "mysqlshdk/shellcore/provider_python.h"
 #include "shellcore/shell_python.h"
 #endif
-#ifdef HAVE_JIT_EXECUTOR
-#include "mysqlshdk/include/shellcore/shell_polyglot.h"
-#include "mysqlshdk/shellcore/provider_polyglot.h"
-#endif
 #include "shellcore/shell_sql.h"
 
 namespace mysqlsh {
@@ -105,7 +103,7 @@ void Base_shell::finish_init() {
 
   shcore::IShell_core::Mode initial_mode = options().initial_mode;
   if (initial_mode == shcore::IShell_core::Mode::None) {
-#ifdef HAVE_JS
+#ifdef HAVE_V8
     initial_mode = shcore::IShell_core::Mode::JavaScript;
 #else
 #ifdef HAVE_PYTHON
@@ -418,11 +416,11 @@ bool Base_shell::switch_shell_mode(shcore::Shell_core::Mode mode,
         }
         break;
       case shcore::Shell_core::Mode::JavaScript:
-#ifdef HAVE_JS
+#ifdef HAVE_V8
         if (_shell->switch_mode(mode) && !initializing)
           println("Switching to JavaScript mode...");
         {
-          auto js = static_cast<shcore::Shell_polyglot *>(
+          auto js = static_cast<shcore::Shell_javascript *>(
               _shell->language_object(mode));
           if (!js->result_processor()) {
             js->set_result_processor(
@@ -431,8 +429,8 @@ bool Base_shell::switch_shell_mode(shcore::Shell_core::Mode mode,
                 shcore::IShell_core::Mode_mask(
                     shcore::IShell_core::Mode::JavaScript),
                 std::unique_ptr<shcore::completer::Provider>(
-                    new shcore::completer::Provider_polyglot(
-                        _completer_object_registry, js->polyglot_context())));
+                    new shcore::completer::Provider_javascript(
+                        _completer_object_registry, js->javascript_context())));
             lang_initialized = true;
           }
         }
@@ -568,31 +566,32 @@ void Base_shell::process_sql_result(
 }
 
 void Base_shell::print_result(const shcore::Value &result) {
-  if (result) {
-    if (result.type == shcore::Object) {
-      auto object = result.as_object();
-      auto shell_hook = get_shell_hook(object->class_name());
-      if (!shell_hook.empty()) {
-        if (object->has_member(shell_hook)) {
-          shcore::Value hook_result = object->call(shell_hook, {});
+  if (!result) return;
 
-          // Recursive call to continue processing shell hooks if any
-          process_result(hook_result, false);
+  auto type = result.get_type();
 
-          return;
-        }
+  if (type == shcore::Object) {
+    auto object = result.as_object();
+    auto shell_hook = get_shell_hook(object->class_name());
+    if (!shell_hook.empty()) {
+      if (object->has_member(shell_hook)) {
+        shcore::Value hook_result = object->call(shell_hook, {});
+
+        // Recursive call to continue processing shell hooks if any
+        process_result(hook_result, false);
+
+        return;
       }
     }
-
-    // In JSON mode: the json representation is used for Object, Array and
-    // Map For anything else a map is printed with the "value" key
-    std::string tag;
-    if (result.type != shcore::Object && result.type != shcore::Array &&
-        result.type != shcore::Map)
-      tag = "value";
-
-    print_value(result, tag);
   }
+
+  // In JSON mode: the json representation is used for Object, Array and
+  // Map For anything else a map is printed with the "value" key
+  std::string tag;
+  if (type != shcore::Object && type != shcore::Array && type != shcore::Map)
+    tag = "value";
+
+  print_value(result, tag);
 }
 
 void Base_shell::process_result(const shcore::Value &result, bool got_error) {
