@@ -1,18 +1,16 @@
 #
-# Copyright (c) 2016, 2024, Oracle and/or its affiliates.
+# Copyright (c) 2016, 2023, Oracle and/or its affiliates.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2.0,
 # as published by the Free Software Foundation.
 #
-# This program is designed to work with certain software (including
-# but not limited to OpenSSL) that is licensed under separate terms,
-# as designated in a particular file or component or in included license
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
 # documentation.  The authors of MySQL hereby grant you an additional
 # permission to link the program and your derivative works with the
-# separately licensed software that they have either included with
-# the program or referenced in the documentation.
-#
+# separately licensed software that they have included with MySQL.
 # This program is distributed in the hope that it will be useful,  but
 # WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -172,17 +170,17 @@ def get_tool_path(basedir, tool, fix_ext=True, required=True,
     # Search for the tool
     none_found = True
     for path in search_paths:
-        norm_path = os.path.normpath(path)
+        # Use realpath() to get the canonical path and eliminate any symlinks
+        norm_path = os.path.normpath(os.path.realpath(path))
         if os.path.isdir(norm_path):
-            toolpath = os.path.normpath(os.path.join(norm_path, tool))
+            toolpath = os.path.join(norm_path, tool)
             if os.path.isfile(toolpath):
                 none_found = False
                 if not check_tool_func or check_tool_func(toolpath):
                     return r"{0}{1}{0}".format(quote_char, toolpath)
             else:
                 if tool == "mysqld.exe":
-                    toolpath = os.path.normpath(
-                        os.path.join(norm_path, "mysqld-nt.exe"))
+                    toolpath = os.path.join(norm_path, "mysqld-nt.exe")
                     if os.path.isfile(toolpath):
                         none_found = False
                         if not check_tool_func or check_tool_func(toolpath):
