@@ -1,4 +1,4 @@
-# Copyright (c) 2021, 2022, Oracle and/or its affiliates.
+# Copyright (c) 2021, 2023, Oracle and/or its affiliates.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2.0,
@@ -978,6 +978,11 @@ class DiagnosticsSession:
             kw_replica = "SLAVE"
             kw_replicas = "SLAVE HOSTS"
 
+        if self.session.version >= 80200:
+            kw_binary_log = "BINARY LOG"
+        else:
+            kw_binary_log = "MASTER"
+
         queries = [
             ("global variables",
              """SELECT g.variable_name name, g.variable_value value /*!80000, i.variable_source source*/
@@ -989,7 +994,7 @@ class DiagnosticsSession:
             # replication configuration
             "SHOW BINARY LOGS",
             f"SHOW {kw_replicas}",
-            "SHOW MASTER STATUS",
+            f"SHOW {kw_binary_log} STATUS",
             f"SHOW {kw_replica} STATUS",
             ("replication master_info",
              """SELECT * FROM mysql.slave_master_info ORDER BY Channel_name""",
@@ -1281,10 +1286,13 @@ def collect_cluster_metadata(zf: zipfile.ZipFile, prefix: str,
         if t == "ar":
             cluster_type = "ar"
         else:
-            t = session.run_sql(
-                "select count(*) from mysql_innodb_cluster_metadata.v2_cs_clustersets").fetch_one()[0]
-            if t:
-                cluster_type = "cs"
+            try:
+                t = session.run_sql(
+                    "select count(*) from mysql_innodb_cluster_metadata.v2_cs_clustersets").fetch_one()[0]
+                if t:
+                    cluster_type = "cs"
+            except:
+                pass
     return cluster_type
 
 
