@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2014, 2024, Oracle and/or its affiliates.
+ * Copyright (c) 2014, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -30,6 +28,7 @@
 #include "mysqlshdk/include/shellcore/base_session.h"
 #include "mysqlshdk/include/shellcore/interrupt_helper.h"
 #include "mysqlshdk/include/shellcore/shell_init.h"
+#include "mysqlshdk/libs/db/mysql/auth_plugins/fido.h"
 #include "mysqlshdk/libs/textui/textui.h"
 #include "mysqlshdk/libs/utils/debug.h"
 #include "mysqlshdk/libs/utils/document_parser.h"
@@ -531,6 +530,11 @@ static std::string version_string(const char *argv0, bool extra) {
       version_msg.append(" - commit_id ");
       version_msg.append(MYSH_COMMIT_ID);
     }
+
+    if (*MYSH_PRODUCT_ID) {
+      version_msg.append(" - product_id ");
+      version_msg.append(MYSH_PRODUCT_ID);
+    }
   } else {
     snprintf(&version_msg[0], version_msg.size(), "%s   %s", argv0,
              shcore::get_long_version());
@@ -603,7 +607,7 @@ static void finalize_shell(mysqlsh::Command_line_shell *shell) {
   shell->restore_print();
 
   // shell needs to be destroyed before global_end() is called, because it
-  // needs to call destructors of JS contexts
+  // needs to call destructors of JS contexts before V8 is shut down
   delete shell;
 
   mysqlsh::global_end();
@@ -850,9 +854,27 @@ int main(int argc, char **argv) {
                 "insecure.");
           }
 
+          std::function<void(std::shared_ptr<mysqlshdk::db::ISession>)>
+              extra_init;
+
+          if (!options.register_factor.empty()) {
+            extra_init =
+                [&options](std::shared_ptr<mysqlshdk::db::ISession> session) {
+                  auto mysql_session =
+                      std::dynamic_pointer_cast<mysqlshdk::db::mysql::Session>(
+                          session);
+
+                  if (mysql_session) {
+                    mysqlshdk::db::mysql::fido::register_device(
+                        mysql_session->get_handle(),
+                        options.register_factor.c_str());
+                  }
+                };
+          }
+
           // Connect to the requested instance
           shell->connect(target, options.recreate_database, true,
-                         !options.prompt_password);
+                         std::move(extra_init));
 
           // If redirect is requested, then reconnect to the right instance
           handle_redirect(shell, options.redirect_session);
@@ -882,7 +904,7 @@ int main(int argc, char **argv) {
             options.redirect_session) {
           mysqlsh::current_console()->print_error(
               "The " + option_for(options.redirect_session) +
-              " option requires a session to a member of an InnoDB cluster or "
+              " option requires a session to a member of an InnoDB Cluster or "
               "ReplicaSet.");
           return 1;
         }
