@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -129,9 +127,12 @@ inline std::string to_utf8(const std::wstring &s) {
 
 namespace mysqlsh {
 
-const char *Prompt_renderer::k_symbol_sep_right_pl = u8"\ue0b0";
-const char *Prompt_renderer::k_symbol_sep_right_hollow_pl = u8"\ue0b1";
-const char *Prompt_renderer::k_symbol_ellipsis_pl = u8"\u2026";
+// U+E0B0
+const char *Prompt_renderer::k_symbol_sep_right_pl = "\xEE\x82\xB0";
+// U+E0B1
+const char *Prompt_renderer::k_symbol_sep_right_hollow_pl = "\xEE\x82\xB1";
+// U+2026
+const char *Prompt_renderer::k_symbol_ellipsis_pl = "\xE2\x80\xA6";
 
 class Prompt_segment {
  public:
