@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2022, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -74,7 +72,7 @@ TEST_F(Completion_cache_refresh, startup) {
   _options->devapi_schema_object_handles = true;
 
   // No connection, no refresh
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   reset_shell("", shcore::IShell_core::Mode::JavaScript);
   MY_EXPECT_STDOUT_NOT_CONTAINS("Creating a session to");
   MY_EXPECT_STDOUT_NOT_CONTAINS("for auto-completion");
@@ -90,7 +88,7 @@ TEST_F(Completion_cache_refresh, startup) {
 
   // Classic
   // Connection without default schema, refresh schemas only
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   reset_shell(_mysql_uri, shcore::IShell_core::Mode::JavaScript);
   MY_EXPECT_STDOUT_CONTAINS("Creating a session to");
   MY_EXPECT_STDOUT_CONTAINS("Fetching schema names for auto-completion");
@@ -105,7 +103,7 @@ TEST_F(Completion_cache_refresh, startup) {
   MY_EXPECT_STDOUT_CONTAINS("Fetching global names for auto-completion");
 
   // Connection with default schema, refresh schemas and objects
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   reset_shell(_mysql_uri + "/mysql", shcore::IShell_core::Mode::JavaScript);
   MY_EXPECT_STDOUT_CONTAINS("Creating a session to");
   MY_EXPECT_STDOUT_CONTAINS("Fetching schema names for auto-completion");
@@ -122,7 +120,7 @@ TEST_F(Completion_cache_refresh, startup) {
 
   // X proto
   // Connection without default schema, refresh schemas only
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   reset_shell(_uri, shcore::IShell_core::Mode::JavaScript);
   MY_EXPECT_STDOUT_CONTAINS("Creating a session to");
   MY_EXPECT_STDOUT_CONTAINS("Fetching schema names for auto-completion");
@@ -137,7 +135,7 @@ TEST_F(Completion_cache_refresh, startup) {
   MY_EXPECT_STDOUT_CONTAINS("Fetching global names for auto-completion");
 
   // Connection with default schema, refresh schemas and objects
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   reset_shell(_uri + "/mysql", shcore::IShell_core::Mode::JavaScript);
   MY_EXPECT_STDOUT_CONTAINS("Creating a session to");
   MY_EXPECT_STDOUT_CONTAINS("Fetching schema names for auto-completion");
@@ -168,7 +166,7 @@ TEST_F(Completion_cache_refresh, connect_interactive) {
   _options->devapi_schema_object_handles = true;
 
   // Start with no connection
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   reset_shell("", shcore::IShell_core::Mode::JavaScript);
   MY_EXPECT_STDOUT_NOT_CONTAINS("Creating a session to");
   MY_EXPECT_STDOUT_NOT_CONTAINS("for auto-completion");
@@ -235,7 +233,7 @@ TEST_F(Completion_cache_refresh, switch_to_sql) {
   _options->devapi_schema_object_handles = true;
 
   shcore::IShell_core::Mode scripting_mode;
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   scripting_mode = shcore::IShell_core::Mode::JavaScript;
 #else
   scripting_mode = shcore::IShell_core::Mode::Python;
@@ -284,7 +282,7 @@ TEST_F(Completion_cache_refresh, switch_schema_js) {
   _options->db_name_cache = true;
   _options->devapi_schema_object_handles = true;
 
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   reset_shell(_mysql_uri, shcore::IShell_core::Mode::JavaScript);
 #else
   reset_shell(_mysql_uri, shcore::IShell_core::Mode::Python);
@@ -316,7 +314,7 @@ TEST_F(Completion_cache_refresh, switch_schema_sql) {
       "Fetching global names, object names from `information_schema` for "
       "auto-completion");
 
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   reset_shell(_mysql_uri, shcore::IShell_core::Mode::JavaScript);
 #else
   reset_shell(_mysql_uri, shcore::IShell_core::Mode::Python);
@@ -375,7 +373,7 @@ TEST_F(Completion_cache_refresh, rehash_db) {
   _options->devapi_schema_object_handles = true;
 
   // Check that rehash also updates the object cache in db
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   reset_shell(_uri, shcore::IShell_core::Mode::JavaScript);
 #else
   reset_shell(_uri, shcore::IShell_core::Mode::Python);
@@ -404,7 +402,7 @@ TEST_F(Completion_cache_refresh, rehash_db) {
 
   _options->devapi_schema_object_handles = true;
 
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   reset_shell(_uri + "/mysql", shcore::IShell_core::Mode::JavaScript);
 #else
   reset_shell(_uri + "/mysql", shcore::IShell_core::Mode::Python);
@@ -423,7 +421,7 @@ TEST_F(Completion_cache_refresh, rehash_db) {
 
   _options->devapi_schema_object_handles = false;
 
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   const std::string bool_true = "true";
   const std::string bool_false = "false";
   reset_shell(_uri + "/mysql", shcore::IShell_core::Mode::JavaScript);
@@ -466,7 +464,7 @@ TEST_F(Completion_cache_refresh, rehash_db) {
 TEST_F(Completion_cache_refresh, options_db_object_handles) {
   _options->db_name_cache = true;
   _options->devapi_schema_object_handles = true;
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   const std::string bool_true = "true";
   const std::string bool_false = "false";
   reset_shell(_uri + "/mysql", shcore::IShell_core::Mode::JavaScript);
@@ -480,7 +478,7 @@ TEST_F(Completion_cache_refresh, options_db_object_handles) {
 
   _options->db_name_cache = true;
   _options->devapi_schema_object_handles = false;
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   reset_shell(_uri + "/mysql", shcore::IShell_core::Mode::JavaScript);
 #else
   reset_shell(_uri + "/mysql", shcore::IShell_core::Mode::Python);
@@ -520,7 +518,7 @@ TEST_F(Completion_cache_refresh, options_db_name_cache) {
   _options->db_name_cache = true;
   _options->devapi_schema_object_handles = true;
 
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   reset_shell(_uri + "/mysql", shcore::IShell_core::Mode::JavaScript);
 #else
   reset_shell(_uri + "/mysql", shcore::IShell_core::Mode::Python);
