@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2020, 2024, Oracle and/or its affiliates.
+ * Copyright (c) 2020, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -575,13 +573,13 @@ class Load_dump_mocked : public Shell_core_test_wrapper {
   }
 
   template <typename... Options>
-  void load_dump(int num_threads, bool check_scheduling, Options &&...opts) {
+  void load_dump(int num_threads, bool check_scheduling, Options &&... opts) {
     auto dir = std::make_unique<tests::Dummy_dump_directory>(
         shcore::path::join_path(g_test_home, "data/load/test_dump1"),
         test_dump1_files, test_dump1_files_size);
 
     Load_dump_options options;
-    options.set_session(make_mock_main_session(), "");
+    options.set_session(make_mock_main_session());
 
     Load_dump_options::options().unpack(
         shcore::make_dict("threads", num_threads, "showProgress", false,
@@ -679,7 +677,7 @@ TEST_F(Load_dump_mocked, filter_user_script_for_mds) {
       .then({"Variable_name", "Value"})
       .add_row({"partial_revokes", "OFF"});
 
-  options.set_session(mock_main_session, "");
+  options.set_session(mock_main_session);
 
   Dump_loader loader(options);
 
