@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2018, 2024, Oracle and/or its affiliates.
+ * Copyright (c) 2018, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -34,7 +32,7 @@
 
 namespace tests {
 
-#ifdef HAVE_JS
+#ifdef HAVE_V8
 
 #define SCRIPTING_LANGUAGE "JavaScript"
 #define SCRIPTING_LANGUAGE_SHORT "js"
@@ -114,6 +112,8 @@ class Pager_initialization_test : public Mysqlsh_pager_test {
   void run(bool with_pager = false) {
     std::vector<const char *> args = {_mysqlsh, SCRIPTING_MODE,
                                       "--interactive"};
+    // workaround for GCC12 -Werror=array-bounds false-positive
+    args.reserve(5);
 
     if (with_pager) {
       args.emplace_back(k_cmdline_pager);
