@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2018, 2024, Oracle and/or its affiliates.
+ * Copyright (c) 2018, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -120,12 +118,12 @@ class Mysqlsh_extension_test : public Command_line_test {
   }
 
   void add_js_test(const std::string &input, const std::string &output = "") {
-#ifdef HAVE_JS
+#ifdef HAVE_V8
     add_test(input, output);
 #else
     (void)input;
     (void)output;
-#endif  // HAVE_JS
+#endif  // HAVE_V8
   }
 
   void add_py_test(const std::string &input, const std::string &output = "") {
@@ -146,11 +144,11 @@ class Mysqlsh_extension_test : public Command_line_test {
   }
 
   void add_expected_js_log(const std::string &expected) {
-#ifdef HAVE_JS
+#ifdef HAVE_V8
     add_expected_log(expected);
 #else
     (void)expected;
-#endif  // HAVE_JS
+#endif  // HAVE_V8
   }
 
   void add_expected_py_log(const std::string &expected) {
@@ -162,11 +160,11 @@ class Mysqlsh_extension_test : public Command_line_test {
   }
 
   void add_unexpected_js_log(const std::string &unexpected) {
-#ifdef HAVE_JS
+#ifdef HAVE_V8
     add_unexpected_log(unexpected);
 #else
     (void)unexpected;
-#endif  // HAVE_JS
+#endif  // HAVE_V8
   }
 
   void add_unexpected_py_log(const std::string &unexpected) {
@@ -423,9 +421,9 @@ global_py_variable = 'PY variable'
 
   add_js_test("\\js", "Switching to JavaScript mode...");
   add_js_test("js_report(null, null);",
-              "js_report is not defined (ReferenceError)");
+              "ReferenceError: js_report is not defined");
   add_js_test("global_js_variable",
-              "global_js_variable is not defined (ReferenceError)");
+              "ReferenceError: global_js_variable is not defined");
   add_js_test("dba", "<Dba>");
 
   add_py_test("\\py", "Switching to Python mode...");
@@ -1080,9 +1078,13 @@ shell.register_global('errtest', obj)
       "mysql.get_session: Access denied for user 'rooot'@'localhost' (using "
       "password: YES)");
 
-  MY_EXPECT_CMD_OUTPUT_CONTAINS("js error got thrown");
-  MY_EXPECT_CMD_OUTPUT_CONTAINS("js another error got thrown");
-  MY_EXPECT_CMD_OUTPUT_CONTAINS("");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS(
+      "errtest.throwError: js error got thrown (RuntimeError)");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS(
+      "errtest.throwError: js another error got thrown (MYSQLSH 99998)");
+  MY_EXPECT_CMD_OUTPUT_CONTAINS(
+      "errtest.connect: mysql.get_session: Access denied for user "
+      "'raaat'@'localhost' (using password: YES) (MySQL Error 1045)");
 
   wipe_out();
   delete_user_plugin("error-reporting");
@@ -1290,9 +1292,8 @@ shell.register_global('kwtest', obj)
   // TEST: Passing named argument for parameter already defined but in a
   // dictionary (See BUG#31500843 For More Details)
   add_py_test("kwtest.print_args('Black', 'Pearl', {'name': 'allowed'})",
-              "ScriptingError: kwtest.print_args: User-defined "
-              "function threw an exception: print_args() got multiple values "
-              "for argument 'name'");
+              "ScriptingError: kwtest.print_args: print_args() got multiple "
+              "values for argument 'name'");
 
   // run the test
   run({"--log-level=debug"});
@@ -1351,8 +1352,8 @@ shell.register_global('kwtest', obj)
   // TEST: Passing named argument for parameter already defined but in a
   // dictionary (See BUG#31500843 For More Details)
   add_py_test("kwtest.printArgs('Black', 'Pearl', {name: 'allowed'})",
-              "kwtest.printArgs: User-defined function threw an exception: "
-              "print_args() got multiple values for argument 'name'");
+              "kwtest.printArgs: print_args() got multiple values for argument "
+              "'name' (ScriptingError)");
 
   // run the test
   run({"--log-level=debug"});
