@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2018, 2024, Oracle and/or its affiliates.
+ * Copyright (c) 2018, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -202,19 +200,17 @@ TEST_F(Config_server_handler_test, config_interface_global_vars) {
   EXPECT_FALSE(!string_val.has_value());
   EXPECT_STREQ("pt_PT", (*string_val).c_str());
 
-  // Restore previous setting directly on the server, using set_now().
-  // NOTE: Use 1 ms delay to set one of the variables.
-  SCOPED_TRACE("Restore initial settings using set_now().");
-  cfg_h.set_now("sql_warnings", std::optional<bool>(false),
-                Var_qualifier::GLOBAL, std::chrono::milliseconds{1});
-  cfg_h.set_now("wait_timeout", wait_timeout, Var_qualifier::GLOBAL);
-  cfg_h.set_now("lc_messages", std::optional<std::string>("en_US"),
-                Var_qualifier::GLOBAL);
-  cfg_h.set_now("sql_warnings", std::optional<bool>(false),
-                Var_qualifier::SESSION, std::chrono::milliseconds{1});
-  cfg_h.set_now("wait_timeout", wait_timeout, Var_qualifier::SESSION);
-  cfg_h.set_now("lc_messages", std::optional<std::string>("en_US"),
-                Var_qualifier::SESSION);
+  // Restore previous setting directly on the server.
+  SCOPED_TRACE("Restore initial settings.");
+  cfg_h.set("sql_warnings", std::optional<bool>(false), Var_qualifier::GLOBAL);
+  cfg_h.set("wait_timeout", wait_timeout, Var_qualifier::GLOBAL);
+  cfg_h.set("lc_messages", std::optional<std::string>("en_US"),
+            Var_qualifier::GLOBAL);
+  cfg_h.set("sql_warnings", std::optional<bool>(false), Var_qualifier::SESSION);
+  cfg_h.set("wait_timeout", wait_timeout, Var_qualifier::SESSION);
+  cfg_h.set("lc_messages", std::optional<std::string>("en_US"),
+            Var_qualifier::SESSION);
+  cfg_h.apply();
 
   // Confirm values where restored properly.
   SCOPED_TRACE("Verify initail settings were restored.");
@@ -377,21 +373,17 @@ TEST_F(Config_server_handler_test, config_interface_session_vars) {
   EXPECT_FALSE(!string_val.has_value());
   EXPECT_STREQ("pt_PT", (*string_val).c_str());
 
-  // Restore previous setting directly on the server, using set_now().
-  // NOTE: Use 1 ms delay to set one of the variables.
+  // Restore previous setting directly on the server.
   SCOPED_TRACE("Restore initial settings using set_now().");
-  cfg_h.set_now("sql_warnings", std::optional<bool>(false),
-                Var_qualifier::SESSION);
-  cfg_h.set_now("wait_timeout", wait_timeout, Var_qualifier::SESSION,
-                std::chrono::milliseconds{1});
-  cfg_h.set_now("lc_messages", std::optional<std::string>("en_US"),
-                Var_qualifier::SESSION);
-  cfg_h.set_now("sql_warnings", std::optional<bool>(false),
-                Var_qualifier::GLOBAL);
-  cfg_h.set_now("wait_timeout", wait_timeout, Var_qualifier::GLOBAL,
-                std::chrono::milliseconds{1});
-  cfg_h.set_now("lc_messages", std::optional<std::string>("en_US"),
-                Var_qualifier::GLOBAL);
+  cfg_h.set("sql_warnings", std::optional<bool>(false), Var_qualifier::SESSION);
+  cfg_h.set("wait_timeout", wait_timeout, Var_qualifier::SESSION);
+  cfg_h.set("lc_messages", std::optional<std::string>("en_US"),
+            Var_qualifier::SESSION);
+  cfg_h.set("sql_warnings", std::optional<bool>(false), Var_qualifier::GLOBAL);
+  cfg_h.set("wait_timeout", wait_timeout, Var_qualifier::GLOBAL);
+  cfg_h.set("lc_messages", std::optional<std::string>("en_US"),
+            Var_qualifier::GLOBAL);
+  cfg_h.apply();
 
   // Confirm values where restored properly.
   SCOPED_TRACE("Verify initail settings were restored.");
@@ -463,44 +455,29 @@ TEST_F(Config_server_handler_test, errors) {
                               Var_qualifier::SESSION),
                     std::invalid_argument,
                     "The value parameter cannot be null.");
-  EXPECT_THROW_LIKE(cfg_h.set_now("sql_warnings", std::optional<bool>(),
-                                  Var_qualifier::GLOBAL),
-                    std::invalid_argument,
-                    "The value parameter cannot be null.");
-  EXPECT_THROW_LIKE(cfg_h.set_now("wait_timeout", std::optional<int64_t>(),
-                                  Var_qualifier::GLOBAL),
-                    std::invalid_argument,
-                    "The value parameter cannot be null.");
-  EXPECT_THROW_LIKE(cfg_h.set_now("lc_messages", std::optional<std::string>(),
-                                  Var_qualifier::GLOBAL),
-                    std::invalid_argument,
-                    "The value parameter cannot be null.");
-
-  // Error if trying to immediately set a variable that does not exists.
-  EXPECT_THROW_LIKE(cfg_h.set_now("not-exist", std::optional<bool>(true),
-                                  Var_qualifier::GLOBAL),
-                    mysqlshdk::db::Error,
-                    "Unknown system variable 'not-exist'");
-  EXPECT_THROW_LIKE(cfg_h.set_now("not-exist", std::optional<int64_t>(1234),
-                                  Var_qualifier::GLOBAL),
-                    mysqlshdk::db::Error,
-                    "Unknown system variable 'not-exist'");
   EXPECT_THROW_LIKE(
-      cfg_h.set_now("not-exist", std::optional<std::string>("mystr"),
-                    Var_qualifier::GLOBAL),
-      mysqlshdk::db::Error, "Unknown system variable 'not-exist'");
+      cfg_h.set("sql_warnings", std::optional<bool>(), Var_qualifier::GLOBAL),
+      std::invalid_argument, "The value parameter cannot be null.");
+  EXPECT_THROW_LIKE(cfg_h.set("wait_timeout", std::optional<int64_t>(),
+                              Var_qualifier::GLOBAL),
+                    std::invalid_argument,
+                    "The value parameter cannot be null.");
+  EXPECT_THROW_LIKE(cfg_h.set("lc_messages", std::optional<std::string>(),
+                              Var_qualifier::GLOBAL),
+                    std::invalid_argument,
+                    "The value parameter cannot be null.");
 
   // Error if trying to apply a variable that does not exists.
   cfg_h.set("not-exist-bool", std::optional<bool>(true));
-  EXPECT_THROW_LIKE(cfg_h.apply(), mysqlshdk::db::Error,
+  EXPECT_THROW_LIKE(cfg_h.apply(true), mysqlshdk::db::Error,
                     "Unknown system variable 'not-exist-bool'");
   Config_server_handler cfg_h2(&instance, Var_qualifier::GLOBAL);
   cfg_h2.set("not-exist-int", std::optional<int64_t>(1234));
-  EXPECT_THROW_LIKE(cfg_h2.apply(), mysqlshdk::db::Error,
+  EXPECT_THROW_LIKE(cfg_h2.apply(true), mysqlshdk::db::Error,
                     "Unknown system variable 'not-exist-int'");
   Config_server_handler cfg_h3(&instance, Var_qualifier::GLOBAL);
   cfg_h3.set("not-exist-string", std::optional<std::string>("mystr"));
-  EXPECT_THROW_LIKE(cfg_h3.apply(), mysqlshdk::db::Error,
+  EXPECT_THROW_LIKE(cfg_h3.apply(true), mysqlshdk::db::Error,
                     "Unknown system variable 'not-exist-string'");
 }
 
@@ -570,7 +547,7 @@ TEST_F(Config_server_handler_test, apply_errors) {
     SCOPED_TRACE("Error applying bool value setting (no context).");
     Config_server_handler cfg_h(&instance, Var_qualifier::GLOBAL);
     cfg_h.set("not_exit_bool", std::optional<bool>(true));
-    EXPECT_THROW_LIKE(cfg_h.apply(), std::runtime_error,
+    EXPECT_THROW_LIKE(cfg_h.apply(true), std::runtime_error,
                       "Unknown system variable 'not_exit_bool'");
   }
 
@@ -578,7 +555,7 @@ TEST_F(Config_server_handler_test, apply_errors) {
     SCOPED_TRACE("Error applying bool value setting (with context).");
     Config_server_handler cfg_h(&instance, Var_qualifier::GLOBAL);
     cfg_h.set("not_exit_bool", std::optional<bool>(true), "notExistBool");
-    EXPECT_THROW_LIKE(cfg_h.apply(), std::runtime_error,
+    EXPECT_THROW_LIKE(cfg_h.apply(true), std::runtime_error,
                       "Unable to set value 'true' for 'notExistBool': Unknown "
                       "system variable 'not_exit_bool'");
   }
@@ -587,7 +564,7 @@ TEST_F(Config_server_handler_test, apply_errors) {
     SCOPED_TRACE("Error applying int value setting (no context).");
     Config_server_handler cfg_h(&instance, Var_qualifier::GLOBAL);
     cfg_h.set("not_exit_int", std::optional<int64_t>(1234));
-    EXPECT_THROW_LIKE(cfg_h.apply(), std::runtime_error,
+    EXPECT_THROW_LIKE(cfg_h.apply(true), std::runtime_error,
                       "Unknown system variable 'not_exit_int'");
   }
 
@@ -595,7 +572,7 @@ TEST_F(Config_server_handler_test, apply_errors) {
     SCOPED_TRACE("Error applying int value setting (with context).");
     Config_server_handler cfg_h(&instance, Var_qualifier::GLOBAL);
     cfg_h.set("not_exit_int", std::optional<int64_t>(1234), "notExistInt");
-    EXPECT_THROW_LIKE(cfg_h.apply(), std::runtime_error,
+    EXPECT_THROW_LIKE(cfg_h.apply(true), std::runtime_error,
                       "Unable to set value '1234' for 'notExistInt': Unknown "
                       "system variable 'not_exit_int'");
   }
@@ -604,7 +581,7 @@ TEST_F(Config_server_handler_test, apply_errors) {
     SCOPED_TRACE("Error applying string value setting (no context).");
     Config_server_handler cfg_h(&instance, Var_qualifier::GLOBAL);
     cfg_h.set("not_exit_string", std::optional<std::string>("mystr"));
-    EXPECT_THROW_LIKE(cfg_h.apply(), std::runtime_error,
+    EXPECT_THROW_LIKE(cfg_h.apply(true), std::runtime_error,
                       "Unknown system variable 'not_exit_string'");
   }
 
@@ -613,7 +590,7 @@ TEST_F(Config_server_handler_test, apply_errors) {
     Config_server_handler cfg_h(&instance, Var_qualifier::GLOBAL);
     cfg_h.set("not_exit_string", std::optional<std::string>("mystr"),
               "notExistString");
-    EXPECT_THROW_LIKE(cfg_h.apply(), std::runtime_error,
+    EXPECT_THROW_LIKE(cfg_h.apply(true), std::runtime_error,
                       "Unable to set value 'mystr' for 'notExistString': "
                       "Unknown system variable 'not_exit_string'");
   }
@@ -631,8 +608,8 @@ TEST_F(Config_server_handler_test, get_persisted_value) {
     EXPECT_TRUE(!res);
 
     // Get variable with persisted value.
-    cfg_h.set_now("gtid_mode", std::optional<std::string>("ON"),
-                  Var_qualifier::PERSIST_ONLY);
+    instance.set_sysvar("gtid_mode", std::string{"ON"},
+                        Var_qualifier::PERSIST_ONLY);
     res = cfg_h.get_persisted_value("gtid_mode");
     EXPECT_FALSE(!res);
     EXPECT_STREQ("ON", (*res).c_str());
@@ -647,4 +624,146 @@ TEST_F(Config_server_handler_test, get_persisted_value) {
   }
 }
 
+TEST_F(Config_server_handler_test, undo) {
+  mysqlshdk::mysql::Instance instance(m_session);
+  Config_server_handler cfg_h(&instance, Var_qualifier::GLOBAL);
+
+  // default values
+  instance.set_sysvar("auto_increment_increment", int64_t{11},
+                      Var_qualifier::GLOBAL);
+  instance.set_sysvar("enforce_gtid_consistency", bool{true},
+                      Var_qualifier::GLOBAL);
+  instance.set_sysvar("character_set_client", std::string{"greek"},
+                      Var_qualifier::GLOBAL);
+
+  cfg_h.set("auto_increment_increment", std::optional<int64_t>(10));
+  cfg_h.set("auto_increment_increment", std::optional<int64_t>(9));
+  cfg_h.set("enforce_gtid_consistency", std::optional<bool>(false));
+  cfg_h.set("character_set_client", std::optional<std::string>("latin2"));
+  cfg_h.apply();
+
+  cfg_h.undo_changes();
+
+  {
+    auto var = instance.get_sysvar_int("auto_increment_increment");
+    EXPECT_TRUE(var.has_value());
+    EXPECT_EQ(var.value(), 11);
+  }
+
+  {
+    auto var = instance.get_sysvar_bool("enforce_gtid_consistency");
+    EXPECT_TRUE(var.has_value());
+    EXPECT_EQ(var.value(), true);
+  }
+
+  {
+    auto var = instance.get_sysvar_string("character_set_client");
+    EXPECT_TRUE(var.has_value());
+    EXPECT_EQ(var.value(), "greek");
+  }
+
+  // reset values
+  instance.set_sysvar_default("auto_increment_increment",
+                              Var_qualifier::GLOBAL);
+  instance.set_sysvar_default("enforce_gtid_consistency",
+                              Var_qualifier::GLOBAL);
+  instance.set_sysvar_default("character_set_client", Var_qualifier::GLOBAL);
+}
+
+TEST_F(Config_server_handler_test, undo_ignore) {
+  mysqlshdk::mysql::Instance instance(m_session);
+  Config_server_handler cfg_h(&instance, Var_qualifier::GLOBAL);
+
+  // default values
+  instance.set_sysvar("auto_increment_increment", int64_t{11},
+                      Var_qualifier::GLOBAL);
+  instance.set_sysvar("enforce_gtid_consistency", bool{true},
+                      Var_qualifier::GLOBAL);
+  instance.set_sysvar("character_set_client", std::string{"greek"},
+                      Var_qualifier::GLOBAL);
+
+  cfg_h.remove_from_undo("enforce_gtid_consistency");
+
+  cfg_h.set("auto_increment_increment", std::optional<int64_t>(10));
+  cfg_h.set("auto_increment_increment", std::optional<int64_t>(9));
+  cfg_h.set("enforce_gtid_consistency", std::optional<bool>(false));
+  cfg_h.set("character_set_client", std::optional<std::string>("latin2"));
+  cfg_h.apply();
+
+  cfg_h.remove_from_undo("character_set_client");
+  cfg_h.undo_changes();
+
+  {
+    auto var = instance.get_sysvar_int("auto_increment_increment");
+    EXPECT_TRUE(var.has_value());
+    EXPECT_EQ(var.value(), 11);
+  }
+
+  {
+    auto var = instance.get_sysvar_bool("enforce_gtid_consistency");
+    EXPECT_TRUE(var.has_value());
+    EXPECT_EQ(var.value(), false);
+  }
+
+  {
+    auto var = instance.get_sysvar_string("character_set_client");
+    EXPECT_TRUE(var.has_value());
+    EXPECT_EQ(var.value(), "latin2");
+  }
+
+  // reset values
+  instance.set_sysvar_default("auto_increment_increment",
+                              Var_qualifier::GLOBAL);
+  instance.set_sysvar_default("enforce_gtid_consistency",
+                              Var_qualifier::GLOBAL);
+  instance.set_sysvar_default("character_set_client", Var_qualifier::GLOBAL);
+}
+
+TEST_F(Config_server_handler_test, undo_ignore_all) {
+  mysqlshdk::mysql::Instance instance(m_session);
+  Config_server_handler cfg_h(&instance, Var_qualifier::GLOBAL);
+
+  // default values
+  instance.set_sysvar("auto_increment_increment", int64_t{11},
+                      Var_qualifier::GLOBAL);
+  instance.set_sysvar("enforce_gtid_consistency", bool{false},
+                      Var_qualifier::GLOBAL);
+  instance.set_sysvar("character_set_client", std::string{"greek"},
+                      Var_qualifier::GLOBAL);
+
+  cfg_h.set("auto_increment_increment", std::optional<int64_t>(10));
+  cfg_h.set("auto_increment_increment", std::optional<int64_t>(9));
+  cfg_h.set("enforce_gtid_consistency", std::optional<bool>(true));
+  cfg_h.set("character_set_client", std::optional<std::string>("latin2"));
+  cfg_h.apply();
+
+  cfg_h.remove_all_from_undo();
+  cfg_h.undo_changes();
+
+  {
+    auto var = instance.get_sysvar_int("auto_increment_increment");
+    EXPECT_TRUE(var.has_value());
+    EXPECT_EQ(var.value(), 9);
+  }
+
+  {
+    auto var = instance.get_sysvar_bool("enforce_gtid_consistency");
+    EXPECT_TRUE(var.has_value());
+    EXPECT_EQ(var.value(), true);
+  }
+
+  {
+    auto var = instance.get_sysvar_string("character_set_client");
+    EXPECT_TRUE(var.has_value());
+    EXPECT_EQ(var.value(), "latin2");
+  }
+
+  // reset values
+  instance.set_sysvar_default("auto_increment_increment",
+                              Var_qualifier::GLOBAL);
+  instance.set_sysvar_default("enforce_gtid_consistency",
+                              Var_qualifier::GLOBAL);
+  instance.set_sysvar_default("character_set_client", Var_qualifier::GLOBAL);
+}
+
 }  // namespace testing
