@@ -16,14 +16,13 @@ var configure_instance_sql = [
     "select @@port, @@datadir",
     "SELECT DISTINCT grantee FROM information_schema.user_privileges WHERE grantee like",
     "show GLOBAL variables where `variable_name` in ('binlog_format')",
-    "SET * `binlog_format` = 'ROW'"
 ];
 
 var create_cluster_sql = [
     "SELECT @@hostname, @@report_host",
     "SELECT plugin_status FROM information_schema.plugins WHERE plugin_name = 'group_replication'",
     "START GROUP_REPLICATION",
-    "CHANGE MASTER TO MASTER_USER = /*(*/ 'mysql_innodb_cluster_*' /*)*/, MASTER_PASSWORD = **** FOR CHANNEL 'group_replication_recovery'",
+    "change " + get_replication_source_keyword() + " TO " + get_replication_option_keyword() + "_USER = /*(*/ 'mysql_innodb_cluster_*' /*)*/, " + get_replication_option_keyword() + "_PASSWORD = **** FOR CHANNEL 'group_replication_recovery'",
     "CHANGE REPLICATION SOURCE TO SOURCE_USER = /*(*/ 'mysql_innodb_cluster_*' /*)*/, SOURCE_PASSWORD = **** FOR CHANNEL 'group_replication_recovery'",
 ];
 
@@ -48,7 +47,7 @@ var check_instance_state_sql = [
 ];
 
 var rejoin_instance_sql = [
-    "SELECT",
+    "SELECT ",
     "START GROUP_REPLICATION"
 ];
 
@@ -183,7 +182,6 @@ dba.configureInstance(__sandbox_uri1, {mycnfPath: mycnf1});
 EXPECT_SHELL_LOG_NOT_CONTAINS(configure_instance_sql[0]);
 EXPECT_SHELL_LOG_NOT_CONTAINS(configure_instance_sql[1]);
 EXPECT_SHELL_LOG_NOT_CONTAINS(configure_instance_sql[2]);
-EXPECT_SHELL_LOG_NOT_CONTAINS(configure_instance_sql[3]);
 
 //@<> WL#13294: create cluster (dba.logSql = 0).
 WIPE_SHELL_LOG();
@@ -420,7 +418,6 @@ dba.configureInstance(__sandbox_uri1, {mycnfPath: mycnf1});
 EXPECT_SHELL_LOG_NOT_CONTAINS(configure_instance_sql[0]);
 EXPECT_SHELL_LOG_NOT_CONTAINS(configure_instance_sql[1]);
 EXPECT_SHELL_LOG_NOT_CONTAINS(configure_instance_sql[2]);
-EXPECT_SHELL_LOG_CONTAINS(configure_instance_sql[3]);
 
 //@<> WL#13294: create cluster (dba.logSql = 1).
 WIPE_SHELL_LOG();
@@ -440,7 +437,11 @@ EXPECT_SHELL_LOG_NOT_CONTAINS(add_instance_sql[0]);
 EXPECT_SHELL_LOG_NOT_CONTAINS(add_instance_sql[1]);
 EXPECT_SHELL_LOG_NOT_CONTAINS(add_instance_sql[2]);
 EXPECT_SHELL_LOG_CONTAINS(add_instance_sql[3]);
-EXPECT_SHELL_LOG_CONTAINS(add_instance_sql[4]);
+if (__version_num < 80000) {
+    EXPECT_SHELL_LOG_CONTAINS(add_instance_sql[4]);
+} else {
+    EXPECT_SHELL_LOG_NOT_CONTAINS(add_instance_sql[4]);
+}
 EXPECT_SHELL_LOG_CONTAINS(add_instance_sql[5]);
 
 //@<> WL#13294: check instance state (dba.logSql = 1).
@@ -658,7 +659,6 @@ dba.configureInstance(__sandbox_uri1, {mycnfPath: mycnf1});
 EXPECT_SHELL_LOG_CONTAINS(configure_instance_sql[0]);
 EXPECT_SHELL_LOG_CONTAINS(configure_instance_sql[1]);
 EXPECT_SHELL_LOG_CONTAINS(configure_instance_sql[2]);
-EXPECT_SHELL_LOG_CONTAINS(configure_instance_sql[3]);
 
 //@<> WL#13294: create cluster (dba.logSql = 2).
 WIPE_SHELL_LOG();
@@ -678,7 +678,11 @@ EXPECT_SHELL_LOG_CONTAINS(add_instance_sql[0]);
 EXPECT_SHELL_LOG_CONTAINS(add_instance_sql[1]);
 EXPECT_SHELL_LOG_CONTAINS(add_instance_sql[2]);
 EXPECT_SHELL_LOG_CONTAINS(add_instance_sql[3]);
-EXPECT_SHELL_LOG_CONTAINS(add_instance_sql[4]);
+if (__version_num < 80000) {
+    EXPECT_SHELL_LOG_CONTAINS(add_instance_sql[4]);
+} else {
+    EXPECT_SHELL_LOG_NOT_CONTAINS(add_instance_sql[4]);
+}
 EXPECT_SHELL_LOG_CONTAINS(add_instance_sql[5]);
 
 //@<> WL#13294: check instance state (dba.logSql = 2).
