@@ -35,7 +35,7 @@ FUNCTIONS
             InnoDB Cluster.
 
       describe()
-            Describe the structure of the cluster.
+            Describe the structure of the Cluster.
 
       disconnect()
             Disconnects all internal sessions used by the cluster object.
@@ -80,7 +80,8 @@ FUNCTIONS
             Rescans the cluster.
 
       resetRecoveryAccountsPassword(options)
-            Reset the password of the recovery accounts of the cluster.
+            Resets the password of the recovery and replication accounts of the
+            Cluster.
 
       routingOptions([router])
             Lists the Cluster Routers configuration options.
@@ -105,7 +106,7 @@ FUNCTIONS
             Create or upgrade a MySQL account to use with MySQL Router.
 
       status([options])
-            Describe the status of the cluster.
+            Describe the status of the Cluster.
 
       switchToMultiPrimaryMode()
             Switches the cluster to multi-primary mode.
@@ -155,7 +156,7 @@ DESCRIPTION
         the recovery process to finish and its verbosity level. Deprecated.
       - recoveryProgress: Integer value to indicate the recovery process
         verbosity level.
-      - password: the instance connection password
+      - password: the instance connection password. Deprecated.
       - memberSslMode: SSL mode used on the instance
       - ipWhitelist: The list of hosts allowed to connect to the instance for
         group replication. Deprecated.
@@ -179,6 +180,10 @@ DESCRIPTION
       - certSubject: instance's certificate subject to use when
         'memberAuthType' contains "CERT_SUBJECT".
 
+      The label must be non-empty and no greater than 256 characters long. It
+      must be unique within the Cluster and can only contain alphanumeric, _
+      (underscore), . (period), - (hyphen), or : (colon) characters.
+
       The password may be contained on the instance definition, however, it can
       be overwritten if it is specified on the options.
 
@@ -300,6 +305,8 @@ DESCRIPTION
 
       ATTENTION: The interactive option will be removed in a future release.
 
+      ATTENTION: The password option will be removed in a future release.
+
 //@<OUT> Check Instance State
 NAME
       checkInstanceState - Verifies the instance gtid state in relation to the
@@ -347,28 +354,28 @@ DESCRIPTION
 
 //@<OUT> Describe
 NAME
-      describe - Describe the structure of the cluster.
+      describe - Describe the structure of the Cluster.
 
 SYNTAX
       <Cluster>.describe()
 
 RETURNS
-      A JSON object describing the structure of the cluster.
+      A JSON object describing the structure of the Cluster.
 
 DESCRIPTION
-      This function describes the structure of the cluster including all its
-      information, ReplicaSets and Instances.
+      This function describes the structure of the Cluster including all its
+      information and members.
 
       The returned JSON object contains the following attributes:
 
-      - clusterName: the cluster name
+      - clusterName: the name of the Cluster
       - defaultReplicaSet: the default ReplicaSet object
 
       The defaultReplicaSet JSON object contains the following attributes:
 
-      - name: the ReplicaSet name
+      - name: the ReplicaSet name (default)
       - topology: a list of dictionaries describing each instance belonging to
-        the ReplicaSet.
+        the Cluster.
       - topologyMode: the InnoDB Cluster topology mode.
 
       Each instance dictionary contains the following attributes:
@@ -376,7 +383,6 @@ DESCRIPTION
       - address: the instance address in the form of host:port
       - label: the instance name identifier
       - role: the instance role
-      - version: the instance version (only available for instances >= 8.0.11)
 
 //@<OUT> Disconnect
 NAME
@@ -442,7 +448,7 @@ SYNTAX
 
 WHERE
       instance: An instance definition to derive the forced group from.
-      password: String with the password for the connection.
+      password: String with the password for the connection. Deprecated.
 
 RETURNS
       Nothing.
@@ -465,6 +471,8 @@ DESCRIPTION
       point of view of the given instance definition will be added to the
       group.
 
+      ATTENTION: The password option will be removed in a future release.
+
 //@<OUT> Get Name
 NAME
       getName - Retrieves the name of the cluster.
@@ -592,7 +600,7 @@ DESCRIPTION
 
       The options dictionary may contain the following attributes:
 
-      - password: the instance connection password
+      - password: the instance connection password. Deprecated.
       - recoveryMethod: Preferred method of state recovery. May be auto, clone
         or incremental. Default is auto.
       - recoveryProgress: Integer value to indicate the recovery process
@@ -679,6 +687,8 @@ DESCRIPTION
 
       ATTENTION: The interactive option will be removed in a future release.
 
+      ATTENTION: The password option will be removed in a future release.
+
 //@<OUT> Remove Instance
 NAME
       removeInstance - Removes an Instance from the cluster.
@@ -702,7 +712,7 @@ DESCRIPTION
 
       The options dictionary may contain the following attributes:
 
-      - password: the instance connection password
+      - password: the instance connection password. Deprecated.
       - force: boolean, indicating if the instance must be removed (even if
         only from metadata) in case it cannot be reached. By default, set to
         false.
@@ -729,6 +739,8 @@ DESCRIPTION
 
       ATTENTION: The interactive option will be removed in a future release.
 
+      ATTENTION: The password option will be removed in a future release.
+
 //@<OUT> SetInstanceOption
 NAME
       setInstanceOption - Changes the value of an option in a Cluster member.
@@ -835,6 +847,10 @@ DESCRIPTION
             useful to shut down the instance and perform maintenance on it
             without disrupting incoming application traffic.
 
+      The label must be non-empty and no greater than 256 characters long. It
+      must be unique within the Cluster and can only contain alphanumeric, _
+      (underscore), . (period), - (hyphen), or : (colon) characters.
+
       The replicationSources is a comma separated list of instances (host:port)
       to act as sources of the replication channel, i.e. to provide source
       failover of the channel. The first member of the list is configured with
@@ -916,6 +932,11 @@ DESCRIPTION
         source server or, if the MySQL communication stack is in use, for Group
         Replication’s group communication connections.
 
+      The clusterName must be non-empty and no greater than 63 characters long.
+      It can only start with an alphanumeric character or with _ (underscore),
+      and can only contain alphanumeric, _ ( underscore), . (period), or -
+      (hyphen) characters.
+
       ATTENTION: The failoverConsistency option will be removed in a future
                  release. Please use the consistency option instead.
 
@@ -1214,14 +1235,14 @@ DESCRIPTION
 
       - addInstances: List with the connection data of the new active instances
         to add to the metadata, or "auto" to automatically add missing
-        instances to the metadata.
+        instances to the metadata. Deprecated.
       - interactive: boolean value used to disable/enable the wizards in the
         command execution, i.e. prompts and confirmations will be provided or
         not according to the value set. The default value is equal to MySQL
         Shell wizard mode. Deprecated.
       - removeInstances: List with the connection data of the obsolete
         instances to remove from the metadata, or "auto" to automatically
-        remove obsolete instances from the metadata.
+        remove obsolete instances from the metadata. Deprecated.
       - updateTopologyMode: boolean value used to indicate if the topology mode
         (single-primary or multi-primary) in the metadata should be updated
         (true) or not (false) to match the one being used by the cluster. By
@@ -1230,7 +1251,14 @@ DESCRIPTION
         Replication communication protocol to the highest version possible.
       - updateViewChangeUuid: boolean value used to indicate if the command
         should generate and set a value for Group Replication View Change UUID
-        in the whole Cluster. Required for InnoDB ClusterSet usage.
+        in the whole Cluster. Required for InnoDB ClusterSet usage (if running
+        MySQL version lower than 8.3.0).
+      - addUnmanaged: set to true to automatically add newly discovered
+        instances, i.e. already part of the replication topology but not
+        managed in the Cluster, to the metadata. Defaults to false.
+      - removeObsolete: set to true to automatically remove all obsolete
+        instances, i.e. no longer part of the replication topology, from the
+        metadata. Defaults to false.
 
       The value for addInstances and removeInstances is used to specify which
       instances to add or remove from the metadata, respectively. Both options
@@ -1243,9 +1271,13 @@ DESCRIPTION
 
       ATTENTION: The interactive option will be removed in a future release.
 
+      ATTENTION: The addInstances and removeInstances options will be removed
+                 in a future release. Use addUnmanaged and removeObsolete
+                 instead.
+
 //@<OUT> Status
 NAME
-      status - Describe the status of the cluster.
+      status - Describe the status of the Cluster.
 
 SYNTAX
       <Cluster>.status([options])
@@ -1254,16 +1286,16 @@ WHERE
       options: Dictionary with options.
 
 RETURNS
-      A JSON object describing the status of the cluster.
+      A JSON object describing the status of the Cluster.
 
 DESCRIPTION
-      This function describes the status of the cluster including its
-      ReplicaSets and Instances. The following options may be given to control
-      the amount of information gathered and returned.
+      This function describes the status of the Cluster and its members. The
+      following options may be given to control the amount of information
+      gathered and returned.
 
       - extended: verbosity level of the command output.
-      - queryMembers: if true, connect to each Instance of the ReplicaSets to
-        query for more detailed stats about the replication machinery.
+      - queryMembers: if true, connect to each Instance of the Cluster to query
+        for more detailed stats about the replication machinery.
 
       ATTENTION: The queryMembers option will be removed in a future release.
                  Please use the extended option instead.
@@ -1273,7 +1305,7 @@ DESCRIPTION
       - 0: disables the command verbosity (default);
       - 1: includes information about the Metadata Version, Group Protocol
         Version, Group name, cluster member UUIDs, cluster member roles and
-        states as reported byGroup Replication and the list of fenced system
+        states as reported by Group Replication and the list of fenced system
         variables;
       - 2: includes information about transactions processed by connection and
         applier;
@@ -1357,8 +1389,8 @@ DESCRIPTION
 
 //@<OUT> resetRecoveryAccountsPassword
 NAME
-      resetRecoveryAccountsPassword - Reset the password of the recovery
-                                      accounts of the cluster.
+      resetRecoveryAccountsPassword - Resets the password of the recovery and
+                                      replication accounts of the Cluster.
 
 SYNTAX
       <Cluster>.resetRecoveryAccountsPassword(options)
@@ -1371,10 +1403,11 @@ RETURNS
 
 DESCRIPTION
       This function resets the passwords for all internal recovery user
-      accounts used by the Cluster. It can be used to reset the passwords of
-      the recovery user accounts when needed for any security reasons. For
-      example: periodically to follow some custom password lifetime policy, or
-      after some security breach event.
+      accounts used by the Cluster as well as for all replication accounts used
+      by any Read Replica instance. It can be used to reset the passwords of
+      the recovery or replication user accounts when needed for any security
+      reasons. For example: periodically to follow some custom password
+      lifetime policy, or after some security breach event.
 
       The options dictionary may contain the following attributes:
 
@@ -1453,6 +1486,11 @@ DESCRIPTION
       - The target cluster's Metadata schema version is 2.1.0 or newer.
       - Unmanaged replication channels are not allowed.
 
+      The domainName must be non-empty and no greater than 63 characters long.
+      It can only start with an alphanumeric character or with _ (underscore),
+      and can only contain alphanumeric, _ ( underscore), . (period), or -
+      (hyphen) characters.
+
       Options
 
       The options dictionary can contain the following values:
@@ -1624,6 +1662,10 @@ DESCRIPTION
       - cloneDonor: The Cluster member to be used as donor when performing
         clone-based recovery.
 
+      The label must be non-empty and no greater than 256 characters long. It
+      must be unique within the Cluster and can only contain alphanumeric, _
+      (underscore), . (period), - (hyphen), or : (colon) characters.
+
       The replicationSources is a comma separated list of instances (host:port)
       to act as sources of the replication channel, i.e. to provide source
       failover of the channel. The first member of the list is configured with
