@@ -64,6 +64,10 @@ This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port2
 Instance configuration is suitable.
 NOTE: Group Replication will communicate with other members using '<<<hostname>>>:<<<__mysql_sandbox_gr_port2>>>'. Use the localAddress option to override.
 
+?{VER(<8.0.27)}
+NOTE: The 'localAddress' "<<<hostname>>>" is [[*]], which is compatible with the Group Replication automatically generated list of IPs.
+See https://dev.mysql.com/doc/refman/en/group-replication-ip-address-permissions.html for more details.
+?{}
 * Checking connectivity and SSL configuration...
 
 A new instance will be added to the InnoDB Cluster. Depending on the amount of
@@ -91,6 +95,10 @@ This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port3
 Instance configuration is suitable.
 NOTE: Group Replication will communicate with other members using '<<<hostname>>>:<<<__mysql_sandbox_gr_port3>>>'. Use the localAddress option to override.
 
+?{VER(<8.0.27)}
+NOTE: The 'localAddress' "<<<hostname>>>" is [[*]], which is compatible with the Group Replication automatically generated list of IPs.
+See https://dev.mysql.com/doc/refman/en/group-replication-ip-address-permissions.html for more details.
+?{}
 * Checking connectivity and SSL configuration...
 
 A new instance will be added to the InnoDB Cluster. Depending on the amount of
@@ -116,6 +124,10 @@ This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port3
 Instance configuration is suitable.
 NOTE: Group Replication will communicate with other members using '<<<hostname>>>:<<<__mysql_sandbox_gr_port3>>>'. Use the localAddress option to override.
 
+?{VER(<8.0.27)}
+NOTE: The 'localAddress' "<<<hostname>>>" is [[*]], which is compatible with the Group Replication automatically generated list of IPs.
+See https://dev.mysql.com/doc/refman/en/group-replication-ip-address-permissions.html for more details.
+?{}
 * Checking connectivity and SSL configuration...
 
 A new instance will be added to the InnoDB Cluster. Depending on the amount of
@@ -239,6 +251,10 @@ This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port2
 Instance configuration is suitable.
 NOTE: Group Replication will communicate with other members using '<<<hostname>>>:<<<__mysql_sandbox_gr_port2>>>'. Use the localAddress option to override.
 
+?{VER(<8.0.27)}
+NOTE: The 'localAddress' "<<<hostname>>>" is [[*]], which is compatible with the Group Replication automatically generated list of IPs.
+See https://dev.mysql.com/doc/refman/en/group-replication-ip-address-permissions.html for more details.
+?{}
 * Checking connectivity and SSL configuration...
 
 A new instance will be added to the InnoDB Cluster. Depending on the amount of
@@ -274,6 +290,10 @@ This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port3
 Instance configuration is suitable.
 NOTE: Group Replication will communicate with other members using '<<<hostname>>>:<<<__mysql_sandbox_gr_port3>>>'. Use the localAddress option to override.
 
+?{VER(<8.0.27)}
+NOTE: The 'localAddress' "<<<hostname>>>" is [[*]], which is compatible with the Group Replication automatically generated list of IPs.
+See https://dev.mysql.com/doc/refman/en/group-replication-ip-address-permissions.html for more details.
+?{}
 * Checking connectivity and SSL configuration...
 
 A new instance will be added to the InnoDB Cluster. Depending on the amount of
@@ -299,6 +319,10 @@ This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port3
 Instance configuration is suitable.
 NOTE: Group Replication will communicate with other members using '<<<hostname>>>:<<<__mysql_sandbox_gr_port3>>>'. Use the localAddress option to override.
 
+?{VER(<8.0.27)}
+NOTE: The 'localAddress' "<<<hostname>>>" is [[*]], which is compatible with the Group Replication automatically generated list of IPs.
+See https://dev.mysql.com/doc/refman/en/group-replication-ip-address-permissions.html for more details.
+?{}
 * Checking connectivity and SSL configuration...
 
 A new instance will be added to the InnoDB Cluster. Depending on the amount of
