@@ -1,12 +1,12 @@
 //@<OUT> configureInstance custom cluster admin and password
-Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB cluster...
+Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB Cluster...
 
 This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port1>>>
 
 ERROR: User 'root' can only connect from 'localhost'. New account(s) with proper source address specification to allow remote connection from all instances must be created to manage the cluster.
 
 1) Create remotely usable account for 'root' with same grants and password
-2) Create a new admin account for InnoDB cluster with minimal required grants
+2) Create a new admin account for InnoDB Cluster with minimal required grants
 3) Ignore and continue
 4) Cancel
 
@@ -41,7 +41,7 @@ Creating user repl_admin@%.
 Account repl_admin@% was successfully created.
 
 Configuring instance...
-The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB cluster.
+The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB Cluster.
 NOTE: MySQL server needs to be restarted for configuration changes to take effect.
 ?{}
 ?{VER(>=8.0.11) && VER(<8.0.21)}
@@ -65,7 +65,7 @@ Creating user repl_admin@%.
 Account repl_admin@% was successfully created.
 
 Configuring instance...
-The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB cluster.
+The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB Cluster.
 NOTE: MySQL server needs to be restarted for configuration changes to take effect.
 ?{}
 ?{VER(>=8.0.21) && VER(<8.0.23)}
@@ -88,7 +88,7 @@ Creating user repl_admin@%.
 Account repl_admin@% was successfully created.
 
 Configuring instance...
-The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB cluster.
+The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB Cluster.
 NOTE: MySQL server needs to be restarted for configuration changes to take effect.
 ?{}
 ?{VER(>=8.0.23) && VER(<8.0.26)}
@@ -112,7 +112,7 @@ Creating user repl_admin@%.
 Account repl_admin@% was successfully created.
 
 Configuring instance...
-The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB cluster.
+The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB Cluster.
 NOTE: MySQL server needs to be restarted for configuration changes to take effect.
 ?{}
 ?{VER(==8.0.26)}
@@ -136,10 +136,10 @@ Creating user repl_admin@%.
 Account repl_admin@% was successfully created.
 
 Configuring instance...
-The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB cluster.
+The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB Cluster.
 NOTE: MySQL server needs to be restarted for configuration changes to take effect.
 ?{}
-?{VER(>=8.0.27)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 +----------------------------------------+---------------+----------------+------------------------------------------------+
 | Variable                               | Current Value | Required Value | Note                                           |
 +----------------------------------------+---------------+----------------+------------------------------------------------+
@@ -161,24 +161,44 @@ Account repl_admin@% was successfully created.
 
 Configuring instance...
 ?{}
-?{VER(>=8.2.0) && !__replaying}
+?{VER(>=8.3.0)}
++----------------------------------------+---------------+----------------+-----------------------------------------------+
+| Variable                               | Current Value | Required Value | Note                                          |
++----------------------------------------+---------------+----------------+-----------------------------------------------+
+| binlog_format                          | <not set>     | ROW            | Update the config file                        |
+| binlog_transaction_dependency_tracking | <not set>     | WRITESET       | Update the config file                        |
+| enforce_gtid_consistency               | OFF           | ON             | Update the config file and restart the server |
+| gtid_mode                              | OFF           | ON             | Update the config file and restart the server |
+| replica_preserve_commit_order          | <not set>     | ON             | Update the config file                        |
+| report_port                            | <not set>     | <<<__mysql_sandbox_port1>>>           | Update the config file                        |
+| server_id                              | 1             | <unique ID>    | Update the config file and restart the server |
++----------------------------------------+---------------+----------------+-----------------------------------------------+
+
+Some variables need to be changed, but cannot be done dynamically on the server.
+Do you want to perform the required configuration changes? [y/n]: Do you want to restart the instance after configuring it? [y/n]:
+Creating user repl_admin@%.
+Account repl_admin@% was successfully created.
+
+Configuring instance...
+?{}
+?{((VER(>=8.0.35) && VER(<8.1.0)) || (VER(>=8.2.0) && VER(<8.3.0))) && !__replaying}
 
 WARNING: '@@binlog_transaction_dependency_tracking' is deprecated and will be removed in a future release. (Code 1287).
 ?{}
 ?{VER(>=8.0.27)}
-The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB cluster.
+The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB Cluster.
 NOTE: MySQL server needs to be restarted for configuration changes to take effect.
 ?{}
 
 //@<OUT> configureInstance custom cluster admin and no password
-Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB cluster...
+Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB Cluster...
 
 This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port1>>>
 
 ERROR: User 'root' can only connect from 'localhost'. New account(s) with proper source address specification to allow remote connection from all instances must be created to manage the cluster.
 
 1) Create remotely usable account for 'root' with same grants and password
-2) Create a new admin account for InnoDB cluster with minimal required grants
+2) Create a new admin account for InnoDB Cluster with minimal required grants
 3) Ignore and continue
 4) Cancel
 
@@ -210,7 +230,7 @@ Creating user repl_admin2@%.
 Account repl_admin2@% was successfully created.
 
 Configuring instance...
-The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB cluster.
+The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB Cluster.
 NOTE: MySQL server needs to be restarted for configuration changes to take effect.
 ?{}
 ?{VER(>=8.0.11)}
@@ -228,7 +248,7 @@ Creating user repl_admin2@%.
 Account repl_admin2@% was successfully created.
 
 Configuring instance...
-The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB cluster.
+The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB Cluster.
 NOTE: MySQL server needs to be restarted for configuration changes to take effect.
 ?{}
 
@@ -238,7 +258,7 @@ No default schema selected; type \use <schema> to set one.
 
 //@<OUT> Verify that configureInstance() detects and fixes the wrong settings {VER(>=8.0.23)}
 The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' belongs to an InnoDB Cluster.
-Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB cluster...
+Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB Cluster...
 
 This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port1>>>
 
@@ -261,10 +281,10 @@ NOTE: Some configuration options need to be fixed:
 ?{}
 
 Configuring instance...
-The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB cluster.
+The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB Cluster.
 
 //@<OUT> canonical IPv6 addresses are supported WL#12758 {VER(>= 8.0.14)}
-Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB cluster...
+Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB Cluster...
 NOTE: Instance detected as a sandbox.
 Please note that sandbox instances are only suitable for deploying test clusters for use within the same host.
 
@@ -274,11 +294,10 @@ This instance reports its own address as [::1]:<<<__mysql_sandbox_port1>>>
 applierWorkerThreads will be set to the default value of 4.
 
 ?{}
-The instance '[::1]:<<<__mysql_sandbox_port1>>>' is valid to be used in an InnoDB cluster.
-The instance '[::1]:<<<__mysql_sandbox_port1>>>' is already ready to be used in an InnoDB cluster.
+The instance '[::1]:<<<__mysql_sandbox_port1>>>' is valid for InnoDB Cluster usage.
 
 //@<OUT> canonical IPv4 addresses are supported WL#12758
-Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB cluster...
+Configuring local MySQL instance listening at port <<<__mysql_sandbox_port1>>> for use in an InnoDB Cluster...
 NOTE: Instance detected as a sandbox.
 Please note that sandbox instances are only suitable for deploying test clusters for use within the same host.
 
@@ -288,8 +307,7 @@ This instance reports its own address as 127.0.0.1:<<<__mysql_sandbox_port1>>>
 applierWorkerThreads will be set to the default value of 4.
 
 ?{}
-The instance '127.0.0.1:<<<__mysql_sandbox_port1>>>' is valid to be used in an InnoDB cluster.
-The instance '127.0.0.1:<<<__mysql_sandbox_port1>>>' is already ready to be used in an InnoDB cluster.
+The instance '127.0.0.1:<<<__mysql_sandbox_port1>>>' is valid for InnoDB Cluster usage.
 
 //@ IPv6 not supported on versions below 8.0.14 WL#12758 {VER(< 8.0.14)}
 |ERROR: Cannot use host '::1' for instance '[::1]:<<<__mysql_sandbox_port1>>>' because it is an IPv6 address which is only supported by Group Replication from MySQL version >= 8.0.14. Set the MySQL server 'report_host' variable to an IPv4 address or hostname that resolves an IPv4 address.|
