@@ -11,7 +11,7 @@
     "defaultReplicaSet": {
         "GRProtocolVersion": "[[*]]",
         "clusterErrors": [
-?{VER(>=8.0.27)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
             "WARNING: The Cluster's group_replication_view_change_uuid is not stored in the Metadata. Please use <Cluster>.rescan() to update the metadata.",
 ?{}
             "WARNING: Cluster's transaction size limit is not registered in the metadata. Use cluster.rescan() to update the metadata."
@@ -114,9 +114,12 @@ ${*}
 ?{VER(>=8.0.17) && VER(<8.0.25)}
                                 "transaction": "<<<gr_uuid>>>:[[*]]"
 ?{}
-?{VER(>=8.0.25)}
+?{VER(>=8.0.25) && VER(<8.3.0)}
                                 "transaction": "<<<gr_view_change_uuid>>>:[[*]]"
 ?{}
+?{VER(>=8.3.0)}
+                                "transaction": ""
+?{}
 ?{VER(>=8.0.17)}
                             },
 ?{}
@@ -342,16 +345,18 @@ ${*}
 ?{}
                     "variable": "group_replication_ip_allowlist"
                 },
+?{VER(<8.3.0)}
                 {
                     "option": "ipWhitelist",
-?{VER(>=8.0.23)}
+?{}
+?{VER(<8.3.0) && VER(>=8.0.23)}
                     "value": "AUTOMATIC",
 ?{}
 ?{VER(<8.0.23)}
                     "value": "<<<allowlist>>>",
-?{}
                     "variable": "group_replication_ip_whitelist"
                 },
+?{}
                 {
                     "option": "localAddress",
                     "value": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>1",
@@ -365,8 +370,8 @@ ${*}
                 {
                     "option": "certSubject",
                     "value": ""
-                },
 ?{VER(<8.0.23)}
+                },
                 {
                     "value": "COMMIT_ORDER",
                     "variable": "binlog_transaction_dependency_tracking"
@@ -382,17 +387,21 @@ ${*}
                 {
                     "value": "OFF",
                     "variable": "<<<__replica_keyword>>>_preserve_commit_order"
-                },
 ?{}
 ?{VER(>=8.0.23)}
+                },
                 {
                     "value": "WRITESET",
                     "variable": "binlog_transaction_dependency_tracking"
                 },
+?{}
+?{VER(>=8.0.23) && VER(<8.3.0)}
                 {
                     "value": "LOGICAL_CLOCK",
                     "variable": "<<<__replica_keyword>>>_parallel_type"
                 },
+?{}
+?{VER(>=8.0.23)}
                 {
                     "value": "4",
                     "variable": "<<<__replica_keyword>>>_parallel_workers"
@@ -400,11 +409,13 @@ ${*}
                 {
                     "value": "ON",
                     "variable": "<<<__replica_keyword>>>_preserve_commit_order"
-                },
 ?{}
+?{VER(<8.3.0)}
+                },
                 {
                     "value": "XXHASH64",
                     "variable": "transaction_write_set_extraction"
+?{}
                 }
             ],
             "<<<hostname>>>:<<<__mysql_sandbox_port2>>>": [
@@ -443,16 +454,18 @@ ${*}
 ?{}
                     "variable": "group_replication_ip_allowlist"
                 },
+?{VER(<8.3.0)}
                 {
                     "option": "ipWhitelist",
-?{VER(>=8.0.23)}
+?{}
+?{VER(<8.3.0) && VER(>=8.0.23)}
                     "value": "AUTOMATIC",
 ?{}
 ?{VER(<8.0.23)}
                     "value": "<<<allowlist>>>",
-?{}
                     "variable": "group_replication_ip_whitelist"
                 },
+?{}
                 {
                     "option": "localAddress",
                     "value": "<<<hostname>>>:<<<__mysql_sandbox_port2>>>1",
@@ -466,8 +479,8 @@ ${*}
                 {
                     "option": "certSubject",
                     "value": ""
-                },
 ?{VER(<8.0.23)}
+                },
                 {
                     "value": "COMMIT_ORDER",
                     "variable": "binlog_transaction_dependency_tracking"
@@ -483,17 +496,21 @@ ${*}
                 {
                     "value": "OFF",
                     "variable": "<<<__replica_keyword>>>_preserve_commit_order"
-                },
 ?{}
 ?{VER(>=8.0.23)}
+                },
                 {
                     "value": "WRITESET",
                     "variable": "binlog_transaction_dependency_tracking"
                 },
+?{}
+?{VER(>=8.0.23) && VER(<8.3.0)}
                 {
                     "value": "LOGICAL_CLOCK",
                     "variable": "<<<__replica_keyword>>>_parallel_type"
                 },
+?{}
+?{VER(>=8.0.23)}
                 {
                     "value": "4",
                     "variable": "<<<__replica_keyword>>>_parallel_workers"
@@ -501,11 +518,13 @@ ${*}
                 {
                     "value": "ON",
                     "variable": "<<<__replica_keyword>>>_preserve_commit_order"
-                },
 ?{}
+?{VER(<8.3.0)}
+                },
                 {
                     "value": "XXHASH64",
                     "variable": "transaction_write_set_extraction"
+?{}
                 }
             ]
         }
