@@ -2,12 +2,12 @@
 
 // Tests createReplicaSet() for adoption specifically
 
-//@<> INCLUDE async_utils.inc
+//@ INCLUDE async_utils.inc
 
 //@<> Setup
-testutil.deploySandbox(__mysql_sandbox_port1, "root", {server_uuid: "cd93e780-b558-11ea-b3de-0242ac130004"});
-testutil.deploySandbox(__mysql_sandbox_port2, "root", {server_uuid: "cd93e780-b558-11ea-b3de-0242ac130005"});
-testutil.deploySandbox(__mysql_sandbox_port3, "root", {server_uuid: "cd93e780-b558-11ea-b3de-0242ac130006"});
+testutil.deploySandbox(__mysql_sandbox_port1, "root");
+testutil.deploySandbox(__mysql_sandbox_port2, "root");
+testutil.deploySandbox(__mysql_sandbox_port3, "root");
 
 // enable interactive by default
 shell.options.useWizards = true;
@@ -62,7 +62,7 @@ shell.connect(__sandbox_uri1);
 
 //@ adopt with existing replicaset (should fail)
 testutil.destroySandbox(__mysql_sandbox_port1);
-testutil.deploySandbox(__mysql_sandbox_port1, "root", {server_uuid: "cd93e780-b558-11ea-b3de-0242ac130004"});
+testutil.deploySandbox(__mysql_sandbox_port1, "root");
 shell.connect(__sandbox_uri1);
 // should work
 rs = dba.createReplicaSet("myrs", {gtidSetIsComplete:1});
@@ -130,9 +130,9 @@ setup_slave(session2, __mysql_sandbox_port1);
 //@<> SSL=1
 session1 = mysql.getSession(__sandbox_uri1);
 
-session2.runSql("STOP SLAVE");
-session2.runSql("CHANGE MASTER TO master_host='localhost', master_port=/*(*/?/*)*/, master_user='root', master_password='root', master_auto_position=1, master_ssl=1", [__mysql_sandbox_port1]);
-session2.runSql("START SLAVE");
+session2.runSql("STOP " + get_replica_keyword());
+session2.runSql("change " + get_replication_source_keyword() + " TO " + get_replication_option_keyword() + "_HOST='localhost', " + get_replication_option_keyword() + "_PORT=/*(*/?/*)*/, " + get_replication_option_keyword() + "_USER='root', " + get_replication_option_keyword() + "_PASSWORD='root', " + get_replication_option_keyword() + "_AUTO_POSITION=1, " + get_replication_option_keyword() + "_SSL=1", [__mysql_sandbox_port1]);
+session2.runSql("START " + get_replica_keyword());
 
 dba.createReplicaSet("myrs", {adoptFromAR:1});
 
@@ -141,9 +141,9 @@ reset_instance(session2);
 setup_slave(session2, __mysql_sandbox_port1);
 
 //@<> SSL=0
-session2.runSql("STOP SLAVE");
-session2.runSql("CHANGE MASTER TO master_host='localhost', master_port=/*(*/?/*)*/, master_user='root', master_password='root', master_auto_position=1, master_ssl=0", [__mysql_sandbox_port1]);
-session2.runSql("START SLAVE");
+session2.runSql("STOP " + get_replica_keyword());
+session2.runSql("change " + get_replication_source_keyword() + " TO " + get_replication_option_keyword() + "_HOST='localhost', " + get_replication_option_keyword() + "_PORT=/*(*/?/*)*/, " + get_replication_option_keyword() + "_USER='root', " + get_replication_option_keyword() + "_PASSWORD='root', " + get_replication_option_keyword() + "_AUTO_POSITION=1, " + get_replication_option_keyword() + "_SSL=0", [__mysql_sandbox_port1]);
+session2.runSql("START " + get_replica_keyword());
 
 dba.createReplicaSet("myrs", {adoptFromAR:1});
 
@@ -155,13 +155,13 @@ setup_slave(session2, __mysql_sandbox_port1);
 session.runSql("CHANGE REPLICATION FILTER REPLICATE_IGNORE_DB = (foo)");
 dba.createReplicaSet("myrs", {adoptFromAR:true});
 
-session.runSql("CHANGE MASTER TO master_host='localhost', master_port=/*(*/?/*)*/ FOR CHANNEL 'bla'", [__mysql_port]);
+session.runSql("change " + get_replication_source_keyword() + " TO " + get_replication_option_keyword() + "_HOST='localhost', " + get_replication_option_keyword() + "_PORT=/*(*/?/*)*/ FOR CHANNEL 'bla'", [__mysql_port]);
 session.runSql("CHANGE REPLICATION FILTER REPLICATE_IGNORE_DB = (foo) FOR CHANNEL 'bla'");
 dba.createReplicaSet("myrs", {adoptFromAR:true});
 
 //@ binlog filters (should fail)
 testutil.destroySandbox(__mysql_sandbox_port1);
-testutil.deploySandbox(__mysql_sandbox_port1, "root", {server_uuid: "cd93e780-b558-11ea-b3de-0242ac130004"});
+testutil.deploySandbox(__mysql_sandbox_port1, "root");
 testutil.stopSandbox(__mysql_sandbox_port1);
 testutil.changeSandboxConf(__mysql_sandbox_port1, "binlog_ignore_db", "igndata");
 testutil.startSandbox(__mysql_sandbox_port1);
@@ -174,13 +174,13 @@ dba.createReplicaSet("myrs", {adoptFromAR:true});
 
 // cleanup
 testutil.destroySandbox(__mysql_sandbox_port1);
-testutil.deploySandbox(__mysql_sandbox_port1, "root", {server_uuid: "cd93e780-b558-11ea-b3de-0242ac130004"});
+testutil.deploySandbox(__mysql_sandbox_port1, "root");
 
 //@ broken repl (should fail)
 shell.connect(__sandbox_uri2);
-session.runSql("STOP SLAVE");
-session.runSql("CHANGE MASTER TO master_host='localhost', master_port=/*(*/?/*)*/, master_user='root', master_password='badpass', MASTER_AUTO_POSITION=1, MASTER_SSL=1", [__mysql_sandbox_port1]);
-session.runSql("START SLAVE");
+session.runSql("STOP " + get_replica_keyword());
+session.runSql("change " + get_replication_source_keyword() + " TO " + get_replication_option_keyword() + "_HOST='localhost', " + get_replication_option_keyword() + "_PORT=/*(*/?/*)*/, " + get_replication_option_keyword() + "_USER='root', " + get_replication_option_keyword() + "_PASSWORD='badpass', " + get_replication_option_keyword() + "_AUTO_POSITION=1, " + get_replication_option_keyword() + "_SSL=1", [__mysql_sandbox_port1]);
+session.runSql("START " + get_replica_keyword());
 dba.createReplicaSet("myrs", {adoptFromAR:true});
 
 reset_instance(session);
@@ -189,8 +189,8 @@ reset_instance(session);
 shell.connect(__sandbox_uri1);
 reset_instance(session);
 reset_instance(session2);
-session2.runSql("CHANGE MASTER TO master_host='localhost', master_port=/*(*/?/*)*/, master_user='root', master_password='root' FOR CHANNEL 'bla'", [__mysql_sandbox_port1]);
-session2.runSql("START SLAVE FOR CHANNEL 'bla'");
+session2.runSql("change " + get_replication_source_keyword() + " TO " + get_replication_option_keyword() + "_HOST='localhost', " + get_replication_option_keyword() + "_PORT=/*(*/?/*)*/, " + get_replication_option_keyword() + "_USER='root', " + get_replication_option_keyword() + "_PASSWORD='root' FOR CHANNEL 'bla'", [__mysql_sandbox_port1]);
+session2.runSql("START " + get_replica_keyword() + " FOR CHANNEL 'bla'");
 
 // this should fail because of the channel name
 dba.createReplicaSet("myrs", {adoptFromAR:true});
@@ -199,7 +199,7 @@ dba.createReplicaSet("myrs", {adoptFromAR:true});
 setup_slave(session2, __mysql_sandbox_port1);
 dba.createReplicaSet("myrs", {adoptFromAR:true});
 
-session2.runSql("STOP SLAVE FOR CHANNEL 'bla'");
+session2.runSql("STOP " + get_replica_keyword() + " FOR CHANNEL 'bla'");
 reset_instance(session2);
 
 //@ bad repl channels - master has a bogus channel
@@ -207,7 +207,7 @@ setup_slave(session, __mysql_sandbox_port3, "foob");
 setup_slave(session2, __mysql_sandbox_port1);
 dba.createReplicaSet("myrs", {adoptFromAR:true});
 
-session.runSql("STOP SLAVE FOR CHANNEL 'foob'");
+session.runSql("STOP " + get_replica_keyword() + " FOR CHANNEL 'foob'");
 reset_instance(session);
 reset_instance(session2);
 
@@ -294,17 +294,16 @@ testutil.deployRawSandbox(__mysql_sandbox_port2, "root", {gtid_mode:'OFF', serve
 shell.connect(__sandbox_uri1);
 session2 = mysql.getSession(__sandbox_uri2);
 
-session2.runSql("CHANGE MASTER TO master_host='localhost', master_port=/*(*/?/*)*/, master_user='root', master_password='root'", [__mysql_sandbox_port1]);
-session2.runSql("START SLAVE");
+session2.runSql("change " + get_replication_source_keyword() + " TO " + get_replication_option_keyword() + "_HOST='localhost', " + get_replication_option_keyword() + "_PORT=/*(*/?/*)*/, " + get_replication_option_keyword() + "_USER='root', " + get_replication_option_keyword() + "_PASSWORD='root'", [__mysql_sandbox_port1]);
+session2.runSql("START " + get_replica_keyword());
 
 dba.createReplicaSet("myrs", {adoptFromAR:true});
 
-
 testutil.destroySandbox(__mysql_sandbox_port1);
-testutil.deploySandbox(__mysql_sandbox_port1, "root", {server_uuid: "cd93e780-b558-11ea-b3de-0242ac130004"});
+testutil.deploySandbox(__mysql_sandbox_port1, "root");
 session1 = mysql.getSession(__sandbox_uri1);
 testutil.destroySandbox(__mysql_sandbox_port2);
-testutil.deploySandbox(__mysql_sandbox_port2, "root", {server_uuid: "cd93e780-b558-11ea-b3de-0242ac130005"});
+testutil.deploySandbox(__mysql_sandbox_port2, "root");
 shell.connect(__sandbox_uri1);
 session2 = mysql.getSession(__sandbox_uri2);
 testutil.restartSandbox(__mysql_sandbox_port3);
@@ -314,50 +313,50 @@ session3 = mysql.getSession(__sandbox_uri3);
 
 //@ unsupported option: delay (should fail)
 reset_instance(session2);
-session2.runSql("CHANGE MASTER TO master_host='localhost', master_port=/*(*/?/*)*/, master_user='root', master_password='root', master_auto_position=1, master_delay=5", [__mysql_sandbox_port1]);
-session2.runSql("START SLAVE");
+session2.runSql("change " + get_replication_source_keyword() + " TO " + get_replication_option_keyword() + "_HOST='localhost', " + get_replication_option_keyword() + "_PORT=/*(*/?/*)*/, " + get_replication_option_keyword() + "_USER='root', " + get_replication_option_keyword() + "_PASSWORD='root', " + get_replication_option_keyword() + "_AUTO_POSITION=1, " + get_replication_option_keyword() + "_delay=5", [__mysql_sandbox_port1]);
+session2.runSql("START " + get_replica_keyword());
 
 dba.createReplicaSet("myrs", {adoptFromAR:1});
 
 //@ unsupported option: connect_retry (should fail)
 reset_instance(session2);
-session2.runSql("CHANGE MASTER TO master_host='localhost', master_port=/*(*/?/*)*/, master_user='root', master_password='root', master_auto_position=1, master_connect_retry=4", [__mysql_sandbox_port1]);
-session2.runSql("START SLAVE");
+session2.runSql("change " + get_replication_source_keyword() + " TO " + get_replication_option_keyword() + "_HOST='localhost', " + get_replication_option_keyword() + "_PORT=/*(*/?/*)*/, " + get_replication_option_keyword() + "_USER='root', " + get_replication_option_keyword() + "_PASSWORD='root', " + get_replication_option_keyword() + "_AUTO_POSITION=1, " + get_replication_option_keyword() + "_connect_retry=4", [__mysql_sandbox_port1]);
+session2.runSql("START " + get_replica_keyword());
 
 dba.createReplicaSet("myrs", {adoptFromAR:1});
 
 //@ unsupported option: retry_count (should fail)
 reset_instance(session2);
-session2.runSql("CHANGE MASTER TO master_host='localhost', master_port=/*(*/?/*)*/, master_user='root', master_password='root', master_auto_position=1, master_retry_count=3", [__mysql_sandbox_port1]);
-session2.runSql("START SLAVE");
+session2.runSql("change " + get_replication_source_keyword() + " TO " + get_replication_option_keyword() + "_HOST='localhost', " + get_replication_option_keyword() + "_PORT=/*(*/?/*)*/, " + get_replication_option_keyword() + "_USER='root', " + get_replication_option_keyword() + "_PASSWORD='root', " + get_replication_option_keyword() + "_AUTO_POSITION=1, " + get_replication_option_keyword() + "_retry_count=3", [__mysql_sandbox_port1]);
+session2.runSql("START " + get_replica_keyword());
 
 dba.createReplicaSet("myrs", {adoptFromAR:1});
 
 //@ unsupported option: heartbeat (should fail)
 reset_instance(session2);
-session2.runSql("CHANGE MASTER TO master_host='localhost', master_port=/*(*/?/*)*/, master_user='root', master_password='root', master_auto_position=1, master_heartbeat_period=32", [__mysql_sandbox_port1]);
-session2.runSql("START SLAVE");
+session2.runSql("change " + get_replication_source_keyword() + " TO " + get_replication_option_keyword() + "_HOST='localhost', " + get_replication_option_keyword() + "_PORT=/*(*/?/*)*/, " + get_replication_option_keyword() + "_USER='root', " + get_replication_option_keyword() + "_PASSWORD='root', " + get_replication_option_keyword() + "_AUTO_POSITION=1, " + get_replication_option_keyword() + "_heartbeat_period=32", [__mysql_sandbox_port1]);
+session2.runSql("START " + get_replica_keyword());
 
 dba.createReplicaSet("myrs", {adoptFromAR:1});
 
 //@ unsupported option: no auto_position (should fail)
 reset_instance(session2);
-session2.runSql("CHANGE MASTER TO master_host='localhost', master_port=/*(*/?/*)*/, master_user='root', master_password='root'", [__mysql_sandbox_port1]);
-session2.runSql("START SLAVE");
+session2.runSql("change " + get_replication_source_keyword() + " TO " + get_replication_option_keyword() + "_HOST='localhost', " + get_replication_option_keyword() + "_PORT=/*(*/?/*)*/, " + get_replication_option_keyword() + "_USER='root', " + get_replication_option_keyword() + "_PASSWORD='root'", [__mysql_sandbox_port1]);
+session2.runSql("START " + get_replica_keyword());
 
 dba.createReplicaSet("myrs", {adoptFromAR:1});
 
 //@ unsupported option: MASTER_COMPRESSION_ALGORITHMS (should fail) {VER(>=8.0.18)}
 reset_instance(session2);
-session2.runSql("CHANGE MASTER TO master_host='localhost', master_port=/*(*/?/*)*/, master_user='root', master_password='root', master_auto_position=1, MASTER_COMPRESSION_ALGORITHMS='zstd'", [__mysql_sandbox_port1]);
-session2.runSql("START SLAVE");
+session2.runSql("change " + get_replication_source_keyword() + " TO " + get_replication_option_keyword() + "_HOST='localhost', " + get_replication_option_keyword() + "_PORT=/*(*/?/*)*/, " + get_replication_option_keyword() + "_USER='root', " + get_replication_option_keyword() + "_PASSWORD='root', " + get_replication_option_keyword() + "_AUTO_POSITION=1, " + get_replication_option_keyword() + "_COMPRESSION_ALGORITHMS='zstd'", [__mysql_sandbox_port1]);
+session2.runSql("START " + get_replica_keyword());
 
 dba.createReplicaSet("myrs", {adoptFromAR:1});
 
 //@ supported option: GET_MASTER_PUBLIC_KEY
 reset_instance(session2);
-session2.runSql("CHANGE MASTER TO master_host='localhost', master_port=/*(*/?/*)*/, master_user='root', master_password='root', master_auto_position=1, GET_MASTER_PUBLIC_KEY=1", [__mysql_sandbox_port1]);
-session2.runSql("START SLAVE");
+session2.runSql("change " + get_replication_source_keyword() + " TO " + get_replication_option_keyword() + "_HOST='localhost', " + get_replication_option_keyword() + "_PORT=/*(*/?/*)*/, " + get_replication_option_keyword() + "_USER='root', " + get_replication_option_keyword() + "_PASSWORD='root', " + get_replication_option_keyword() + "_AUTO_POSITION=1, GET_" + get_replication_option_keyword() + "_PUBLIC_KEY=1", [__mysql_sandbox_port1]);
+session2.runSql("START " + get_replica_keyword());
 
 dba.createReplicaSet("myrs", {adoptFromAR:1});
 
@@ -382,7 +381,16 @@ var rs = dba.createReplicaSet("myrs", {adoptFromAR:true});
 
 // check that repl configs didn't change
 EXPECT_EQ(slaves1, session.runSql("SELECT * FROM performance_schema.replication_connection_configuration").fetchAll());
-EXPECT_EQ(slaves2, session2.runSql("SELECT * FROM performance_schema.replication_connection_configuration").fetchAll());
+
+var slaves2_new = session2.runSql("SELECT * FROM performance_schema.replication_connection_configuration").fetchAll();
+EXPECT_EQ(slaves2[0].length, slaves2_new[0].length);
+for (var i = 0; i < slaves2[0].length; i++) {
+    if (i == 3) {
+        EXPECT_EQ("mysql_innodb_rs_" + session2.runSql("SELECT @@server_id").fetchOne()[0], slaves2_new[0][i]);
+        continue;
+    }
+    EXPECT_EQ(slaves2[0][i], slaves2_new[0][i]);
+}
 
 rs.status();
 
@@ -394,7 +402,17 @@ setup_slave(session2, __mysql_sandbox_port1);
 setup_slave(session3, __mysql_sandbox_port1);
 testutil.waitMemberTransactions(__mysql_sandbox_port2, __mysql_sandbox_port1);
 testutil.waitMemberTransactions(__mysql_sandbox_port3, __mysql_sandbox_port1);
+
+session2.runSql("STOP SLAVE");
+session2.runSql("CHANGE MASTER TO GET_MASTER_PUBLIC_KEY=1");
+session2.runSql("START SLAVE");
+
+session3.runSql("STOP SLAVE");
+session3.runSql("CHANGE MASTER TO GET_MASTER_PUBLIC_KEY=1");
+session3.runSql("START SLAVE");
+
 var rs = dba.createReplicaSet("myrs", {adoptFromAR:true});
+
 testutil.waitMemberTransactions(__mysql_sandbox_port2, __mysql_sandbox_port1);
 testutil.waitMemberTransactions(__mysql_sandbox_port3, __mysql_sandbox_port1);
 rs.status();
@@ -403,6 +421,35 @@ reset_instance(session);
 reset_instance(session2);
 reset_instance(session3);
 
+//<> Check unused users message
+
+setup_slave(session2, __mysql_sandbox_port1);
+setup_slave(session3, __mysql_sandbox_port1);
+session.runSql("CREATE USER foo@'%' IDENTIFIED BY 'foo_pwd' REQUIRE NONE");
+session.runSql("GRANT CLONE_ADMIN, EXECUTE ON *.* TO foo@'%'");
+session.runSql("GRANT REPLICATION SLAVE ON *.* TO foo@'%'");
+session.runSql("CREATE USER bar@'%' IDENTIFIED BY 'bar_pwd' REQUIRE NONE");
+session.runSql("GRANT CLONE_ADMIN, EXECUTE ON *.* TO bar@'%'");
+session.runSql("GRANT REPLICATION SLAVE ON *.* TO bar@'%'");
+
+testutil.waitMemberTransactions(__mysql_sandbox_port2, __mysql_sandbox_port1);
+testutil.waitMemberTransactions(__mysql_sandbox_port3, __mysql_sandbox_port1);
+
+session2.runSql("STOP SLAVE");
+session2.runSql("CHANGE " + get_replication_source_keyword() + " TO " + get_replication_option_keyword() + "_USER='foo', " + get_replication_option_keyword() + "_PASSWORD='foo_pwd', GET_" + get_replication_option_keyword() + "_PUBLIC_KEY=1");
+session2.runSql("START SLAVE");
+
+session3.runSql("STOP SLAVE");
+session3.runSql("CHANGE " + get_replication_source_keyword() + " TO " + get_replication_option_keyword() + "_USER='bar', " + get_replication_option_keyword() + "_PASSWORD='bar_pwd', GET_" + get_replication_option_keyword() + "_PUBLIC_KEY=1");
+session3.runSql("START SLAVE");
+
+var rs = dba.createReplicaSet("myrs", {adoptFromAR:true});
+EXPECT_OUTPUT_CONTAINS("A new replication user was created for each instance of the ReplicaSet, which means that the following users are unused and should be removed: 'foo', 'bar'");
+
+reset_instance(session);
+reset_instance(session2);
+reset_instance(session3);
+
 // Options
 //--------------------------------
 
@@ -432,34 +479,6 @@ EXPECT_JSON_EQ(clean(snap2), clean(repl_snapshot(session2)));
 reset_instance(session);
 reset_instance(session2);
 
-//@<> Check if instances are ignored if report-host isn't set
-testutil.removeFromSandboxConf(__mysql_sandbox_port1, "report_host");
-testutil.removeFromSandboxConf(__mysql_sandbox_port2, "report_host");
-
-testutil.restartSandbox(__mysql_sandbox_port1);
-testutil.restartSandbox(__mysql_sandbox_port2);
-
-shell.connect(__sandbox_uri1);
-
-var rs;
-EXPECT_NO_THROWS(function(){
-    rs = dba.createReplicaSet("myrs", {gtidSetIsComplete: true});
-    rs.addInstance(__sandbox_uri2);
-});
-
-EXPECT_EQ("", session.runSql("show replicas").fetchOne().Host);
-
-dba.dropMetadataSchema({force:true});
-testutil.waitMemberTransactions(__mysql_sandbox_port2, __mysql_sandbox_port1);
-
-EXPECT_THROWS(function(){
-    rs = dba.createReplicaSet("myrs", {gtidSetIsComplete: true, adoptFromAR: true});
-}, "Target server is not part of an async replication topology");
-
-EXPECT_OUTPUT_CONTAINS(`Instance 'cd93e780-b558-11ea-b3de-0242ac130005' (a replica of '${hostname}:${__mysql_sandbox_port1}') doesn't have the 'report_host' variable properly configured: ':${__mysql_sandbox_port2}'`);
-EXPECT_OUTPUT_CONTAINS(`In order to discover all available replicas, each one must have the 'report_host' variable set, otherwise they can't be uniquely identified and reached from '${hostname}:${__mysql_sandbox_port1}'. Please configure the 'report_host' variable of instance 'cd93e780-b558-11ea-b3de-0242ac130005'.`);
-EXPECT_OUTPUT_CONTAINS(`ERROR: Ignoring replica 'cd93e780-b558-11ea-b3de-0242ac130005', connected to '${hostname}:${__mysql_sandbox_port1}', because its address can't be resolved: ':${__mysql_sandbox_port2}'`)
-
 //@<> Cleanup
 testutil.destroySandbox(__mysql_sandbox_port1);
 testutil.destroySandbox(__mysql_sandbox_port2);
