@@ -110,7 +110,7 @@ rs = dba.createReplicaSet("myrs");
 rs.addInstance(__sandbox_uri3, {recoveryMethod: "incremental"});
 
 // STOP SLAVE on instance 3 to simulate the rejoins
-session3.runSql("STOP SLAVE");
+session3.runSql("STOP " + get_replica_keyword());
 
 var gtid_executed = session.runSql("SELECT @@global.gtid_executed").fetchOne()[0];
 
@@ -147,12 +147,12 @@ rs.rejoinInstance(__sandbox_uri3, {interactive: false, recoveryMethod: "clone"})
 //      CONTINUE WITH CLONE
 
 //@ addInstance: recoveryMethod:clone, interactive, make sure no prompts {VER(>=8.0.17)}
-session2.runSql("RESET MASTER");
+session2.runSql("RESET " + get_reset_binary_logs_keyword());
 mark_gtid_set_complete(false);
 rs.addInstance(__sandbox_uri2, {interactive:true, recoveryMethod:"clone"});
 
 //@ rejoinInstance: recoveryMethod:clone, interactive, make sure no prompts {VER(>=8.0.17)}
-session3.runSql("RESET MASTER");
+session3.runSql("RESET " + get_reset_binary_logs_keyword());
 mark_gtid_set_complete(false);
 rs.rejoinInstance(__sandbox_uri3, {interactive:true, recoveryMethod:"clone"});
 
@@ -175,12 +175,12 @@ rs.rejoinInstance(__sandbox_uri3, {recoveryMethod: "clone"});
 mark_gtid_set_complete(false);
 
 //@ addInstance: recoveryMethod:clone, subset GTIDs -> clone {VER(>=8.0.17)}
-session2.runSql("RESET MASTER");
+session2.runSql("RESET " + get_reset_binary_logs_keyword());
 session2.runSql("SET GLOBAL gtid_purged=?", [gtid_executed]);
 rs.addInstance(__sandbox_uri2, {recoveryMethod: "clone"});
 
 //@ rejoinInstance: recoveryMethod:clone, subset GTIDs -> clone {VER(>=8.0.17)}
-session3.runSql("RESET MASTER");
+session3.runSql("RESET " + get_reset_binary_logs_keyword());
 session3.runSql("SET GLOBAL gtid_purged=?", [gtid_executed]);
 rs.rejoinInstance(__sandbox_uri3 , {recoveryMethod: "clone"});
 
@@ -203,14 +203,14 @@ rs.rejoinInstance(__sandbox_uri3 , {recoveryMethod: "clone"});
 //         ERROR "Incremental Recovery is not possible (GTID state not compatible)"
 
 //@ addInstance: recoveryMethod:incremental, interactive, make sure no prompts {VER(>= 8.0.0)}
-session2.runSql("RESET MASTER");
+session2.runSql("RESET " + get_reset_binary_logs_keyword());
 mark_gtid_set_complete(false);
 rs.addInstance(__sandbox_uri2, {interactive:true, recoveryMethod:"incremental"});
 EXPECT_FALSE(clone_installed(session1));
 EXPECT_FALSE(clone_installed(session2));
 
 //@ rejoinInstance: recoveryMethod:incremental, interactive, error {VER(>= 8.0.0)}
-session3.runSql("RESET MASTER");
+session3.runSql("RESET " + get_reset_binary_logs_keyword());
 mark_gtid_set_complete(false);
 rs.rejoinInstance(__sandbox_uri3, {interactive:true, recoveryMethod:"incremental"});
 
@@ -228,14 +228,14 @@ EXPECT_FALSE(clone_installed(session2));
 EXPECT_FALSE(clone_installed(session3));
 
 //@ addInstance: recoveryMethod:incremental, subset GTIDs -> incr {VER(>= 8.0.0)}
-session2.runSql("RESET MASTER");
+session2.runSql("RESET " + get_reset_binary_logs_keyword());
 session2.runSql("SET GLOBAL gtid_purged=?", [gtid_executed]);
 rs.addInstance(__sandbox_uri2, {recoveryMethod:"incremental"});
 EXPECT_FALSE(clone_installed(session1));
 EXPECT_FALSE(clone_installed(session2));
 
 //@ rejoinInstance: recoveryMethod:incremental, subset GTIDs -> incr {VER(>= 8.0.0)}
-session3.runSql("RESET MASTER");
+session3.runSql("RESET " + get_reset_binary_logs_keyword());
 session3.runSql("SET GLOBAL gtid_purged=?", [gtid_executed]);
 rs.rejoinInstance(__sandbox_uri3, {recoveryMethod:"incremental"});
 EXPECT_FALSE(clone_installed(session1));
@@ -243,14 +243,14 @@ EXPECT_FALSE(clone_installed(session2));
 EXPECT_FALSE(clone_installed(session3));
 
 //@ addInstance: recoveryMethod:incremental, errant GTIDs -> error {VER(>= 8.0.0)}
-session2.runSql("RESET MASTER");
+session2.runSql("RESET " + get_reset_binary_logs_keyword());
 session2.runSql("SET GLOBAL gtid_purged=?", [gtid_executed+",00025721-1111-1111-1111-111111111111:1"]);
 rs.addInstance(__sandbox_uri2, {recoveryMethod:"incremental"});
 EXPECT_FALSE(clone_installed(session1));
 EXPECT_FALSE(clone_installed(session2));
 
 //@ rejoinInstance: recoveryMethod:incremental, errant GTIDs -> error {VER(>= 8.0.0)}
-session3.runSql("RESET MASTER");
+session3.runSql("RESET " + get_reset_binary_logs_keyword());
 session3.runSql("SET GLOBAL gtid_purged=?", [gtid_executed+",00025721-1111-1111-1111-111111111111:1"]);
 rs.rejoinInstance(__sandbox_uri3, {recoveryMethod:"incremental"});
 EXPECT_FALSE(clone_installed(session1));
@@ -278,14 +278,14 @@ shell.connect(__sandbox_uri1);
 
 //@ addInstance: recoveryMethod:auto, interactive, clone unavailable, empty GTID -> prompt i/a {VER(>= 8.0.0) && VER(< 8.0.17)}
 testutil.expectPrompt("Please select a recovery method [I]ncremental recovery/[A]bort (default Incremental recovery): ", "a");
-session2.runSql("RESET MASTER");
+session2.runSql("RESET " + get_reset_binary_logs_keyword());
 mark_gtid_set_complete(false);
 rs.addInstance(__sandbox_uri2, {interactive: true});
 EXPECT_FALSE(clone_installed(session1));
 EXPECT_FALSE(clone_installed(session2));
 
 //@ rejoinInstance: recoveryMethod:auto, interactive, clone unavailable, empty GTID -> error {VER(>= 8.0.0) && VER(< 8.0.17)}
-session3.runSql("RESET MASTER");
+session3.runSql("RESET " + get_reset_binary_logs_keyword());
 mark_gtid_set_complete(false);
 rs.rejoinInstance(__sandbox_uri3, {interactive: true});
 EXPECT_FALSE(clone_installed(session1));
@@ -294,7 +294,7 @@ EXPECT_FALSE(clone_installed(session3));
 
 //@ addInstance: recoveryMethod:auto, interactive, empty GTID -> prompt c/i/a {VER(>= 8.0.19)}
 testutil.expectPrompt("Please select a recovery method [C]lone/[I]ncremental recovery/[A]bort (default Clone): ", "i");
-session2.runSql("RESET MASTER");
+session2.runSql("RESET " + get_reset_binary_logs_keyword());
 mark_gtid_set_complete(false);
 rs.addInstance(__sandbox_uri2, {interactive: true});
 EXPECT_FALSE(clone_installed(session1));
@@ -302,7 +302,7 @@ EXPECT_FALSE(clone_installed(session2));
 
 //@ rejoinInstance: recoveryMethod:auto, interactive, empty GTID -> prompt c/a {VER(>= 8.0.19)}
 testutil.expectPrompt("Please select a recovery method [C]lone/[A]bort (default Abort): ", "c");
-session3.runSql("RESET MASTER");
+session3.runSql("RESET " + get_reset_binary_logs_keyword());
 mark_gtid_set_complete(false);
 rs.rejoinInstance(__sandbox_uri3, {interactive: true});
 EXPECT_FALSE(clone_installed(session1));
@@ -325,7 +325,7 @@ EXPECT_FALSE(clone_installed(session3));
 mark_gtid_set_complete(false);
 
 //@ addInstance: recoveryMethod:auto, interactive, errant GTIDs -> prompt c/a {VER(>= 8.0.19)}
-session2.runSql("RESET MASTER");
+session2.runSql("RESET " + get_reset_binary_logs_keyword());
 session2.runSql("SET GLOBAL gtid_purged=?", [gtid_executed+",00025721-1111-1111-1111-111111111111:1"]);
 testutil.expectPrompt("Please select a recovery method [C]lone/[A]bort (default Abort): ", "a");
 rs.addInstance(__sandbox_uri2, {interactive:true});
@@ -333,7 +333,7 @@ EXPECT_FALSE(clone_installed(session1));
 EXPECT_FALSE(clone_installed(session2));
 
 //@ rejoinInstance: recoveryMethod:auto, interactive, errant GTIDs -> error {VER(>= 8.0.19)}
-session3.runSql("RESET MASTER");
+session3.runSql("RESET " + get_reset_binary_logs_keyword());
 session3.runSql("SET GLOBAL gtid_purged=?", [gtid_executed+",00025721-1111-1111-1111-111111111111:1"]);
 rs.rejoinInstance(__sandbox_uri3, {interactive:true});
 EXPECT_FALSE(clone_installed(session1));
@@ -341,14 +341,14 @@ EXPECT_FALSE(clone_installed(session2));
 EXPECT_FALSE(clone_installed(session3));
 
 //@ addInstance: recoveryMethod:auto, interactive, errant GTIDs -> error clone not supported {VER(>= 8.0.0) && VER(< 8.0.17)}
-session2.runSql("RESET MASTER");
+session2.runSql("RESET " + get_reset_binary_logs_keyword());
 session2.runSql("SET GLOBAL gtid_purged=?", [gtid_executed+",00025721-1111-1111-1111-111111111111:1"]);
 rs.addInstance(__sandbox_uri2, {interactive:true});
 EXPECT_FALSE(clone_installed(session1));
 EXPECT_FALSE(clone_installed(session2));
 
 //@ rejoinInstance: recoveryMethod:auto, interactive, errant GTIDs -> error clone not supported {VER(>= 8.0.0) && VER(< 8.0.17)}
-session3.runSql("RESET MASTER");
+session3.runSql("RESET " + get_reset_binary_logs_keyword());
 session3.runSql("SET GLOBAL gtid_purged=?", [gtid_executed+",00025721-1111-1111-1111-111111111111:1"]);
 rs.rejoinInstance(__sandbox_uri3, {interactive:true});
 EXPECT_FALSE(clone_installed(session1));
@@ -358,14 +358,14 @@ EXPECT_FALSE(clone_installed(session3));
 // Non-interactive tests
 
 //@ addInstance: recoveryMethod:auto, non-interactive, empty GTID -> error {VER(>= 8.0.19)}
-session2.runSql("RESET MASTER");
+session2.runSql("RESET " + get_reset_binary_logs_keyword());
 mark_gtid_set_complete(false);
 rs.addInstance(__sandbox_uri2, {interactive: false});
 EXPECT_FALSE(clone_installed(session1));
 EXPECT_FALSE(clone_installed(session2));
 
 //@ rejoinInstance: recoveryMethod:auto, non-interactive, empty GTID -> error {VER(>= 8.0.19)}
-session3.runSql("RESET MASTER");
+session3.runSql("RESET " + get_reset_binary_logs_keyword());
 mark_gtid_set_complete(false);
 rs.rejoinInstance(__sandbox_uri3, {interactive: false});
 EXPECT_FALSE(clone_installed(session1));
@@ -373,14 +373,14 @@ EXPECT_FALSE(clone_installed(session2));
 EXPECT_FALSE(clone_installed(session3));
 
 //@ addInstance: recoveryMethod:auto, non-interactive, clone not supported, empty GTID -> error {VER(>= 8.0.0) && VER(< 8.0.17)}
-session2.runSql("RESET MASTER");
+session2.runSql("RESET " + get_reset_binary_logs_keyword());
 mark_gtid_set_complete(false);
 rs.addInstance(__sandbox_uri2, {interactive:false});
 EXPECT_FALSE(clone_installed(session1));
 EXPECT_FALSE(clone_installed(session2));
 
 //@ rejoinInstance: recoveryMethod:auto, non-interactive, clone not supported, empty GTID -> error {VER(>= 8.0.0) && VER(< 8.0.17)}
-session3.runSql("RESET MASTER");
+session3.runSql("RESET " + get_reset_binary_logs_keyword());
 mark_gtid_set_complete(false);
 rs.rejoinInstance(__sandbox_uri3, {interactive:false});
 EXPECT_FALSE(clone_installed(session1));
@@ -403,14 +403,14 @@ EXPECT_FALSE(clone_installed(session3));
 mark_gtid_set_complete(false);
 
 //@ addInstance: recoveryMethod:auto, non-interactive, subset GTIDs -> incr {VER(>=8.0.17)}
-session2.runSql("RESET MASTER");
+session2.runSql("RESET " + get_reset_binary_logs_keyword());
 session2.runSql("SET GLOBAL gtid_purged=?", [gtid_executed]);
 rs.addInstance(__sandbox_uri2, {interactive:false});
 EXPECT_FALSE(clone_installed(session1));
 EXPECT_FALSE(clone_installed(session2));
 
 //@ rejoinInstance: recoveryMethod:auto, non-interactive, subset GTIDs -> incr {VER(>=8.0.17)}
-session3.runSql("RESET MASTER");
+session3.runSql("RESET " + get_reset_binary_logs_keyword());
 session3.runSql("SET GLOBAL gtid_purged=?", [gtid_executed]);
 rs.rejoinInstance(__sandbox_uri3, {interactive:false});
 EXPECT_FALSE(clone_installed(session1));
@@ -418,14 +418,14 @@ EXPECT_FALSE(clone_installed(session2));
 EXPECT_FALSE(clone_installed(session3));
 
 //@ addInstance: recoveryMethod:auto, non-interactive, errant GTIDs -> error {VER(>=8.0.0)}
-session2.runSql("RESET MASTER");
+session2.runSql("RESET " + get_reset_binary_logs_keyword());
 session2.runSql("SET GLOBAL gtid_purged=?", [gtid_executed+",00025721-1111-1111-1111-111111111111:1"]);
 rs.addInstance(__sandbox_uri2, {interactive:false});
 EXPECT_FALSE(clone_installed(session1));
 EXPECT_FALSE(clone_installed(session2));
 
 //@ rejoinInstance: recoveryMethod:auto, non-interactive, errant GTIDs -> error {VER(>=8.0.0)}
-session3.runSql("RESET MASTER");
+session3.runSql("RESET " + get_reset_binary_logs_keyword());
 session3.runSql("SET GLOBAL gtid_purged=?", [gtid_executed+",00025721-1111-1111-1111-111111111111:1"]);
 rs.rejoinInstance(__sandbox_uri3, {interactive:false});
 EXPECT_FALSE(clone_installed(session1));
@@ -442,8 +442,8 @@ EXPECT_FALSE(clone_installed(session3));
 session.runSql("FLUSH BINARY LOGS");
 session.runSql("PURGE BINARY LOGS BEFORE DATE_ADD(NOW(6), INTERVAL 1 DAY)");
 
-session2.runSql("RESET MASTER");
-session3.runSql("RESET MASTER");
+session2.runSql("RESET " + get_reset_binary_logs_keyword());
+session3.runSql("RESET " + get_reset_binary_logs_keyword());
 
 //@ addInstance: recoveryMethod:auto, interactive, purged GTID -> prompt c/a {VER(>=8.0.17)}
 testutil.expectPrompt("Please select a recovery method [C]lone/[A]bort (default Clone): ", "a");
@@ -457,14 +457,14 @@ rs.addInstance(__sandbox_uri2, {interactive: false});
 // BUG#30884590: ADDING AN INSTANCE WITH COMPATIBLE GTID SET SHOULDN'T PROMPT FOR CLONE
 //@ addInstance: recoveryMethod:auto, interactive, purged GTID, subset gtid -> clone, no prompt {VER(>=8.0.17)}
 mark_gtid_set_complete(false);
-session2.runSql("RESET MASTER");
+session2.runSql("RESET " + get_reset_binary_logs_keyword());
 session2.runSql("SET GLOBAL gtid_purged=?", [gtid_executed]);
 
 rs.addInstance(__sandbox_uri2, {interactive: true});
 
 //@ addInstance: recoveryMethod:auto, no-interactive, purged GTID, subset gtid -> clone, no prompt {VER(>=8.0.17)}
 mark_gtid_set_complete(false);
-session2.runSql("RESET MASTER");
+session2.runSql("RESET " + get_reset_binary_logs_keyword());
 session2.runSql("SET GLOBAL gtid_purged=?", [gtid_executed]);
 
 rs.addInstance(__sandbox_uri2, {interactive: false});
@@ -477,7 +477,7 @@ rs.rejoinInstance(__sandbox_uri3, {interactive: true});
 // BUG#30884590: ADDING AN INSTANCE WITH COMPATIBLE GTID SET SHOULDN'T PROMPT FOR CLONE
 //@ rejoinInstance: recoveryMethod:auto, interactive, purged GTID, subset gtid -> clone, no prompt {VER(>=8.0.17)}
 mark_gtid_set_complete(false);
-session3.runSql("RESET MASTER");
+session3.runSql("RESET " + get_reset_binary_logs_keyword());
 session3.runSql("SET GLOBAL gtid_purged=?", [gtid_executed]);
 
 rs.rejoinInstance(__sandbox_uri3, {interactive: true});
@@ -485,59 +485,59 @@ rs.rejoinInstance(__sandbox_uri3, {interactive: true});
 // BUG#30884590: ADDING AN INSTANCE WITH COMPATIBLE GTID SET SHOULDN'T PROMPT FOR CLONE
 //@ rejoinInstance: recoveryMethod:auto, no-interactive, purged GTID, subset gtid -> clone, no prompt {VER(>=8.0.17)}
 mark_gtid_set_complete(false);
-session3.runSql("RESET MASTER");
+session3.runSql("RESET " + get_reset_binary_logs_keyword());
 session3.runSql("SET GLOBAL gtid_purged=?", [gtid_executed]);
 
 rs.rejoinInstance(__sandbox_uri3, {interactive: false});
 
 //@ addInstance: recoveryMethod:auto, interactive, errant GTIDs + purged GTIDs -> prompt c/a {VER(>=8.0.17)}
-session2.runSql("RESET MASTER");
+session2.runSql("RESET " + get_reset_binary_logs_keyword());
 session2.runSql("SET GLOBAL gtid_purged=?", ["00025721-1111-1111-1111-111111111111:1"]);
 testutil.expectPrompt("Please select a recovery method [C]lone/[A]bort (default Abort): ", "a");
 rs.addInstance(__sandbox_uri2, {interactive: true});
 
 //@ rejoinInstance: recoveryMethod:auto, interactive, errant GTIDs + purged GTIDs -> error {VER(>=8.0.17)}
-session3.runSql("RESET MASTER");
+session3.runSql("RESET " + get_reset_binary_logs_keyword());
 session3.runSql("SET GLOBAL gtid_purged=?", ["00025721-1111-1111-1111-111111111111:1"]);
 rs.rejoinInstance(__sandbox_uri3, {interactive: true});
 
 //@ addInstance: recoveryMethod:incremental, purged GTID -> error {VER(>= 8.0.0)}
-session2.runSql("RESET MASTER");
+session2.runSql("RESET " + get_reset_binary_logs_keyword());
 mark_gtid_set_complete(false);
 rs.addInstance(__sandbox_uri2, {recoveryMethod: "incremental"});
 
 //@ rejoinInstance: recoveryMethod:incremental, purged GTID -> error {VER(>= 8.0.0)}
-session3.runSql("RESET MASTER");
+session3.runSql("RESET " + get_reset_binary_logs_keyword());
 mark_gtid_set_complete(false);
 rs.rejoinInstance(__sandbox_uri3, {recoveryMethod: "incremental"});
 
 //@ addInstance: recoveryMethod:incremental, errant GTIDs + purged GTIDs -> error {VER(>= 8.0.0)}
-session2.runSql("RESET MASTER");
+session2.runSql("RESET " + get_reset_binary_logs_keyword());
 session2.runSql("SET GLOBAL gtid_purged=?", ["00025721-1111-1111-1111-111111111111:1"]);
 rs.addInstance(__sandbox_uri2, {recoveryMethod: "incremental"});
 
 //@ rejoinInstance: recoveryMethod:incremental, errant GTIDs + purged GTIDs -> error {VER(>= 8.0.0)}
-session3.runSql("RESET MASTER");
+session3.runSql("RESET " + get_reset_binary_logs_keyword());
 session3.runSql("SET GLOBAL gtid_purged=?", ["00025721-1111-1111-1111-111111111111:1"]);
 rs.rejoinInstance(__sandbox_uri3, {recoveryMethod: "incremental"});
 
 //@ addInstance: recoveryMethod:clone, purged GTID -> clone {VER(>=8.0.17)}
-session2.runSql("RESET MASTER");
+session2.runSql("RESET " + get_reset_binary_logs_keyword());
 mark_gtid_set_complete(false);
 rs.addInstance(__sandbox_uri2, {recoveryMethod:"clone"});
 
 //@ rejoinInstance: recoveryMethod:clone, purged GTID -> clone {VER(>=8.0.17)}
-session3.runSql("RESET MASTER");
+session3.runSql("RESET " + get_reset_binary_logs_keyword());
 mark_gtid_set_complete(false);
 rs.rejoinInstance(__sandbox_uri3, {recoveryMethod:"clone"});
 
 //@ addInstance: recoveryMethod:clone, errant GTIDs + purged GTIDs -> clone {VER(>=8.0.17)}
-session2.runSql("RESET MASTER");
+session2.runSql("RESET " + get_reset_binary_logs_keyword());
 session2.runSql("SET GLOBAL gtid_purged=?", [gtid_executed+",00025721-1111-1111-1111-111111111111:1"]);
 rs.addInstance(__sandbox_uri2, {recoveryMethod:"clone"});
 
 //@ rejoinInstance: recoveryMethod:clone, errant GTIDs + purged GTIDs -> clone {VER(>=8.0.17)}
-session3.runSql("RESET MASTER");
+session3.runSql("RESET " + get_reset_binary_logs_keyword());
 session3.runSql("SET GLOBAL gtid_purged=?", [gtid_executed+",00025721-1111-1111-1111-111111111111:1"]);
 rs.rejoinInstance(__sandbox_uri3, {recoveryMethod:"clone"});
 
