@@ -173,7 +173,7 @@
 |this method by default, set the 'recoveryMethod' option to 'incremental'.|
 ||
 |ERROR: The target instance must be either cloned or fully re-provisioned before it can be re-added to the target replicaset.|
-|Built-in clone support is available starting with MySQL 8.0.17 and is the recommended method for provisioning instances.|
+|Built-in clone support is available starting with MySQL 8.0.17 and is the recommended method for provisioning instances. Instance is running MySQL <<<__version>>>.|
 ||Instance provisioning required (MYSQLSH 51153)
 
 //@ addInstance: recoveryMethod:auto, interactive, empty GTID -> prompt c/i/a {VER(>= 8.0.19)}
@@ -254,11 +254,11 @@
 |contains transactions that do not originate from the replicaset, which must be|
 |discarded before it can join the replicaset.|
 ||
-|<<<hostname_ip>>>:<<<__mysql_sandbox_port2>>> has the following errant GTIDs that do not exist in the replicaset:|
+|Instance '<<<hostname_ip>>>:<<<__mysql_sandbox_port2>>>' has the following errant GTIDs that do not exist in the replicaset:|
 |00025721-1111-1111-1111-111111111111:1|
 ||
 |WARNING: Discarding these extra GTID events can either be done manually or by completely|
-|overwriting the state of <<<hostname_ip>>>:<<<__mysql_sandbox_port2>>> with a physical snapshot from an|
+|overwriting the state of '<<<hostname_ip>>>:<<<__mysql_sandbox_port2>>>' with a physical snapshot from an|
 |existing replicaset member. To use this method by default, set the|
 |'recoveryMethod' option to 'clone'.|
 ||
@@ -278,11 +278,11 @@
 |contains transactions that do not originate from the replicaset, which must be|
 |discarded before it can join the replicaset.|
 ||
-|<<<hostname_ip>>>:<<<__mysql_sandbox_port3>>> has the following errant GTIDs that do not exist in the replicaset:|
+|Instance '<<<hostname_ip>>>:<<<__mysql_sandbox_port3>>>' has the following errant GTIDs that do not exist in the replicaset:|
 |00025721-1111-1111-1111-111111111111:1|
 ||
 |WARNING: Discarding these extra GTID events can either be done manually or by completely|
-|overwriting the state of <<<hostname_ip>>>:<<<__mysql_sandbox_port3>>> with a physical snapshot from an|
+|overwriting the state of '<<<hostname_ip>>>:<<<__mysql_sandbox_port3>>>' with a physical snapshot from an|
 |existing replicaset member. To use this method by default, set the|
 |'recoveryMethod' option to 'clone'.|
 ||
@@ -307,11 +307,11 @@
 |contains transactions that do not originate from the replicaset, which must be|
 |discarded before it can join the replicaset.|
 ||
-|<<<hostname_ip>>>:<<<__mysql_sandbox_port2>>> has the following errant GTIDs that do not exist in the replicaset:|
+|Instance '<<<hostname_ip>>>:<<<__mysql_sandbox_port2>>>' has the following errant GTIDs that do not exist in the replicaset:|
 |00025721-1111-1111-1111-111111111111:1|
 ||
 |WARNING: Discarding these extra GTID events can either be done manually or by completely|
-|overwriting the state of <<<hostname_ip>>>:<<<__mysql_sandbox_port2>>> with a physical snapshot from an|
+|overwriting the state of '<<<hostname_ip>>>:<<<__mysql_sandbox_port2>>>' with a physical snapshot from an|
 |existing replicaset member. To use this method by default, set the|
 |'recoveryMethod' option to 'clone'.|
 ||
@@ -319,7 +319,7 @@
 |this further and ensure that the data can be removed prior to choosing the|
 |clone recovery method.|
 |ERROR: The target instance must be either cloned or fully provisioned before it can be added to the target replicaset.|
-|Built-in clone support is available starting with MySQL 8.0.17 and is the recommended method for provisioning instances.|
+|Built-in clone support is available starting with MySQL 8.0.17 and is the recommended method for provisioning instances. Instance is running MySQL <<<__version>>>.|
 
 ||Instance provisioning required (MYSQLSH 51153)
 
@@ -391,11 +391,11 @@
 ||debug (LogicError)
 
 //@ addInstance: recoveryMethod:auto, non-interactive, errant GTIDs -> error {VER(>=8.0.0)}
-|<<<hostname_ip>>>:<<<__mysql_sandbox_port2>>> has the following errant GTIDs that do not exist in the replicaset:|
+|Instance '<<<hostname_ip>>>:<<<__mysql_sandbox_port2>>>' has the following errant GTIDs that do not exist in the replicaset:|
 |00025721-1111-1111-1111-111111111111:1|
 ||
 |WARNING: Discarding these extra GTID events can either be done manually or by completely|
-|overwriting the state of <<<hostname_ip>>>:<<<__mysql_sandbox_port2>>> with a physical snapshot from an|
+|overwriting the state of '<<<hostname_ip>>>:<<<__mysql_sandbox_port2>>>' with a physical snapshot from an|
 |existing replicaset member. To use this method by default, set the|
 |'recoveryMethod' option to 'clone'.|
 ||
@@ -405,17 +405,17 @@
 |ERROR: The target instance must be either cloned or fully provisioned before it can be added to the target replicaset.|
 
 //@ addInstance: recoveryMethod:auto, non-interactive, errant GTIDs -> error {VER(>=8.0.0) && VER(<8.0.17)}
-|Built-in clone support is available starting with MySQL 8.0.17 and is the recommended method for provisioning instances.|
+|Built-in clone support is available starting with MySQL 8.0.17 and is the recommended method for provisioning instances. Instance is running MySQL <<<__version>>>.|
 
 //@ addInstance: recoveryMethod:auto, non-interactive, errant GTIDs -> error {VER(>=8.0.0)}
 ||Instance provisioning required (MYSQLSH 51153)
 
 //@ rejoinInstance: recoveryMethod:auto, non-interactive, errant GTIDs -> error {VER(>=8.0.0)}
-|<<<hostname_ip>>>:<<<__mysql_sandbox_port3>>> has the following errant GTIDs that do not exist in the replicaset:|
+|Instance '<<<hostname_ip>>>:<<<__mysql_sandbox_port3>>>' has the following errant GTIDs that do not exist in the replicaset:|
 |00025721-1111-1111-1111-111111111111:1|
 ||
 |WARNING: Discarding these extra GTID events can either be done manually or by completely|
-|overwriting the state of <<<hostname_ip>>>:<<<__mysql_sandbox_port3>>> with a physical snapshot from an|
+|overwriting the state of '<<<hostname_ip>>>:<<<__mysql_sandbox_port3>>>' with a physical snapshot from an|
 |existing replicaset member. To use this method by default, set the|
 |'recoveryMethod' option to 'clone'.|
 ||
@@ -425,7 +425,7 @@
 |ERROR: The target instance must be either cloned or fully re-provisioned before it can be re-added to the target replicaset.|
 
 //@ rejoinInstance: recoveryMethod:auto, non-interactive, errant GTIDs -> error {VER(>=8.0.0) && VER(<8.0.17)}
-|Built-in clone support is available starting with MySQL 8.0.17 and is the recommended method for provisioning instances.|
+|Built-in clone support is available starting with MySQL 8.0.17 and is the recommended method for provisioning instances. Instance is running MySQL <<<__version>>>.|
 
 //@ rejoinInstance: recoveryMethod:auto, non-interactive, errant GTIDs -> error {VER(>=8.0.0)}
 ||Instance provisioning required (MYSQLSH 51153)
