@@ -2,9 +2,8 @@
 |Account admin@% was successfully created.|
 |The instance '<<<hostname_ip>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB ReplicaSet.|
 |Account admin@% was successfully created.|
-|The instance '<<<hostname_ip>>>:<<<__mysql_sandbox_port2>>>' is already ready to be used in an InnoDB ReplicaSet.|
 |Account admin@% was successfully created.|
-|The instance '<<<hostname_ip>>>:<<<__mysql_sandbox_port3>>>' is already ready to be used in an InnoDB ReplicaSet.|
+|The instance '<<<hostname_ip>>>:<<<__mysql_sandbox_port3>>>' is valid for InnoDB ReplicaSet usage.|
 
 //@<OUT> createReplicaSet
 A new replicaset with instance '<<<hostname_ip>>>:<<<__mysql_sandbox_port1>>>' will be created.
@@ -135,7 +134,7 @@ The current PRIMARY is <<<hostname_ip>>>:<<<__mysql_sandbox_port1>>>.
 <<<hostname_ip>>>:<<<__mysql_sandbox_port3>>> was promoted to PRIMARY.
 
 //@# forcePrimaryInstance (prepare)
-|WARNING: Unable to connect to the PRIMARY of the ReplicaSet myrs: MYSQLSH 51118: Could not open connection to '<<<hostname_ip>>>:<<<__mysql_sandbox_port3>>>': Can't connect to MySQL server on '<<<libmysql_host_description(hostname_ip, __mysql_sandbox_port3)>>>'|
+|WARNING: Unable to connect to the PRIMARY of the ReplicaSet 'myrs': MYSQLSH 51118: Could not open connection to '<<<hostname_ip>>>:<<<__mysql_sandbox_port3>>>': Can't connect to MySQL server on '<<<libmysql_host_description(hostname_ip, __mysql_sandbox_port3)>>>'|
 |        "status": "UNAVAILABLE", |
 
 //@<OUT> forcePrimaryInstance
