@@ -42,7 +42,7 @@ NOTE: Some configuration options need to be fixed:
 | server_id                              | 1             | <unique ID>    | Update read-only variable and restart the server |
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
 ?{}
-?{VER(>=8.0.27)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
 | Variable                               | Current Value | Required Value | Note                                             |
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
@@ -52,6 +52,15 @@ NOTE: Some configuration options need to be fixed:
 | server_id                              | 1             | <unique ID>    | Update read-only variable and restart the server |
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
 ?{}
+?{VER(>=8.3.0)}
++--------------------------+---------------+----------------+--------------------------------------------------+
+| Variable                 | Current Value | Required Value | Note                                             |
++--------------------------+---------------+----------------+--------------------------------------------------+
+| enforce_gtid_consistency | OFF           | ON             | Update read-only variable and restart the server |
+| gtid_mode                | OFF           | ON             | Update read-only variable and restart the server |
+| server_id                | 1             | <unique ID>    | Update read-only variable and restart the server |
++--------------------------+---------------+----------------+--------------------------------------------------+
+?{}
 
 Some variables need to be changed, but cannot be done dynamically on the server.
 
@@ -59,8 +68,8 @@ Creating user admin@%.
 Account admin@% was successfully created.
 
 Configuring instance...
+?{(VER(>=8.0.35) && VER(<8.1.0)) || (VER(>=8.2.0) && VER(<8.3.0))}
 
-?{VER(>=8.2.0)}
 WARNING: '@@binlog_transaction_dependency_tracking' is deprecated and will be removed in a future release. (Code 1287).
 ?{}
 The instance '<<<__address1>>>' was configured to be used in an InnoDB ReplicaSet.
@@ -78,12 +87,11 @@ Assuming full account name 'admin'@'%' for admin
 applierWorkerThreads will be set to the default value of 4.
 ?{}
 
-The instance '<<<__address2>>>' is valid to be used in an InnoDB ReplicaSet.
-
 Creating user admin@%.
 Account admin@% was successfully created.
 
-The instance '<<<__address2>>>' is already ready to be used in an InnoDB ReplicaSet.
+
+The instance '<<<__address2>>>' is valid for InnoDB ReplicaSet usage.
 ?{VER(>=8.0.23)}
 
 Successfully enabled parallel appliers.
@@ -199,9 +207,9 @@ The current PRIMARY is 127.0.0.1:<<<__mysql_sandbox_port1>>>.
 127.0.0.1:<<<__mysql_sandbox_port3>>> was promoted to PRIMARY.
 
 //@<OUT> forcePrimaryInstance (prepare)
-WARNING: Unable to connect to the PRIMARY of the ReplicaSet myrs: MYSQLSH 51118: Could not open connection to '127.0.0.1:<<<__mysql_sandbox_port3>>>': Can't connect to MySQL server on '<<<libmysql_host_description('127.0.0.1', __mysql_sandbox_port3)>>>' ([[*]])
-Cluster change operations will not be possible unless the PRIMARY can be reached.
-If the PRIMARY is unavailable, you must either repair it or perform a forced failover.
+WARNING: Unable to connect to the PRIMARY of the ReplicaSet 'myrs': MYSQLSH 51118: Could not open connection to '127.0.0.1:<<<__mysql_sandbox_port3>>>': Can't connect to MySQL server on '<<<libmysql_host_description('127.0.0.1', __mysql_sandbox_port3)>>>' ([[*]])
+ReplicaSet change operations will not be possible unless the PRIMARY can be reached.
+If the PRIMARY is unavailable, you must either repair it or perform a failover.
 See \help forcePrimaryInstance for more information.
 {
     "replicaSet": {
@@ -381,7 +389,7 @@ true
                     "receiverStatus": "ON",
                     "receiverThreadState": "Waiting for <<<__source_keyword>>> to send event",
                     "replicationLag": null,
-                    "replicationSsl": null,
+                    "replicationSsl": "[[*]]",
                     "replicationSslMode": "REQUIRED"
                 },
                 "status": "ONLINE"
@@ -396,7 +404,7 @@ true
                     "receiverStatus": "ON",
                     "receiverThreadState": "Waiting for <<<__source_keyword>>> to send event",
                     "replicationLag": null,
-                    "replicationSsl": null,
+                    "replicationSsl": "[[*]]",
                     "replicationSslMode": "REQUIRED"
                 },
                 "status": "ONLINE"
