@@ -126,7 +126,9 @@ CHECK_CLUSTER_SET(session);
 
 // promoting cluster2 should be OK
 EXPECT_NO_THROWS(function() { cs.setPrimaryCluster("cluster2"); } );
-EXPECT_OUTPUT_CONTAINS("* Reconciling 1 internally generated GTIDs");
+if (__version_num < 80300) {
+  EXPECT_OUTPUT_CONTAINS("* Reconciling 1 internally generated GTIDs");
+}
 
 testutil.waitMemberTransactions(__mysql_sandbox_port4, __mysql_sandbox_port1);
 
@@ -218,7 +220,7 @@ CHECK_REPLICA_CLUSTER([__sandbox_uri4], c1, c2);
 CHECK_REPLICA_CLUSTER([__sandbox_uri5], c1, c3);
 CHECK_CLUSTER_SET(session);
 
-session5.runSql("show slave status");
+session5.runSql("show " + get_replica_keyword() + " status");
 
 //@<> Switch primary 3/1/1
 
