@@ -309,6 +309,10 @@ OPTIONS
             a list of valid partition names used to limit the data copy to just
             the specified partitions. Default: not set.
 
+--checksum=<bool>
+            Compute checksums of the data and verify tables in the target
+            instance against these checksums. Default: false.
+
 --excludeTables=<str list>
             List of tables or views to be excluded from the copy in the format
             of schema.table. Default: empty.
@@ -509,6 +513,10 @@ OPTIONS
             a list of valid partition names used to limit the data copy to just
             the specified partitions. Default: not set.
 
+--checksum=<bool>
+            Compute checksums of the data and verify tables in the target
+            instance against these checksums. Default: false.
+
 --excludeTables=<str list>
             List of tables or views to be excluded from the copy in the format
             of schema.table. Default: empty.
@@ -691,6 +699,10 @@ OPTIONS
             a list of valid partition names used to limit the data copy to just
             the specified partitions. Default: not set.
 
+--checksum=<bool>
+            Compute checksums of the data and verify tables in the target
+            instance against these checksums. Default: false.
+
 --all=<bool>
             Copy all views and tables from the specified schema, requires the
             tables argument to be an empty list. Default: false.
@@ -882,6 +894,9 @@ OPTIONS
             a list of valid partition names used to limit the data export to
             just the specified partitions. Default: not set.
 
+--checksum=<bool>
+            Compute and include checksum of the dumped data. Default: false.
+
 --osBucketName=<str>
             Use specified OCI bucket for the location of the dump. Default: not
             set.
@@ -1120,6 +1135,9 @@ OPTIONS
             a list of valid partition names used to limit the data export to
             just the specified partitions. Default: not set.
 
+--checksum=<bool>
+            Compute and include checksum of the dumped data. Default: false.
+
 --osBucketName=<str>
             Use specified OCI bucket for the location of the dump. Default: not
             set.
@@ -1339,6 +1357,9 @@ OPTIONS
             a list of valid partition names used to limit the data export to
             just the specified partitions. Default: not set.
 
+--checksum=<bool>
+            Compute and include checksum of the dumped data. Default: false.
+
 --osBucketName=<str>
             Use specified OCI bucket for the location of the dump. Default: not
             set.
@@ -1945,6 +1966,10 @@ OPTIONS
             continues, "ignore": ignores the error and continues loading the
             account.
 
+--checksum=<bool>
+            Verify tables against checksums that were computed during dump.
+            Default: false.
+
 --osBucketName=<str>
             Use specified OCI bucket for the location of the dump. Default: not
             set.
