@@ -48,8 +48,10 @@ manifest_par=create_par(OS_NAMESPACE, OS_BUCKET_NAME, "ObjectRead", "manifest-pa
 manifest_par_converted = convert_par(manifest_par)
 
 #@<> WL14154-TSFR7_1 - When doing a load using a PAR for a manifest file with the progressFile option not set. Validate that the load fail because progressFile option is mandatory.
+WIPE_OUTPUT()
 PREPARE_PAR_IS_SECRET_TEST()
 EXPECT_THROWS(lambda:util.load_dump(manifest_par), "Util.load_dump: When using a PAR to load a dump, the progressFile option must be defined")
+EXPECT_STDOUT_CONTAINS("Support for PAR Manifest is deprecated and will be removed in a future release. Please use a prefix PAR instead.")
 EXPECT_PAR_IS_SECRET()
 
 #@<> Attempt to load using a manifest PAR as progress PAR.
@@ -86,11 +88,13 @@ for par in [progress_par, progress_par_converted]:
     delete_object(OS_BUCKET_NAME, "shell-test/par-load-progress.json", OS_NAMESPACE)
 
 #@<> Use the progressFile option set to a read/write PAR object for a file that is not in the same bucket where the dump is.
+WIPE_OUTPUT()
 prepare_empty_bucket(OS_BUCKET_NAME + '-par-test', OS_NAMESPACE)
 progress_par=create_par(OS_NAMESPACE, OS_BUCKET_NAME + '-par-test', "ObjectReadWrite", "manifest-par", today_plus_days(1, RFC3339), "shell-test/another-bucket-progress.json")
 
 PREPARE_PAR_IS_SECRET_TEST()
 EXPECT_NO_THROWS(lambda:util.load_dump(manifest_par, {"progressFile": progress_par}), "load_dump() using PAR progress file in another bucket")
+EXPECT_STDOUT_CONTAINS("Support for PAR Manifest is deprecated and will be removed in a future release. Please use a prefix PAR instead.")
 EXPECT_PAR_IS_SECRET()
 
 # verify if everything was OK
@@ -131,7 +135,7 @@ EXPECT_THROWS(lambda:util.load_dump(manifest_par, {"progressFile": progress_par}
 EXPECT_PAR_IS_SECRET()
 
 # BUG#32593125 - check if details of failed operation are logged
-EXPECT_SHELL_LOG_CONTAINS(f"Warning: Request failed: https://objectstorage.{config['region']}.oraclecloud.com/p/<secret>/n/{OS_NAMESPACE}/b/{OS_BUCKET_NAME}/o/shell-test/ PUT read-only-progress.json (404 - Not Found)")
+EXPECT_SHELL_LOG_CONTAINS(f"Warning: Request failed: https://{OS_NAMESPACE}.objectstorage.{config['region']}.oci.customer-oci.com/p/<secret>/n/{OS_NAMESPACE}/b/{OS_BUCKET_NAME}/o/shell-test/ PUT read-only-progress.json (404 - Not Found)")
 EXPECT_SHELL_LOG_CONTAINS("Info: REQUEST HEADERS:")
 EXPECT_SHELL_LOG_CONTAINS("Info: RESPONSE HEADERS:")
 EXPECT_SHELL_LOG_CONTAINS("Info: RESPONSE BODY:")
@@ -187,7 +191,7 @@ delete_object(OS_BUCKET_NAME, "shell-test/par-load-progress.json", OS_NAMESPACE)
 progress_par=create_par(OS_NAMESPACE, OS_BUCKET_NAME, "ObjectRead", "manifest-par", today_plus_days(1, RFC3339), "shell-test/par-load-progress.json")
 
 PREPARE_PAR_IS_SECRET_TEST()
-EXPECT_THROWS(lambda: util.load_dump(manifest_par, {"progressFile": progress_par}), f"Error: Shell Error (54404): Util.load_dump: Failed to put object 'https://objectstorage.{config['region']}.oraclecloud.com/p/<secret>/n/{OS_NAMESPACE}/b/{OS_BUCKET_NAME}/o/shell-test/par-load-progress.json': BucketNotFound: Either the bucket named '{OS_BUCKET_NAME}' does not exist in the namespace '{OS_NAMESPACE}' or you are not authorized to access it (404)")
+EXPECT_THROWS(lambda: util.load_dump(manifest_par, {"progressFile": progress_par}), f"Error: Shell Error (54404): Util.load_dump: Failed to put object 'https://{OS_NAMESPACE}.objectstorage.{config['region']}.oci.customer-oci.com/p/<secret>/n/{OS_NAMESPACE}/b/{OS_BUCKET_NAME}/o/shell-test/par-load-progress.json': BucketNotFound: Either the bucket named '{OS_BUCKET_NAME}' does not exist in the namespace '{OS_NAMESPACE}' or you are not authorized to access it (404)")
 EXPECT_PAR_IS_SECRET()
 
 #@<> BUG#31606223 - read only, empty progress file
@@ -196,7 +200,7 @@ open("par-load-progress.json", "w").close()
 testutil.anycopy("par-load-progress.json", {"osBucketName":OS_BUCKET_NAME, "osNamespace": OS_NAMESPACE, "ociConfigFile":oci_config_file, "name":"shell-test/par-load-progress.json"})
 
 PREPARE_PAR_IS_SECRET_TEST()
-EXPECT_THROWS(lambda: util.load_dump(manifest_par, {"progressFile": progress_par}), f"Error: Shell Error (54404): Util.load_dump: Failed to put object 'https://objectstorage.{config['region']}.oraclecloud.com/p/<secret>/n/{OS_NAMESPACE}/b/{OS_BUCKET_NAME}/o/shell-test/par-load-progress.json': BucketNotFound: Either the bucket named '{OS_BUCKET_NAME}' does not exist in the namespace '{OS_NAMESPACE}' or you are not authorized to access it (404)")
+EXPECT_THROWS(lambda: util.load_dump(manifest_par, {"progressFile": progress_par}), f"Error: Shell Error (54404): Util.load_dump: Failed to put object 'https://{OS_NAMESPACE}.objectstorage.{config['region']}.oci.customer-oci.com/p/<secret>/n/{OS_NAMESPACE}/b/{OS_BUCKET_NAME}/o/shell-test/par-load-progress.json': BucketNotFound: Either the bucket named '{OS_BUCKET_NAME}' does not exist in the namespace '{OS_NAMESPACE}' or you are not authorized to access it (404)")
 EXPECT_PAR_IS_SECRET()
 
 os.remove("par-load-progress.json")
