@@ -1,4 +1,5 @@
 var sandbox_uris = {}
+const PLUGIN_ALREADY_EXISTS = 1125;
 sandbox_uris[__mysql_sandbox_port1] = __sandbox_uri1;
 sandbox_uris[__mysql_sandbox_port2] = __sandbox_uri2;
 sandbox_uris[__mysql_sandbox_port3] = __sandbox_uri3;
@@ -222,7 +223,7 @@ function hasAwsEnvironment() {
 
 
 function hasAuthEnvironment(context) {
-  if (['LDAP_SIMPLE', 'LDAP_SASL', 'LDAP_KERBEROS', 'KERBEROS', 'FIDO', 'OCI_AUTH'].indexOf(context) == -1) {
+  if (['LDAP_SIMPLE', 'LDAP_SASL', 'LDAP_KERBEROS', 'KERBEROS', 'FIDO', 'WEBAUTHN', 'OCI_AUTH'].indexOf(context) == -1) {
     return false
   }
 
@@ -344,6 +345,11 @@ function getAuthServerConfig(context) {
     return {
       "plugin-load-add": `authentication_fido.${ext}`
     };
+  } else if (context == 'WEBAUTHN') {
+    return {
+      "authentication-webauthn-rp-id": "mysql.com",
+      "plugin-load-add": `authentication_webauthn.${ext}`
+    };
   }
 
   return {};
@@ -380,7 +386,10 @@ function isAuthMethodSupported(context) {
   try {
     ensure_plugin_enabled(plugin, s);
   } catch (error) {
-    plugin_supported = false;
+    plugin_supported = error.code == PLUGIN_ALREADY_EXISTS;
+    if (!plugin_supported) {
+      print(`Unable to get ${plugin} installed: Error ${error.code}: ${error.message}`)
+    }
   }
 
   if (plugin_supported) {
@@ -725,8 +734,16 @@ function exist_in_metadata_schema(port) {
   return row[0] != 0;
 }
 
-function reset_instance(session) {
-  session.runSql("STOP SLAVE");
+function reset_instance(session, read_session_version) {
+  var version = __version_num;
+  if (read_session_version !== undefined && read_session_version) {
+    var version_array = session.runSql("SELECT version()").fetchOne()[0].match(/^(\d+)\.(\d+)\.(\d+)[^\d]*/);
+    EXPECT_EQ(4, version_array.length);
+
+    version = parseInt(version_array[1]) * 10000 + parseInt(version_array[2]) * 100 + parseInt(version_array[3]);
+  }
+
+  session.runSql("STOP " + get_replica_keyword(version));
   try {
   session.runSql("STOP group_replication");
   } catch (e) {}
@@ -751,8 +768,8 @@ function reset_instance(session) {
           continue;
       session.runSql("DROP USER ?@?", [row[0], row[1]]);
   }
-  session.runSql("RESET MASTER");
-  session.runSql("RESET SLAVE ALL");
+  session.runSql("RESET " + get_reset_binary_logs_keyword(version));
+  session.runSql("RESET " + get_replica_keyword(version) + " ALL");
 }
 
 var SANDBOX_PORTS = [__mysql_sandbox_port1, __mysql_sandbox_port2, __mysql_sandbox_port3];
@@ -1805,6 +1822,7 @@ function get_mysqlx_endpoint(uri) {
   return shell.unparseUri({ 'host': u.host, 'port': u.port * 10 });
 }
 
+var connection_error_msg = "Lost connection to MySQL server at 'waiting for initial communication packet', system error: 110";
 var protocol_error_msg = "The provided URI uses the X protocol, which is not supported by this command.";
 
 function EXPECT_THROWS_ERROR(msg, f, ...args) {
@@ -1818,14 +1836,15 @@ function CHECK_MYSQLX_EXPECT_THROWS_ERROR(msg, f, classic, ...args) {
 }
 
 function EXPECT_DBA_THROWS_PROTOCOL_ERROR(context, f, classic, ...args) {
-  CHECK_MYSQLX_EXPECT_THROWS_ERROR(`${context}: ${protocol_error_msg}`, f, classic, ...args);
+  CHECK_MYSQLX_EXPECT_THROWS_ERROR([`${context}: ${protocol_error_msg}`, `${context}: ${connection_error_msg}`], f, classic, ...args);
 }
 
 function EXPECT_CLUSTER_THROWS_PROTOCOL_ERROR(context, f, classic, ...args) {
   for (const uri of get_mysqlx_uris(classic)) {
     const endpoint = get_mysqlx_endpoint(classic);
     WIPE_OUTPUT();
-    EXPECT_THROWS_ERROR(`${context}: Could not open connection to '${endpoint}': ${protocol_error_msg}`, f, uri, ...args);
+    EXPECT_THROWS_ERROR([`${context}: Could not open connection to '${endpoint}': ${protocol_error_msg}`,
+        `${context}: Could not open connection to '${endpoint}': ${connection_error_msg}`], f, uri, ...args);
     EXPECT_STDOUT_CONTAINS(`Unable to connect to the target instance '${endpoint}'. Please verify the connection settings, make sure the instance is available and try again.`);
   }
 }
@@ -2005,3 +2024,47 @@ function STDCHECK_ARGTYPES(func, min_args, good_args1, good_args2, good_args3, g
   }
 }
 
+function get_reset_binary_logs_keyword(version) {
+  if (version === undefined) {
+    version = __version_num;
+  }
+
+  if (version < 80200) {
+    return "MASTER";
+  }
+
+  return "BINARY LOGS AND GTIDS";
+}
+
+function get_replica_keyword(version) {
+  if (version === undefined)
+    version = __version_num;
+
+  if (version < 80022) {
+    return "SLAVE";
+  }
+
+  return "REPLICA";
+}
+
+function get_replication_source_keyword(version) {
+  if (version === undefined)
+    version = __version_num;
+
+  if (version < 80022) {
+    return "MASTER";
+  }
+
+  return "REPLICATION SOURCE";
+}
+
+function get_replication_option_keyword(version) {
+  if (version === undefined)
+    version = __version_num;
+
+  if (version < 80022) {
+    return "MASTER";
+  }
+
+  return "SOURCE";
+}
