@@ -150,17 +150,15 @@ class Shell_cli_operation_test : public Shell_core_test_wrapper,
     prepare();
 
     // If the second list is empty, it means there were no arguments passed
-    // for it and so the CLI mapper provide an empty list as the second
-    // parameter
-    EXPECT_EQ(2, m_argument_list.size());
+    // for it and so the CLI mapper will NOT provide this argument to the API
+    // call
+    EXPECT_EQ(second ? 2 : 1, m_argument_list.size());
     EXPECT_EQ(shcore::Value(first), m_argument_list.at(0));
 
     // If there were arguments for the second list, they should be mapped
     // properly
     if (second) {
       EXPECT_EQ(shcore::Value(second), m_argument_list.at(1));
-    } else {
-      EXPECT_EQ(shcore::Value::new_array(), m_argument_list.at(1));
     }
   }
 
@@ -663,7 +661,7 @@ TEST_F(Shell_cli_operation_test, local_dict) {
     EXPECT_EQ("util", m_object_name);
     EXPECT_EQ("checkForServerUpgrade", m_method_name);
     EXPECT_EQ(1, m_argument_list.size());
-    ASSERT_TRUE(m_argument_list[0].type == Value_type::Map);
+    ASSERT_TRUE(m_argument_list[0].get_type() == Value_type::Map);
     EXPECT_EQ("localhost", m_argument_list.map_at(0)->get_string("host"));
   }
   {
@@ -683,9 +681,8 @@ TEST_F(Shell_cli_operation_test, local_dict) {
     parse(&it);
     // This no longer crashes as { and } are simply ignored
     prepare();
-    EXPECT_EQ(2, m_argument_list.size());
-    ASSERT_TRUE(m_argument_list[0].type == Value_type::Map);
-    ASSERT_EQ(shcore::Value::new_map(), m_argument_list[1]);
+    EXPECT_EQ(1, m_argument_list.size());
+    ASSERT_TRUE(m_argument_list[0].get_type() == Value_type::Map);
     EXPECT_EQ("localhost", m_argument_list.map_at(0)->get_string("host"));
   }
   {
@@ -718,9 +715,8 @@ TEST_F(Shell_cli_operation_test, connection_options) {
     EXPECT_NO_THROW(prepare());
     EXPECT_EQ("util", m_object_name);
     EXPECT_EQ("checkForServerUpgrade", m_method_name);
-    EXPECT_EQ(2, m_argument_list.size());
-    EXPECT_EQ(shcore::Value::new_map(), m_argument_list.at(1));
-    ASSERT_TRUE(m_argument_list[0].type == Value_type::Map);
+    EXPECT_EQ(1, m_argument_list.size());
+    ASSERT_TRUE(m_argument_list[0].get_type() == Value_type::Map);
     EXPECT_EQ("localhost", m_argument_list.map_at(0)->get_string("host"));
     EXPECT_EQ("required", m_argument_list.map_at(0)->get_string("ssl-mode"));
     EXPECT_EQ("zstd",
@@ -745,7 +741,7 @@ TEST_F(Shell_cli_operation_test, connection_options) {
     EXPECT_EQ("util", m_object_name);
     EXPECT_EQ("checkForServerUpgrade", m_method_name);
     EXPECT_EQ(2, m_argument_list.size());
-    ASSERT_TRUE(m_argument_list[0].type == Value_type::Map);
+    ASSERT_TRUE(m_argument_list[0].get_type() == Value_type::Map);
     auto co = m_argument_list.map_at(0);
     // a connection options dictionary
     EXPECT_EQ(3306, co->get_int("port"));
@@ -754,7 +750,7 @@ TEST_F(Shell_cli_operation_test, connection_options) {
     EXPECT_EQ("root", co->get_string("user"));
 
     // not a connection options dictionary
-    ASSERT_TRUE(m_argument_list[1].type == Value_type::Map);
+    ASSERT_TRUE(m_argument_list[1].get_type() == Value_type::Map);
     EXPECT_EQ("/whatever/path",
               m_argument_list.map_at(1)->get_string("configPath"));
   }
@@ -771,7 +767,7 @@ TEST_F(Shell_cli_operation_test, connection_options) {
     EXPECT_EQ("checkForServerUpgrade", m_method_name);
     EXPECT_EQ(2, m_argument_list.size());
     EXPECT_EQ(shcore::Value::Null(), m_argument_list[0]);
-    ASSERT_TRUE(m_argument_list[1].type == Value_type::Map);
+    ASSERT_TRUE(m_argument_list[1].get_type() == Value_type::Map);
     auto co = m_argument_list.map_at(1);
     // a connection options dictionary
     EXPECT_EQ("JSON", co->get_string("outputFormat"));
@@ -854,6 +850,16 @@ TEST_F(Shell_cli_operation_test, integration_test) {
                     {"--", "util", "check-for-server-upgrade", uri.c_str()}, "",
                     env));
   MY_EXPECT_STDOUT_CONTAINS("will now be checked for compatibility issues");
+  MY_EXPECT_STDOUT_CONTAINS("To check for a different target server version");
+  output_handler.wipe_all();
+
+  EXPECT_NE(10,
+            testutil->call_mysqlsh_c({"--", "util", "check-for-server-upgrade",
+                                      uri.c_str(), "--target-version=8.3.0"},
+                                     "", env));
+  MY_EXPECT_STDOUT_CONTAINS("will now be checked for compatibility issues");
+  MY_EXPECT_STDOUT_NOT_CONTAINS(
+      "To check for a different target server version");
   output_handler.wipe_all();
 
   MY_EXPECT_EQ_OR_DUMP(
@@ -1021,7 +1027,7 @@ class Test_cli_integration_api_options : public Shell_cli_operation_test {
           // Small exception if the actual argument is an array, in that case
           // the expected should contain all the values until named ones are
           // found
-          if (actual.type == shcore::Array) {
+          if (actual.get_type() == shcore::Array) {
             auto array = shcore::make_array();
             while (index < last_positional) {
               array->push_back(positional_arguments.at(index++));
