@@ -176,7 +176,8 @@ class Shell_cmdline_options : public tests::Shell_base_test {
     else if (option == "run_file")
       return options->run_file;
     else if (option == "connect-timeout")
-      return options->connection_options().get(mysqlshdk::db::kConnectTimeout);
+      return std::to_string(
+          options->connection_options().get_connect_timeout());
     else if (option == "quiet-start")
       return AS__STRING(static_cast<int>(options->quiet_start));
     else if (option == "showColumnTypeInfo")
@@ -1133,6 +1134,31 @@ TEST_F(Shell_cmdline_options, test_deprecated_arguments) {
         "The --dbuser option was deprecated, please use --user instead.",
         cout.str());
   }
+  {
+    SCOPED_TRACE("TESTING: deprecated --recreate-schema argument");
+    firstArg = "root@localhost:3301/some-schema";
+    secondArg = "--recreate-schema";
+
+    char *argv[] = {const_cast<char *>("ut"),
+                    const_cast<char *>(firstArg.c_str()),
+                    const_cast<char *>(secondArg.c_str()), NULL};
+
+    // Redirect cout.
+    std::streambuf *cout_backup = std::cout.rdbuf();
+    std::ostringstream cout;
+    std::cout.rdbuf(cout.rdbuf());
+
+    Shell_options cmd_options(3, argv);
+
+    // Restore old cout.
+    std::cout.rdbuf(cout_backup);
+
+    EXPECT_EQ(0, cmd_options.get().exit_code);
+    EXPECT_STREQ(cmd_options.get().connection_options().as_uri().c_str(),
+                 "root@localhost:3301/some-schema");
+    MY_EXPECT_OUTPUT_CONTAINS("The --recreate-schema option was deprecated.",
+                              cout.str());
+  }
 }
 
 TEST_F(Shell_cmdline_options, test_positional_argument) {
@@ -1589,7 +1615,7 @@ TEST_F(Shell_cmdline_options, invalid_connect_timeout) {
     std::string error("Invalid value '");
     error.append(value);
     error.append(
-        "' for 'connect-timeout'. The connection timeout value must "
+        "' for 'connect-timeout'. The timeout value must "
         "be a positive integer (including 0).\n");
 
     std::streambuf *backup = std::cerr.rdbuf();
