@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -496,7 +494,7 @@ TEST_F(Shell_prompt, color_i256_unicode) {
   prompt.clear();
   prompt.set_prompt(shcore::Value::parse("'\\uF37A'").get_string(), "",
                     mysqlshdk::textui::Style());
-  EXPECT_EQ(u8"\uF37A", prompt.render());
+  EXPECT_EQ("\xEF\x8D\xBA", prompt.render());
 }
 
 TEST(Shell_prompt_manager, load) {
@@ -997,7 +995,7 @@ class Shell_prompt_exe : public tests::Command_line_test {
 };
 
 TEST_F(Shell_prompt_exe, environment) {
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   const auto expect_prompt = "mysql-js>";
 #else
   const auto expect_prompt = "mysql-py>";
@@ -1196,7 +1194,7 @@ TEST_F(Shell_prompt_exe, sample_prompt_theme_nocolor) {
                "--ssl-mode=REQUIRED", "-e", "1", nullptr});
   EXPECT_EQ(0, rc);
   std::cout << _output << "\n";
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   EXPECT_PROMPT("MySQL [" + _host + ":" + _port + "+ ssl/mysql] JS> ");
 #else
   EXPECT_PROMPT("MySQL [" + _host + ":" + _port + "+ ssl/mysql] Py> ");
@@ -1217,7 +1215,7 @@ TEST_F(Shell_prompt_exe, sample_prompt_theme_16) {
   EXPECT_EQ(0, rc);
   std::cout << _output << "\n";
 
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   EXPECT_PROMPT("MySQL \x1B[1m[" + _host + "+ ssl/mysql] \x1B[0mJS> ");
 #else
   EXPECT_PROMPT("MySQL \x1B[1m[" + _host + "+ ssl/mysql] \x1B[0mPy> ");
@@ -1238,7 +1236,7 @@ TEST_F(Shell_prompt_exe, sample_prompt_theme_256) {
   EXPECT_EQ(0, rc);
   std::cout << _output << "\n";
 
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   EXPECT_PROMPT(
       "\x1B[48;5;254m\x1B[38;5;23m My\x1B[0m\x1B[48;5;254m\x1B[38;5;166mSQL "
       "\x1B[0m\x1B[48;5;237m\x1B[38;5;15m " +
@@ -1271,7 +1269,7 @@ TEST_F(Shell_prompt_exe, sample_prompt_theme_dbl_256) {
   EXPECT_EQ(0, rc);
   std::cout << _output << "\n";
 
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   EXPECT_DBL_PROMPT(
       "\x1B[48;5;254m\x1B[38;5;23m My\x1B[0m\x1B[48;5;254m\x1B[38;5;166mSQL "
       "\x1B[0m\x1B[48;5;237m\x1B[38;5;15m " +
@@ -1304,7 +1302,7 @@ TEST_F(Shell_prompt_exe, sample_prompt_theme_256pl) {
   EXPECT_EQ(0, rc);
   std::cout << _output << "\n";
 
-#ifdef HAVE_JS
+#ifdef HAVE_V8
   EXPECT_PROMPT(
       "\x1B[48;5;254m\x1B[38;5;23m My\x1B[0m\x1B[48;5;254m\x1B[38;5;166mSQL "
       "\x1B[48;5;237m\x1B[38;5;254m\xEE\x82\xB0\x1B[0m\x1B[48;5;237m\x1B[38;5;"
@@ -1332,7 +1330,7 @@ TEST_F(Shell_prompt_exe, sample_prompt_theme_256pl) {
   shcore::unsetenv("MYSQLSH_TERM_COLOR_MODE");
 }
 
-#ifdef HAVE_JS
+#ifdef HAVE_V8
 TEST_F(Shell_prompt_exe, bug28314383_js) {
   static constexpr auto k_file = "close.js";
   shcore::setenv("MYSQLSH_PROMPT_THEME",
@@ -1363,7 +1361,7 @@ TEST_F(Shell_prompt_exe, bug28314383_js) {
   shcore::unsetenv("MYSQLSH_TERM_COLOR_MODE");
   shcore::delete_file(k_file);
 }
-#endif  // HAVE_JS
+#endif  // HAVE_V8
 
 #ifdef HAVE_PYTHON
 TEST_F(Shell_prompt_exe, bug28314383_py) {
@@ -1401,7 +1399,7 @@ TEST_F(Shell_prompt_exe, bug28314383_py) {
 TEST_F(Shell_prompt_exe, bug30406283) {
   const std::string prompt_file = "invalid-utf8.json";
   const auto expect_prompt =
-#ifdef HAVE_JS
+#ifdef HAVE_V8
       "mysql-js> "
 #else
       "mysql-py> "
